@@ -51,7 +51,7 @@ public:
 		const std::string& feedurl);
 	void update_rssitem_unread_and_enqueued(RssItem* item,
 		const std::string& feedurl);
-	void cleanup_cache(std::vector<std::shared_ptr<RssFeed>>& feeds);
+	void cleanup_cache(std::vector<std::shared_ptr<RssFeed>> feeds);
 	void do_vacuum();
 	std::vector<std::shared_ptr<RssItem>> search_for_items(
 			const std::string& querystr,
@@ -74,6 +74,7 @@ public:
 	void mark_items_read_by_guid(const std::vector<std::string>& guids);
 	std::vector<std::string> get_read_item_guids();
 	void fetch_descriptions(RssFeed* feed);
+	std::string fetch_description(RssItem* item);
 
 private:
 	SchemaVersion get_schema_version();
