@@ -5,6 +5,7 @@
 #include <vector>
 
 #include "configparser.h"
+#include "stflpp.h"
 
 namespace podboat {
 class PbView;
@@ -14,6 +15,12 @@ class View;
 
 namespace newsboat {
 
+struct TextStyle {
+	std::string fg_color;
+	std::string bg_color;
+	std::vector<std::string> attributes;
+};
+
 class ColorManager : public ConfigActionHandler {
 public:
 	ColorManager();
@@ -22,29 +29,14 @@ public:
 	void handle_action(const std::string& action,
 		const std::vector<std::string>& params) override;
 	void dump_config(std::vector<std::string>& config_output) override;
-	bool colors_loaded()
+	void apply_colors(Stfl::Form& form) const;
+	std::map<std::string, TextStyle> get_styles() const
 	{
-		return colors_loaded_;
-	}
-	void set_pb_colors(podboat::PbView* v);
-	std::map<std::string, std::string>& get_fgcolors()
-	{
-		return fg_colors;
-	}
-	std::map<std::string, std::string>& get_bgcolors()
-	{
-		return bg_colors;
-	}
-	std::map<std::string, std::vector<std::string>>& get_attributes()
-	{
-		return attributes;
+		return element_styles;
 	}
 
 private:
-	bool colors_loaded_;
-	std::map<std::string, std::string> fg_colors;
-	std::map<std::string, std::string> bg_colors;
-	std::map<std::string, std::vector<std::string>> attributes;
+	std::map<std::string, TextStyle> element_styles;
 };
 
 } // namespace newsboat
