@@ -2,6 +2,7 @@
 #define NEWSBOAT_DIALOGSFORMACTION_H_
 
 #include "formaction.h"
+#include "listwidget.h"
 
 namespace newsboat {
 
@@ -20,10 +21,11 @@ public:
 	void handle_cmdline(const std::string& cmd) override;
 
 private:
-	void process_operation(Operation op,
+	bool process_operation(Operation op,
 		bool automatic = false,
 		std::vector<std::string>* args = nullptr) override;
 	bool update_list;
+	ListWidget dialogs_list;
 };
 
 } // namespace newsboat
