@@ -19,7 +19,7 @@ public:
 	void sort_feeds(const FeedSortStrategy& sort_strategy);
 	std::shared_ptr<RssFeed> get_feed(const unsigned int pos);
 	void add_feed(const std::shared_ptr<RssFeed> feed);
-	void mark_all_feed_items_read(const unsigned int feed_pos);
+	void mark_all_feed_items_read(std::shared_ptr<RssFeed> feed);
 	void mark_all_feeds_read();
 	unsigned int get_feed_count_per_tag(const std::string& tag);
 
@@ -35,14 +35,14 @@ public:
 	unsigned int feeds_size();
 	void reset_feeds_status();
 	void set_feeds(const std::vector<std::shared_ptr<RssFeed>> new_feeds);
-	std::vector<std::shared_ptr<RssFeed>> get_all_feeds();
-	void clear_feeds_items();
+	std::vector<std::shared_ptr<RssFeed>> get_all_feeds() const;
 	unsigned int unread_feed_count() const;
 	unsigned int unread_item_count() const;
 
-	std::vector<std::shared_ptr<RssFeed>> feeds;
+	void replace_feed(unsigned int pos, std::shared_ptr<RssFeed> feed);
 
 private:
+	std::vector<std::shared_ptr<RssFeed>> feeds;
 	mutable std::mutex feeds_mutex;
 };
 } // namespace newsboat
