@@ -6,7 +6,6 @@
 #include "configcontainer.h"
 #include "history.h"
 #include "listformaction.h"
-#include "listwidget.h"
 #include "matcher.h"
 #include "regexmanager.h"
 #include "view.h"
@@ -88,8 +87,6 @@ private:
 
 	History filterhistory;
 
-	std::shared_ptr<RssFeed> search_dummy_feed;
-
 	unsigned int filterpos;
 	bool set_filterpos;
 
@@ -99,7 +96,7 @@ private:
 
 	nonstd::optional<FeedSortStrategy> old_sort_strategy;
 
-	ListWidget feeds_list;
+	Cache* cache;
 };
 
 } // namespace newsboat
