@@ -40,9 +40,12 @@ private:
 		std::vector<std::string>* args = nullptr) override;
 	void update_title(const std::string& working_directory);
 
-	void add_file(ListFormatter& listfmt, std::string filename);
+	void add_file(ListFormatter& listfmt,
+		std::vector<std::string>& id_at_position,
+		std::string filename);
 	std::string get_filename_suggestion(const std::string& s);
 	std::string get_rwx(unsigned short val);
+	std::vector<std::string> id_at_position;
 
 	char get_filetype(mode_t mode);
 	std::string get_owner(uid_t uid);
