@@ -28,7 +28,7 @@ public:
 	virtual ~FormAction();
 	virtual void prepare() = 0;
 	virtual void init() = 0;
-	std::shared_ptr<Stfl::Form> get_form();
+	Stfl::Form& get_form();
 	virtual void set_redraw(bool b)
 	{
 		do_redraw = b;
@@ -42,7 +42,7 @@ public:
 
 	virtual void handle_cmdline(const std::string& cmd);
 
-	void process_op(Operation op,
+	bool process_op(Operation op,
 		bool automatic = false,
 		std::vector<std::string>* args = nullptr);
 
@@ -87,7 +87,7 @@ public:
 		const std::string& feed_title);
 
 protected:
-	virtual void process_operation(Operation op,
+	virtual bool process_operation(Operation op,
 		bool automatic = false,
 		std::vector<std::string>* args = nullptr) = 0;
 	virtual void set_keymap_hints();
@@ -101,7 +101,7 @@ protected:
 
 	View* v;
 	ConfigContainer* cfg;
-	std::shared_ptr<Stfl::Form> f;
+	Stfl::Form f;
 	bool do_redraw;
 
 	std::vector<std::string> qna_responses;
