@@ -2,6 +2,7 @@
 #define NEWSBOAT_HELPFORMACTION_H_
 
 #include "formaction.h"
+#include "textviewwidget.h"
 
 namespace newsboat {
 
@@ -22,7 +23,7 @@ public:
 	void set_context(const std::string& ctx);
 
 private:
-	void process_operation(Operation op,
+	bool process_operation(Operation op,
 		bool automatic = false,
 		std::vector<std::string>* args = nullptr) override;
 	std::string make_colorstring(const std::vector<std::string>& colors);
@@ -30,6 +31,7 @@ private:
 	bool apply_search;
 	std::string searchphrase;
 	std::string context;
+	TextviewWidget textview;
 };
 
 } // namespace newsboat
