@@ -10,7 +10,9 @@
 
 namespace newsboat {
 
-enum class LinkType { HREF, IMG, EMBED };
+// This enum has to be kept in sync with enum LinkType in rust/libnewsboat/src/htmlrenderer.rs
+enum class LinkType { HREF, IMG, EMBED, VIDEO, AUDIO };
+
 enum class HtmlTag {
 	A = 1,
 	EMBED,
@@ -43,7 +45,10 @@ enum class HtmlTag {
 	TABLE,
 	TH,
 	TR,
-	TD
+	TD,
+	VIDEO,
+	AUDIO,
+	SOURCE
 };
 
 typedef std::pair<std::string, LinkType> LinkPair;
@@ -110,7 +115,6 @@ private:
 	unsigned int add_link(std::vector<LinkPair>& links,
 		const std::string& link,
 		LinkType type);
-	std::string quote_for_stfl(std::string str);
 	std::string absolute_url(const std::string& url,
 		const std::string& link);
 	std::string type2str(LinkType type);
@@ -130,6 +134,9 @@ private:
 	void add_hr(std::vector<std::pair<LineType, std::string>>& lines);
 	std::string get_char_numbering(unsigned int count);
 	std::string get_roman_numbering(unsigned int count);
+	void add_media_link(std::string& line, std::vector<LinkPair>& links,
+		const std::string& url, const std::string& media_url,
+		unsigned int media_count, LinkType type);
 	bool raw_;
 };
 
