@@ -5,6 +5,7 @@
 #include "htmlrenderer.h"
 #include "regexmanager.h"
 #include "textformatter.h"
+#include "textviewwidget.h"
 
 namespace newsboat {
 
@@ -18,7 +19,8 @@ public:
 		std::shared_ptr<ItemListFormAction> il,
 		std::string formstr,
 		Cache* cc,
-		ConfigContainer* cfg);
+		ConfigContainer* cfg,
+		RegexManager& r);
 	~ItemViewFormAction() override;
 	void prepare() override;
 	void init() override;
@@ -48,12 +50,12 @@ public:
 		std::vector<LinkPair>& thelinks,
 		const std::string& url);
 
-	void set_regexmanager(RegexManager* r);
-
 	void update_percent();
 
 private:
-	void process_operation(Operation op,
+	void register_format_styles();
+
+	bool process_operation(Operation op,
 		bool automatic = false,
 		std::vector<std::string>* args = nullptr) override;
 	void update_head(const std::shared_ptr<RssItem>& item);
@@ -74,11 +76,12 @@ private:
 	bool show_source;
 	std::vector<LinkPair> links;
 	bool quit;
-	RegexManager* rxman;
+	RegexManager& rxman;
 	unsigned int num_lines;
 	std::shared_ptr<ItemListFormAction> itemlist;
 	bool in_search;
 	Cache* rsscache;
+	TextviewWidget textview;
 };
 
 } // namespace newsboat
