@@ -12,7 +12,8 @@ namespace newsboat {
 
 class ListWidget {
 public:
-	ListWidget(const std::string& list_name, Stfl::Form& form);
+	ListWidget(const std::string& list_name, Stfl::Form& form,
+		std::uint32_t scrolloff);
 	void stfl_replace_list(std::uint32_t number_of_lines, std::string stfl);
 	void stfl_replace_lines(const ListFormatter& listfmt);
 
@@ -29,9 +30,15 @@ public:
 	std::uint32_t get_width();
 	std::uint32_t get_height();
 private:
+	std::uint32_t get_scroll_offset();
+	void set_scroll_offset(std::uint32_t pos);
+
+	void update_scroll_offset(std::uint32_t pos);
+
 	const std::string list_name;
 	Stfl::Form& form;
 	std::uint32_t num_lines;
+	std::uint32_t num_context_lines;
 };
 
 } // namespace newsboat
