@@ -5,9 +5,11 @@
 #include <string>
 #include <vector>
 
+#include "colormanager.h"
 #include "configcontainer.h"
 #include "download.h"
 #include "fslock.h"
+#include "keymap.h"
 #include "queueloader.h"
 
 namespace podboat {
@@ -24,7 +26,8 @@ public:
 	{
 		v = vv;
 	}
-	int run(int argc, char* argv[] = 0);
+	void initialize(int argc, char* argv[]);
+	int run();
 
 	bool view_update_necessary() const
 	{
@@ -59,6 +62,11 @@ public:
 		return cfg;
 	}
 
+	const newsboat::ColorManager& get_colormanager()
+	{
+		return colorman;
+	}
+
 private:
 	void print_usage(const char* argv0);
 	bool setup_dirs_xdg(const char* env_home);
@@ -82,6 +90,10 @@ private:
 
 	std::string lock_file;
 	std::unique_ptr<newsboat::FsLock> fslock;
+
+	bool automatic_dl = false;
+	newsboat::ColorManager colorman;
+	newsboat::KeyMap keys;
 };
 
 } // namespace podboat
