@@ -14,13 +14,6 @@ class CurlHandle;
 
 /// \brief Updates feeds (fetches, parses, puts results into Controller).
 class Reloader {
-	Controller* ctrl;
-	Cache* rsscache;
-	ConfigContainer* cfg;
-	std::mutex reload_mutex;
-
-	std::string prepare_message(unsigned int pos, unsigned int max);
-
 public:
 	Reloader(Controller* c, Cache* cc, ConfigContainer* cfg);
 
@@ -30,8 +23,8 @@ public:
 	/// \brief Starts a thread that will reload feeds with specified
 	/// indexes.
 	///
-	/// If \a indexes is nullptr, all feeds will be reloaded.
-	void start_reload_all_thread(std::vector<int>* indexes = nullptr);
+	/// If \a indexes is empty, all feeds will be reloaded.
+	void start_reload_all_thread(const std::vector<int>& indexes = {});
 
 	void unlock_reload_mutex()
 	{
@@ -78,6 +71,7 @@ public:
 		unsigned int size,
 		bool unattended = false);
 
+private:
 	/// \brief Notify in various ways that there are new unread feeds or
 	/// articles.
 	///
@@ -89,6 +83,17 @@ public:
 	/// notification will contain \a msg passed.
 	void notify(const std::string& msg);
 
+	void notify_reload_finished(unsigned int unread_feeds_before,
+		unsigned int unread_articles_before);
+
+	Controller* ctrl;
+	Cache* rsscache;
+	ConfigContainer* cfg;
+	std::mutex reload_mutex;
+
+	std::string prepare_message(unsigned int pos, unsigned int max);
+
+
 };
 
 } // namespace newsboat
