@@ -3,6 +3,7 @@
 
 #include "filtercontainer.h"
 #include "formaction.h"
+#include "listwidget.h"
 
 namespace newsboat {
 
@@ -40,7 +41,7 @@ public:
 	std::string title() override;
 
 private:
-	void process_operation(Operation op,
+	bool process_operation(Operation op,
 		bool automatic = false,
 		std::vector<std::string>* args = nullptr) override;
 	bool quit;
@@ -53,6 +54,8 @@ private:
 		const std::string& tag,
 		unsigned int pos,
 		unsigned int width);
+
+	ListWidget tags_list;
 };
 
 } // namespace newsboat
