@@ -3,6 +3,7 @@
 
 #include "formaction.h"
 #include "htmlrenderer.h"
+#include "listwidget.h"
 
 namespace newsboat {
 
@@ -28,12 +29,13 @@ public:
 	void handle_cmdline(const std::string& cmd) override;
 
 private:
-	void process_operation(Operation op,
+	bool process_operation(Operation op,
 		bool automatic = false,
 		std::vector<std::string>* args = nullptr) override;
 	std::vector<LinkPair> links;
 	bool quit;
 	std::shared_ptr<RssFeed> feed;
+	ListWidget urls_list;
 };
 
 } // namespace newsboat
