@@ -1,11 +1,13 @@
 #ifndef NEWSBOAT_UTIL_H_
 #define NEWSBOAT_UTIL_H_
 
+#include <cstdint>
 #include <curl/curl.h>
 #include <libxml/parser.h>
 #include <memory>
 #include <stdexcept>
 #include <string>
+#include <utility>
 #include <vector>
 
 #include "3rd-party/optional.hpp"
@@ -19,6 +21,14 @@ namespace newsboat {
 enum class LinkType;
 
 namespace utils {
+
+enum class HTTPMethod {
+	GET = 0,
+	POST,
+	PUT,
+	DELETE
+};
+
 std::string strip_comments(const std::string& line);
 std::vector<std::string> tokenize(const std::string& str,
 	std::string delimiters = " \r\n\t");
@@ -28,12 +38,11 @@ std::vector<std::string> tokenize_nl(const std::string& str,
 	std::string delimiters = "\r\n");
 std::vector<std::string> tokenize_quoted(const std::string& str,
 	std::string delimiters = " \r\n\t");
+nonstd::optional<std::string> extract_token_quoted(std::string& str,
+	std::string delimiters = " \r\n\t");
 
 std::string consolidate_whitespace(const std::string& str);
 
-std::vector<std::wstring> wtokenize(const std::wstring& str,
-	std::wstring delimiters = L" \r\n\t");
-
 std::string translit(const std::string& tocode,
 	const std::string& fromcode);
 std::string convert_text(const std::string& text,
@@ -48,10 +57,12 @@ std::string get_command_output(const std::string& cmd);
 void extract_filter(const std::string& line,
 	std::string& filter,
 	std::string& url);
+std::string http_method_str(const HTTPMethod method);
 std::string retrieve_url(const std::string& url,
 	ConfigContainer* cfgcont = nullptr,
 	const std::string& authinfo = "",
-	const std::string* postdata = nullptr,
+	const std::string* body = nullptr,
+	const HTTPMethod method = HTTPMethod::GET,
 	CURL* easyhandle = nullptr);
 void run_command(const std::string& cmd,
 	const std::string& param); // used for notifications only
@@ -75,7 +86,6 @@ std::string get_useragent(ConfigContainer* cfgcont);
 
 size_t strwidth(const std::string& s);
 size_t strwidth_stfl(const std::string& str);
-size_t wcswidth_stfl(const std::wstring& str, size_t size);
 
 std::string substr_with_width(const std::string& str,
 	const size_t max_width);
@@ -135,7 +145,7 @@ int mkdir_parents(const std::string& pathname,
 
 std::string make_title(const std::string& url);
 
-int32_t run_interactively(const std::string& command,
+nonstd::optional<std::uint8_t> run_interactively(const std::string& command,
 	const std::string& caller);
 
 std::string getcwd();
