@@ -1,16 +1,20 @@
 #ifndef NEWSBOAT_VIEW_H_
 #define NEWSBOAT_VIEW_H_
 
+#include <cstdint>
 #include <list>
 #include <mutex>
 #include <string>
 #include <vector>
 
+#include "3rd-party/optional.hpp"
+
 #include "colormanager.h"
 #include "configcontainer.h"
 #include "controller.h"
-#include "filebrowserformaction.h"
 #include "dirbrowserformaction.h"
+#include "feedlistformaction.h"
+#include "filebrowserformaction.h"
 #include "htmlrenderer.h"
 #include "keymap.h"
 #include "regexmanager.h"
@@ -20,6 +24,7 @@ namespace newsboat {
 
 class ItemListFormAction;
 class ItemViewFormAction;
+class FeedListFormAction;
 
 class View {
 public:
@@ -59,7 +64,8 @@ public:
 	char confirm(const std::string& prompt, const std::string& charset);
 
 	void push_itemlist(unsigned int pos);
-	void push_itemlist(std::shared_ptr<RssFeed> feed);
+	std::shared_ptr<ItemListFormAction> push_itemlist(std::shared_ptr<RssFeed>
+		feed);
 	void push_itemview(std::shared_ptr<RssFeed> f,
 		const std::string& guid,
 		const std::string& searchphrase = "");
@@ -77,35 +83,31 @@ public:
 	std::string select_filter(
 		const std::vector<FilterNameExprPair>& filters);
 
-	int open_in_browser(const std::string& url);
+	nonstd::optional<std::uint8_t> open_in_browser(const std::string& url);
 	void open_in_pager(const std::string& filename);
 
 	std::string get_filename_suggestion(const std::string& s);
 
-	bool get_next_unread(ItemListFormAction* itemlist,
+	bool get_next_unread(ItemListFormAction& itemlist,
 		ItemViewFormAction* itemview = nullptr);
-	bool get_previous_unread(ItemListFormAction* itemlist,
+	bool get_previous_unread(ItemListFormAction& itemlist,
 		ItemViewFormAction* itemview = nullptr);
-	bool get_next(ItemListFormAction* itemlist,
+	bool get_next(ItemListFormAction& itemlist,
 		ItemViewFormAction* itemview = nullptr);
-	bool get_previous(ItemListFormAction* itemlist,
+	bool get_previous(ItemListFormAction& itemlist,
 		ItemViewFormAction* itemview = nullptr);
-	bool get_random_unread(ItemListFormAction* itemlist,
+	bool get_random_unread(ItemListFormAction& itemlist,
 		ItemViewFormAction* itemview = nullptr);
 
-	bool get_next_unread_feed(ItemListFormAction* itemlist);
-	bool get_prev_unread_feed(ItemListFormAction* itemlist);
-	bool get_next_feed(ItemListFormAction* itemlist);
-	bool get_prev_feed(ItemListFormAction* itemlist);
+	bool get_next_unread_feed(ItemListFormAction& itemlist);
+	bool get_prev_unread_feed(ItemListFormAction& itemlist);
+	bool get_next_feed(ItemListFormAction& itemlist);
+	bool get_prev_feed(ItemListFormAction& itemlist);
 
 	void prepare_query_feed(std::shared_ptr<RssFeed> feed);
 
 	void force_redraw();
 
-	void set_colors(std::map<std::string, std::string>& fg_colors,
-		std::map<std::string, std::string>& bg_colors,
-		std::map<std::string, std::vector<std::string>>& attributes);
-
 	void notify_itemlist_change(std::shared_ptr<RssFeed> feed);
 
 	void feedlist_mark_pos_if_visible(unsigned int pos);
@@ -134,6 +136,8 @@ public:
 	static void ctrl_c_action(int sig);
 
 protected:
+	bool run_commands(const std::vector<MacroCmd>& commands);
+
 	void apply_colors(std::shared_ptr<FormAction> fa);
 
 	void handle_cmdline_completion(std::shared_ptr<FormAction> fa);
@@ -148,18 +152,15 @@ protected:
 	KeyMap* keys;
 	std::mutex mtx;
 
-	friend class ColorManager;
-
 	std::vector<std::shared_ptr<FormAction>> formaction_stack;
 	unsigned int current_formaction;
+	std::shared_ptr<FeedListFormAction> feedlist_form;
 
 	std::vector<std::string> tags;
 
 	RegexManager& rxman;
 
-	std::map<std::string, std::string> fg_colors;
-	std::map<std::string, std::string> bg_colors;
-	std::map<std::string, std::vector<std::string>> attributes;
+	std::map<std::string, TextStyle> text_styles;
 
 	bool is_inside_qna;
 	bool is_inside_cmdline;
@@ -168,6 +169,7 @@ protected:
 	unsigned int tab_count;
 	Cache* rsscache;
 	FilterContainer& filters;
+	const ColorManager& colorman;
 	std::vector<std::string> suggestions;
 };
 
