@@ -1,14 +1,18 @@
 //! Parses filter expressions.
 
+use gettextrs::gettext;
+use lazy_static::lazy_static;
 use nom::{
     branch::alt,
     bytes::complete::{escaped, is_not, tag, take, take_while, take_while1},
     character::{is_alphanumeric, is_digit},
     combinator::{complete, map, opt, peek, recognize, value},
-    error::{make_error, ErrorKind, ParseError, VerboseError},
+    error::{context, ParseError, VerboseError, VerboseErrorKind},
     sequence::{delimited, separated_pair, terminated, tuple},
     IResult, Offset,
 };
+use std::collections::BTreeMap;
+use strprintf::fmt;
 
 /// Operators that can be used in comparisons.
 #[derive(Debug, Clone, PartialEq)]
@@ -28,11 +32,7 @@ pub enum Operator {
 
 /// Values that can be used on the right-hand side of comparisons.
 #[derive(Debug, Clone, PartialEq)]
-pub enum Value {
-    Str(String),
-    Int(i32),
-    Range(i32, i32),
-}
+pub struct Value(pub String);
 
 /// Parsed filter expression.
 ///
@@ -51,28 +51,68 @@ pub enum Expression {
 
 /// Errors that may come up during parsing.
 #[derive(PartialEq, Debug)]
-pub enum Error<'a> {
-    /// Parser finished the work, but the input string still contains some characters.
-    TrailingCharacters(&'a str),
+enum Error<'a> {
+    /// Parser finished the work, but the input string still contains some characters (starting at
+    /// given position).
+    TrailingCharacters(usize, &'a str),
 
-    /// Parsing error at given position.
-    AtPos(usize),
+    /// Parsing error at given position. "Explanation string" is one of `EXPECTED_*` constants.
+    AtPos(usize, &'static str),
+
+    /// Parse error that has no explanations attached to it.
+    Internal,
+}
+
+// These strings are used as identifiers in nom::context macro, which unfortunately requires
+// &'static str. The identifiers are then turned into actual, internationalized messages by
+// expected_to_i18n_msg().
+static EXPECTED_ATTRIBUTE_NAME: &str = "EXPECTED_ATTRIBUTE_NAME";
+static EXPECTED_OPERATORS: &str = "EXPECTED_OPERATORS";
+static EXPECTED_VALUE: &str = "EXPECTED_VALUE";
+
+fn expected_to_i18n_msg(expected_id: &'static str) -> &'static str {
+    lazy_static! {
+        static ref ID_TO_I18N: BTreeMap<&'static str, String> = {
+            let mut result = BTreeMap::new();
+            result.insert(EXPECTED_ATTRIBUTE_NAME, gettext("attribute name"));
+            result.insert(
+                EXPECTED_OPERATORS,
+                gettext("one of: =~, ==, =, !~, !=, <=, >=, <, >, between, #, !#"),
+            );
+            result.insert(
+                EXPECTED_VALUE,
+                gettext("one of: quoted string, range, number"),
+            );
+            result
+        };
+    }
+
+    ID_TO_I18N
+        .get(expected_id)
+        .map(|s| s.as_str())
+        // This message is intentionally left untranslated, to make it more eye-catching for
+        // non-English-speaking users. If this ever pops up, it's be nice to hear of it ASAP, so it
+        // pays to make it look unusual.
+        .unwrap_or("<internal error in filterparser::expected_to_i18n_msg>")
 }
 
 fn operators<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, Operator, E> {
-    alt((
-        value(Operator::RegexMatches, tag("=~")),
-        value(Operator::Equals, alt((tag("=="), tag("=")))),
-        value(Operator::NotRegexMatches, tag("!~")),
-        value(Operator::NotEquals, tag("!=")),
-        value(Operator::LessThanOrEquals, tag("<=")),
-        value(Operator::GreaterThanOrEquals, tag(">=")),
-        value(Operator::LessThan, tag("<")),
-        value(Operator::GreaterThan, tag(">")),
-        value(Operator::Between, tag("between")),
-        value(Operator::Contains, tag("#")),
-        value(Operator::NotContains, tag("!#")),
-    ))(input)
+    context(
+        EXPECTED_OPERATORS,
+        alt((
+            value(Operator::RegexMatches, tag("=~")),
+            value(Operator::Equals, alt((tag("=="), tag("=")))),
+            value(Operator::NotRegexMatches, tag("!~")),
+            value(Operator::NotEquals, tag("!=")),
+            value(Operator::LessThanOrEquals, tag("<=")),
+            value(Operator::GreaterThanOrEquals, tag(">=")),
+            value(Operator::LessThan, tag("<")),
+            value(Operator::GreaterThan, tag(">")),
+            value(Operator::Between, tag("between")),
+            value(Operator::Contains, tag("#")),
+            value(Operator::NotContains, tag("!#")),
+        )),
+    )(input)
 }
 
 fn quoted_string<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, Value, E> {
@@ -86,25 +126,16 @@ fn quoted_string<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str,
         Ok((leftovers, String::from(chr)))
     };
 
-    map(alt((nonempty_string, empty_string)), Value::Str)(input)
+    map(alt((nonempty_string, empty_string)), Value)(input)
 }
 
-fn number<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, i32, E> {
-    recognize(tuple((opt(tag("-")), take_while1(|c| is_digit(c as u8)))))(input).and_then(
-        |(leftovers, num)| {
-            match num.parse() {
-                Ok(number) => Ok((leftovers, number)),
-                // It shouldn't matter what ErrorKind we use here: we don't examine it anyway, and
-                // only use the `input` part to figure out the location of the error.
-                Err(_) => Err(nom::Err::Error(make_error(input, ErrorKind::TakeWhile1))),
-            }
-        },
-    )
+fn number<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, &'a str, E> {
+    recognize(tuple((opt(tag("-")), take_while1(|c| is_digit(c as u8)))))(input)
 }
 
 fn range<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, Value, E> {
     separated_pair(number, tag(":"), number)(input)
-        .map(|(leftovers, (a, b))| (leftovers, Value::Range(a, b)))
+        .map(|(leftovers, (a, b))| (leftovers, Value(format!("{}:{}", a, b))))
 }
 
 /// Skips zero or more space characters.
@@ -124,15 +155,20 @@ fn space1<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, &'a st
 }
 
 fn comparison<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, Expression, E> {
-    let attribute_name =
-        take_while1(|c| is_alphanumeric(c as u8) || c == '_' || c == '-' || c == '.');
+    let attribute_name = context(
+        EXPECTED_ATTRIBUTE_NAME,
+        take_while1(|c| is_alphanumeric(c as u8) || c == '_' || c == '-' || c == '.'),
+    );
 
     let (input, attr) = attribute_name(input)?;
     let attribute = attr.to_string();
     let (input, _) = space0(input)?;
     let (input, op) = operators(input)?;
     let (input, _) = space0(input)?;
-    let (leftovers, value) = alt((quoted_string, range, map(number, Value::Int)))(input)?;
+    let (leftovers, value) = context(
+        EXPECTED_VALUE,
+        alt((quoted_string, range, map(number, |n| Value(n.to_string())))),
+    )(input)?;
 
     Ok((
         leftovers,
@@ -210,22 +246,28 @@ fn parser<'a, E: ParseError<&'a str>>(input: &'a str) -> IResult<&'a str, Expres
     complete(parsers)(input)
 }
 
-/// Parse a string `expr` as a filter expression.
-pub fn parse(expr: &str) -> Result<Expression, Error> {
+fn internal_parse(expr: &str) -> Result<Expression, Error> {
     match parser::<VerboseError<&str>>(expr) {
         Ok((leftovers, expression)) => {
             if leftovers.is_empty() {
                 Ok(expression)
             } else {
-                Err(Error::TrailingCharacters(&leftovers))
+                Err(Error::TrailingCharacters(
+                    expr.offset(leftovers),
+                    &leftovers,
+                ))
             }
         }
         Err(error) => {
             let handler = |e: VerboseError<&str>| -> Error {
-                match e.errors.first() {
-                    None => Error::AtPos(0),
-                    Some((s, _kind)) => Error::AtPos(expr.offset(s)),
+                for (chunk, err) in e.errors {
+                    let pos = expr.offset(chunk);
+                    match err {
+                        VerboseErrorKind::Context(expected) => return Error::AtPos(pos, expected),
+                        _ => continue,
+                    }
                 }
+                Error::Internal
             };
 
             match error {
@@ -239,44 +281,98 @@ pub fn parse(expr: &str) -> Result<Expression, Error> {
     }
 }
 
+/// Parse a string `expr` as a filter expression.
+///
+/// If parsing fails, returns an internationalized error message.
+pub fn parse(expr: &str) -> Result<Expression, String> {
+    match internal_parse(expr) {
+        Ok(expression) => Ok(expression),
+        Err(error) => {
+            let err = match error {
+                Error::TrailingCharacters(pos, tail) => fmt!(
+                    // The "%{}" thing is a number, a zero-based offset into a string.
+                    &gettext("Parse error: trailing characters after position %{}: %s"),
+                    PRIu64,
+                    pos as u64,
+                    tail
+                ),
+                Error::AtPos(pos, expected) => fmt!(
+                    // The "%{}" thing is a number, a zero-based offset into a string.
+                    &gettext("Parse error at position %{}: expected %s"),
+                    PRIu64,
+                    pos as u64,
+                    expected_to_i18n_msg(expected)
+                ),
+                Error::Internal => fmt!(&gettext("Internal parse error")),
+            };
+            Err(err)
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::{Expression::*, *};
 
     #[test]
     fn t_error_on_invalid_queries() {
-        assert_eq!(parse("title =¯ \"foo\""), Err(Error::AtPos(7)));
-        assert_eq!(parse("a = \"b"), Err(Error::AtPos(4)));
-        assert_eq!(parse("a = b"), Err(Error::AtPos(4)));
-        assert_eq!(parse("a !! \"b\""), Err(Error::AtPos(2)));
+        // Invalid character in operator
+        assert_eq!(
+            internal_parse("title =¯ \"foo\""),
+            Err(Error::AtPos(7, EXPECTED_VALUE))
+        );
+        // Incorrect string quoting
+        assert_eq!(
+            internal_parse("a = \"b"),
+            Err(Error::AtPos(4, EXPECTED_VALUE))
+        );
+        // Non-value to the right of equality operator
+        assert_eq!(
+            internal_parse("a = b"),
+            Err(Error::AtPos(4, EXPECTED_VALUE))
+        );
+        // Non-existent operator
+        assert_eq!(
+            internal_parse("a !! \"b\""),
+            Err(Error::AtPos(2, EXPECTED_OPERATORS))
+        );
 
-        assert_eq!(parse("((a=\"b\")))"), Err(Error::TrailingCharacters(")")));
+        // Unbalanced parentheses
+        assert_eq!(
+            internal_parse("((a=\"b\")))"),
+            Err(Error::TrailingCharacters(9, ")"))
+        );
 
-        // From C++ Matcher suite
+        // Incorrect syntax for range
         assert_eq!(
-            parse("AAAA between 0:15:30"),
-            Err(Error::TrailingCharacters(":30"))
+            internal_parse("AAAA between 0:15:30"),
+            Err(Error::TrailingCharacters(17, ":30"))
+        );
+        // No whitespace after the `and` operator
+        assert_eq!(
+            internal_parse("x = 42andy=0"),
+            Err(Error::TrailingCharacters(6, "andy=0"))
         );
         assert_eq!(
-            parse("x = 42andy=0"),
-            Err(Error::TrailingCharacters("andy=0"))
+            internal_parse("x = 42 andy=0"),
+            Err(Error::TrailingCharacters(7, "andy=0"))
         );
+        // Operator without arguments
         assert_eq!(
-            parse("x = 42 andy=0"),
-            Err(Error::TrailingCharacters("andy=0"))
+            internal_parse("=!"),
+            Err(Error::AtPos(0, EXPECTED_ATTRIBUTE_NAME))
         );
-        assert_eq!(parse("=!"), Err(Error::AtPos(0)));
     }
 
     #[test]
     fn t_no_error_on_valid_queries() {
-        assert!(parse("a = \"b\"").is_ok());
-        assert!(parse("(a=\"b\")").is_ok());
-        assert!(parse("((a=\"b\"))").is_ok());
-        assert!(parse("a != \"b\"").is_ok());
-        assert!(parse("a =~ \"b\"").is_ok());
-        assert!(parse("a !~ \"b\"").is_ok());
-        assert!(parse(
+        assert!(internal_parse("a = \"b\"").is_ok());
+        assert!(internal_parse("(a=\"b\")").is_ok());
+        assert!(internal_parse("((a=\"b\"))").is_ok());
+        assert!(internal_parse("a != \"b\"").is_ok());
+        assert!(internal_parse("a =~ \"b\"").is_ok());
+        assert!(internal_parse("a !~ \"b\"").is_ok());
+        assert!(internal_parse(
 				"( a = \"b\") and ( b = \"c\" ) or ( ( c != \"d\" ) and ( c !~ \"asdf\" )) or c != \"xx\"").is_ok());
     }
 
@@ -285,28 +381,30 @@ mod tests {
         let expected = Ok(Expression::Comparison {
             attribute: "a".to_string(),
             op: Operator::Equals,
-            value: Value::Str("abc".to_string()),
+            value: Value("abc".to_string()),
         });
 
-        assert_eq!(parse("a = \"abc\""), expected);
-        assert_eq!(parse("a == \"abc\""), expected);
+        assert_eq!(internal_parse("a = \"abc\""), expected);
+        assert_eq!(internal_parse("a == \"abc\""), expected);
     }
 
     #[test]
     fn t_filterparser_disallows_nul_byte() {
-        assert!(parse("attri\0bute = 0").is_err());
-        assert!(parse("attribute\0= 0").is_err());
-        assert!(parse("attribute = \0").is_err());
-        assert!(parse("attribute = \\\"\0\\\"").is_err());
+        assert!(internal_parse("attri\0bute = 0").is_err());
+        assert!(internal_parse("attribute\0= 0").is_err());
+        assert!(internal_parse("attribute = \0").is_err());
+        assert!(internal_parse("attribute = \\\"\0\\\"").is_err());
 
         // Unlike the C++ implementation, Rust is OK with having NUL inside a string literal. In
-        // C++, it terminates the whole expression and implicitly closes the string literal
+        // C++, it terminates the whole expression and implicitly closes the string literal. When
+        // calling Rust through C FFI, we'll automatically get the C behaviour since we're passing
+        // the input as `const char*` without specifying its length.
         assert_eq!(
-            parse("attribute = \"hello\0world\""),
+            internal_parse("attribute = \"hello\0world\""),
             Ok(Expression::Comparison {
                 attribute: "attribute".to_string(),
                 op: Operator::Equals,
-                value: Value::Str("hello\0world".to_string()),
+                value: Value("hello\0world".to_string()),
             })
         );
     }
@@ -316,58 +414,58 @@ mod tests {
         let expected = Ok(Expression::Comparison {
             attribute: "title".to_string(),
             op: Operator::Equals,
-            value: Value::Str(String::new()),
+            value: Value(String::new()),
         });
 
-        assert_eq!(parse("title==\"\""), expected);
+        assert_eq!(internal_parse("title==\"\""), expected);
     }
 
     #[test]
     fn t_and_operator_requires_space_or_paren_after_it() {
-        assert!(parse("a=42andy=0").is_err());
-        assert!(parse("(a=42)andy=0").is_err());
-        assert!(parse("a=42 andy=0").is_err());
+        assert!(internal_parse("a=42andy=0").is_err());
+        assert!(internal_parse("(a=42)andy=0").is_err());
+        assert!(internal_parse("a=42 andy=0").is_err());
 
         let expected_tree = And(
             Box::new(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::Equals,
-                value: Value::Int(42),
+                value: Value("42".to_string()),
             }),
             Box::new(Comparison {
                 attribute: "y".to_string(),
                 op: Operator::Equals,
-                value: Value::Int(0),
+                value: Value("0".to_string()),
             }),
         );
 
-        assert_eq!(parse("a=42and(y=0)"), Ok(expected_tree.clone()));
-        assert_eq!(parse("(a=42)and(y=0)"), Ok(expected_tree.clone()));
-        assert_eq!(parse("a=42and y=0"), Ok(expected_tree));
+        assert_eq!(internal_parse("a=42and(y=0)"), Ok(expected_tree.clone()));
+        assert_eq!(internal_parse("(a=42)and(y=0)"), Ok(expected_tree.clone()));
+        assert_eq!(internal_parse("a=42and y=0"), Ok(expected_tree));
     }
 
     #[test]
     fn t_or_operator_requires_space_or_paren_after_it() {
-        assert!(parse("a=42ory=0").is_err());
-        assert!(parse("(a=42)ory=0").is_err());
-        assert!(parse("a=42 ory=0").is_err());
+        assert!(internal_parse("a=42ory=0").is_err());
+        assert!(internal_parse("(a=42)ory=0").is_err());
+        assert!(internal_parse("a=42 ory=0").is_err());
 
         let expected_tree = Or(
             Box::new(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::Equals,
-                value: Value::Int(42),
+                value: Value("42".to_string()),
             }),
             Box::new(Comparison {
                 attribute: "y".to_string(),
                 op: Operator::Equals,
-                value: Value::Int(0),
+                value: Value("0".to_string()),
             }),
         );
 
-        assert_eq!(parse("a=42or(y=0)"), Ok(expected_tree.clone()));
-        assert_eq!(parse("(a=42)or(y=0)"), Ok(expected_tree.clone()));
-        assert_eq!(parse("a=42or y=0"), Ok(expected_tree));
+        assert_eq!(internal_parse("a=42or(y=0)"), Ok(expected_tree.clone()));
+        assert_eq!(internal_parse("(a=42)or(y=0)"), Ok(expected_tree.clone()));
+        assert_eq!(internal_parse("a=42or y=0"), Ok(expected_tree));
     }
 
     #[test]
@@ -375,79 +473,91 @@ mod tests {
         let expected = Comparison {
             attribute: "array".to_string(),
             op: Operator::Contains,
-            value: Value::Str("bar".to_string()),
+            value: Value("bar".to_string()),
         };
 
-        assert_eq!(parse("array # \"bar\""), Ok(expected.clone()));
-        assert_eq!(parse("   array # \"bar\""), Ok(expected.clone()));
-        assert_eq!(parse("array   # \"bar\""), Ok(expected.clone()));
-        assert_eq!(parse("array #   \"bar\""), Ok(expected.clone()));
-        assert_eq!(parse("array # \"bar\"     "), Ok(expected.clone()));
-        assert_eq!(parse("array#  \"bar\"  "), Ok(expected.clone()));
+        assert_eq!(internal_parse("array # \"bar\""), Ok(expected.clone()));
+        assert_eq!(internal_parse("   array # \"bar\""), Ok(expected.clone()));
+        assert_eq!(internal_parse("array   # \"bar\""), Ok(expected.clone()));
+        assert_eq!(internal_parse("array #   \"bar\""), Ok(expected.clone()));
+        assert_eq!(internal_parse("array # \"bar\"     "), Ok(expected.clone()));
+        assert_eq!(internal_parse("array#  \"bar\"  "), Ok(expected.clone()));
         assert_eq!(
-            parse("     array         #         \"bar\"      "),
+            internal_parse("     array         #         \"bar\"      "),
             Ok(expected)
         );
     }
 
     #[test]
     fn t_only_space_characters_are_considered_whitespace_by_filter_parser() {
-        assert_eq!(parse("attr\t= \"value\""), Err(Error::AtPos(4)));
-        assert_eq!(parse("attr =\t\"value\""), Err(Error::AtPos(6)));
-        assert_eq!(parse("attr\n=\t\"value\""), Err(Error::AtPos(4)));
-        assert_eq!(parse("attr\u{b}=\"value\""), Err(Error::AtPos(4)));
         assert_eq!(
-            parse("attr=\"value\"\r\n"),
-            Err(Error::TrailingCharacters("\r\n"))
+            internal_parse("attr\t= \"value\""),
+            Err(Error::AtPos(4, EXPECTED_OPERATORS))
+        );
+        assert_eq!(
+            internal_parse("attr =\t\"value\""),
+            Err(Error::AtPos(6, EXPECTED_VALUE))
+        );
+        assert_eq!(
+            internal_parse("attr\n=\t\"value\""),
+            Err(Error::AtPos(4, EXPECTED_OPERATORS))
+        );
+        assert_eq!(
+            internal_parse("attr\u{b}=\"value\""),
+            Err(Error::AtPos(4, EXPECTED_OPERATORS))
+        );
+        assert_eq!(
+            internal_parse("attr=\"value\"\r\n"),
+            Err(Error::TrailingCharacters(12, "\r\n"))
         );
     }
 
     #[test]
     fn t_whitespace_before_and_or_operators_is_not_required() {
         assert_eq!(
-            parse("x = 42and y=0"),
+            internal_parse("x = 42and y=0"),
             Ok(And(
                 Box::new(Comparison {
                     attribute: "x".to_string(),
                     op: Operator::Equals,
-                    value: Value::Int(42)
+                    value: Value("42".to_string())
                 }),
                 Box::new(Comparison {
                     attribute: "y".to_string(),
                     op: Operator::Equals,
-                    value: Value::Int(0)
+                    value: Value("0".to_string())
                 })
             ))
         );
 
         assert_eq!(
-            parse("x = \"42\"and y=0"),
+            internal_parse("x = \"42\"and y=0"),
             Ok(And(
                 Box::new(Comparison {
                     attribute: "x".to_string(),
                     op: Operator::Equals,
-                    value: Value::Str("42".to_string())
+                    value: Value("42".to_string())
                 }),
                 Box::new(Comparison {
                     attribute: "y".to_string(),
                     op: Operator::Equals,
-                    value: Value::Int(0)
+                    value: Value("0".to_string())
                 })
             ))
         );
 
         assert_eq!(
-            parse("x = \"42\"or y=42"),
+            internal_parse("x = \"42\"or y=42"),
             Ok(Or(
                 Box::new(Comparison {
                     attribute: "x".to_string(),
                     op: Operator::Equals,
-                    value: Value::Str("42".to_string())
+                    value: Value("42".to_string())
                 }),
                 Box::new(Comparison {
                     attribute: "y".to_string(),
                     op: Operator::Equals,
-                    value: Value::Int(42)
+                    value: Value("42".to_string())
                 })
             ))
         );
@@ -458,130 +568,130 @@ mod tests {
     #[test]
     fn t_parses_simple_queries() {
         assert_eq!(
-            parse("a = \"b\""),
+            internal_parse("a = \"b\""),
             Ok(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::Equals,
-                value: Value::Str("b".to_string())
+                value: Value("b".to_string())
             })
         );
 
         assert_eq!(
-            parse("(a!=\"b\")"),
+            internal_parse("(a!=\"b\")"),
             Ok(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::NotEquals,
-                value: Value::Str("b".to_string())
+                value: Value("b".to_string())
             })
         );
 
         assert_eq!(
-            parse("((a=~\"b\"))"),
+            internal_parse("((a=~\"b\"))"),
             Ok(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::RegexMatches,
-                value: Value::Str("b".to_string())
+                value: Value("b".to_string())
             })
         );
 
         assert_eq!(
-            parse("a !~ \"b\""),
+            internal_parse("a !~ \"b\""),
             Ok(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::NotRegexMatches,
-                value: Value::Str("b".to_string())
+                value: Value("b".to_string())
             })
         );
 
         // This is nonsensical, but it's a syntactically valid expression, so we parse it. Matcher
         // will sort it out during evaluation.
         assert_eq!(
-            parse("a < \"b\""),
+            internal_parse("a < \"b\""),
             Ok(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::LessThan,
-                value: Value::Str("b".to_string())
+                value: Value("b".to_string())
             })
         );
 
         assert_eq!(
-            parse("a <= \"b\""),
+            internal_parse("a <= \"b\""),
             Ok(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::LessThanOrEquals,
-                value: Value::Str("b".to_string())
+                value: Value("b".to_string())
             })
         );
 
         assert_eq!(
-            parse("a > \"abc\""),
+            internal_parse("a > \"abc\""),
             Ok(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::GreaterThan,
-                value: Value::Str("abc".to_string())
+                value: Value("abc".to_string())
             })
         );
 
         assert_eq!(
-            parse("a == \"abc\""),
+            internal_parse("a == \"abc\""),
             Ok(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::Equals,
-                value: Value::Str("abc".to_string())
+                value: Value("abc".to_string())
             })
         );
 
         assert_eq!(
-            parse("a >= 3"),
+            internal_parse("a >= 3"),
             Ok(Comparison {
                 attribute: "a".to_string(),
                 op: Operator::GreaterThanOrEquals,
-                value: Value::Int(3)
+                value: Value("3".to_string())
             })
         );
 
         assert_eq!(
-            parse("some_value between 0:-1"),
+            internal_parse("some_value between 0:-1"),
             Ok(Comparison {
                 attribute: "some_value".to_string(),
                 op: Operator::Between,
-                value: Value::Range(0, -1)
+                value: Value("0:-1".to_string())
             })
         );
 
         assert_eq!(
-            parse("other_string between \"impossible\""),
+            internal_parse("other_string between \"impossible\""),
             Ok(Comparison {
                 attribute: "other_string".to_string(),
                 op: Operator::Between,
-                value: Value::Str("impossible".to_string())
+                value: Value("impossible".to_string())
             })
         );
 
         assert_eq!(
-            parse("array # \"name\""),
+            internal_parse("array # \"name\""),
             Ok(Comparison {
                 attribute: "array".to_string(),
                 op: Operator::Contains,
-                value: Value::Str("name".to_string())
+                value: Value("name".to_string())
             })
         );
 
         assert_eq!(
-            parse("answers !# 42"),
+            internal_parse("answers !# 42"),
             Ok(Comparison {
                 attribute: "answers".to_string(),
                 op: Operator::NotContains,
-                value: Value::Int(42)
+                value: Value("42".to_string())
             })
         );
 
         assert_eq!(
-            parse("author =~ \"\\s*Doe$\""),
+            internal_parse("author =~ \"\\s*Doe$\""),
             Ok(Comparison {
                 attribute: "author".to_string(),
                 op: Operator::RegexMatches,
-                value: Value::Str("\\s*Doe$".to_string())
+                value: Value("\\s*Doe$".to_string())
             })
         );
     }
@@ -589,248 +699,105 @@ mod tests {
     #[test]
     fn t_parses_complex_queries() {
         assert_eq!(
-            parse("a = \"b\" and b = \"c\" or c = \"d\"").unwrap(),
+            internal_parse("a = \"b\" and b = \"c\" or c = \"d\"").unwrap(),
             And(
                 Box::new(Comparison {
                     attribute: "a".to_string(),
                     op: Operator::Equals,
-                    value: Value::Str("b".to_string())
+                    value: Value("b".to_string())
                 }),
                 Box::new(Or(
                     Box::new(Comparison {
                         attribute: "b".to_string(),
                         op: Operator::Equals,
-                        value: Value::Str("c".to_string())
+                        value: Value("c".to_string())
                     }),
                     Box::new(Comparison {
                         attribute: "c".to_string(),
                         op: Operator::Equals,
-                        value: Value::Str("d".to_string())
+                        value: Value("d".to_string())
                     }),
                 ))
             )
         );
 
         assert_eq!(
-            parse("a = \"b\" or b = \"c\" and c = \"d\"").unwrap(),
+            internal_parse("a = \"b\" or b = \"c\" and c = \"d\"").unwrap(),
             Or(
                 Box::new(Comparison {
                     attribute: "a".to_string(),
                     op: Operator::Equals,
-                    value: Value::Str("b".to_string())
+                    value: Value("b".to_string())
                 }),
                 Box::new(And(
                     Box::new(Comparison {
                         attribute: "b".to_string(),
                         op: Operator::Equals,
-                        value: Value::Str("c".to_string())
+                        value: Value("c".to_string())
                     }),
                     Box::new(Comparison {
                         attribute: "c".to_string(),
                         op: Operator::Equals,
-                        value: Value::Str("d".to_string())
+                        value: Value("d".to_string())
                     }),
                 ))
             )
         );
 
         assert_eq!(
-            parse("(a = \"b\" or b = \"c\") and c = \"d\"").unwrap(),
+            internal_parse("(a = \"b\" or b = \"c\") and c = \"d\"").unwrap(),
             And(
                 Box::new(Or(
                     Box::new(Comparison {
                         attribute: "a".to_string(),
                         op: Operator::Equals,
-                        value: Value::Str("b".to_string())
+                        value: Value("b".to_string())
                     }),
                     Box::new(Comparison {
                         attribute: "b".to_string(),
                         op: Operator::Equals,
-                        value: Value::Str("c".to_string())
+                        value: Value("c".to_string())
                     }),
                 )),
                 Box::new(Comparison {
                     attribute: "c".to_string(),
                     op: Operator::Equals,
-                    value: Value::Str("d".to_string())
+                    value: Value("d".to_string())
                 })
             )
         );
 
-        assert!(parse(
+        assert!(internal_parse(
             "( a = \"b\") and ( b = \"c\" ) or ( ( c != \"d\" ) and ( c !~ \"asdf\" )) or c != \"xx\""
         ).is_ok());
     }
 
-    #[test]
-    fn t_only_i32_numbers_are_parsed() {
-        assert_eq!(
-            parse("a = 0"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(0)
-            })
-        );
-
-        assert_eq!(
-            parse("a = 127"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(127)
-            })
-        );
-
-        assert_eq!(
-            parse("a = -128"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(-128)
-            })
-        );
-
-        assert_eq!(
-            parse("a = 128"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(128)
-            })
-        );
-
-        assert_eq!(
-            parse("a = -129"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(-129)
-            })
-        );
-
-        assert_eq!(
-            parse("a = 255"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(255)
-            })
-        );
-
-        assert_eq!(
-            parse("a = 256"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(256)
-            })
-        );
-
-        assert_eq!(
-            parse("a = 32767"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(32767)
-            })
-        );
-
-        assert_eq!(
-            parse("a = -32768"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(-32768)
-            })
-        );
-
-        assert_eq!(
-            parse("a = 32768"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(32768)
-            })
-        );
-
-        assert_eq!(
-            parse("a = -32769"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(-32769)
-            })
-        );
-
-        assert_eq!(
-            parse("a = 65535"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(65535)
-            })
-        );
-
-        assert_eq!(
-            parse("a = 65536"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(65536)
-            })
-        );
-
-        assert_eq!(
-            parse("a = 2147483647"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(2147483647)
-            })
-        );
-
-        assert_eq!(
-            parse("a = -2147483648"),
-            Ok(Comparison {
-                attribute: "a".to_string(),
-                op: Operator::Equals,
-                value: Value::Int(-2147483648)
-            })
-        );
-
-        assert_eq!(parse("a = 2147483648"), Err(Error::AtPos(4)));
-        assert_eq!(parse("a = -2147483649"), Err(Error::AtPos(4)));
-        assert_eq!(parse("abba = -9999999999999"), Err(Error::AtPos(7)));
-        assert_eq!(parse("another = 98979695999999999"), Err(Error::AtPos(10)));
-    }
-
     #[test]
     fn t_ranges_accept_negative_numbers() {
         assert_eq!(
-            parse("value between -100:-1"),
+            internal_parse("value between -100:-1"),
             Ok(Comparison {
                 attribute: "value".to_string(),
                 op: Operator::Between,
-                value: Value::Range(-100, -1)
+                value: Value("-100:-1".to_string())
             })
         );
 
         assert_eq!(
-            parse("value between -100:100500"),
+            internal_parse("value between -100:100500"),
             Ok(Comparison {
                 attribute: "value".to_string(),
                 op: Operator::Between,
-                value: Value::Range(-100, 100500)
+                value: Value("-100:100500".to_string())
             })
         );
 
         assert_eq!(
-            parse("value between 123:-10"),
+            internal_parse("value between 123:-10"),
             Ok(Comparison {
                 attribute: "value".to_string(),
                 op: Operator::Between,
-                value: Value::Range(123, -10)
+                value: Value("123:-10".to_string())
             })
         );
     }
@@ -839,17 +806,17 @@ mod tests {
         #[test]
         fn does_not_crash_on_any_input(ref input in "\\PC*") {
             // Result explicitly ignored because we just want to make sure this call doesn't panic.
-            let _ = parse(&input);
+            let _ = internal_parse(&input);
         }
 
         #[test]
         fn whitespace_doesnt_affect_results_1(ref input in r#" *a *!= *"b" *"#) {
             assert_eq!(
-                parse(&input),
+                internal_parse(&input),
                 Ok(Comparison {
                     attribute: "a".to_string(),
                     op: Operator::NotEquals,
-                    value: Value::Str("b".to_string())
+                    value: Value("b".to_string())
                 })
             );
         }
@@ -857,11 +824,11 @@ mod tests {
         #[test]
         fn whitespace_doesnt_affect_results_2(ref input in r#" *( *a *!= *"b" *) *"#) {
             assert_eq!(
-                parse(&input),
+                internal_parse(&input),
                 Ok(Comparison {
                     attribute: "a".to_string(),
                     op: Operator::NotEquals,
-                    value: Value::Str("b".to_string())
+                    value: Value("b".to_string())
                 })
             );
         }
@@ -869,8 +836,15 @@ mod tests {
         #[test]
         fn attribute_names_can_contain_alphanumerics_underscore_dash_and_dot(ref input in r#"[-A-Za-z0-9_.]+ == 0"#) {
             assert!(
-                parse(&input).is_ok(),
+                internal_parse(&input).is_ok(),
             );
         }
+
+        #[test]
+        fn no_internal_parsing_errors(ref input in "\\PC*") {
+            // We should return either a parsed expression or a descriptive error -- never
+            // a nondescript "internal error".
+            assert_ne!(internal_parse(&input), Err(Error::Internal));
+        }
     }
 }
