@@ -98,7 +98,7 @@ impl FmtStrFormatter {
         result.push_str(&rest);
     }
 
-    fn format_format(&self, c: char, padding: &Padding, _width: u32, result: &mut LimitedString) {
+    fn format_format(&self, c: char, padding: &Padding, width: u32, result: &mut LimitedString) {
         let empty_string = String::new();
         let value = self.fmts.get(&c).unwrap_or_else(|| &empty_string);
         match *padding {
@@ -119,6 +119,27 @@ impl FmtStrFormatter {
                 result.push_str(text);
                 result.push_str(&padding);
             }
+
+            Padding::Center(total_width) => {
+                let w = if total_width == 0 {
+                    width as usize
+                } else {
+                    total_width
+                };
+                let text = &utils::substr_with_width(value, w);
+                let padding_width = w - utils::strwidth(text);
+                if padding_width > 0 {
+                    let left: usize = padding_width / 2;
+                    let right: usize = padding_width - left;
+                    let padding_l = String::from(" ").repeat(left);
+                    let padding_r = String::from(" ").repeat(right);
+                    result.push_str(&padding_l);
+                    result.push_str(text);
+                    result.push_str(&padding_r);
+                } else {
+                    result.push_str(text);
+                }
+            }
         }
     }
 
@@ -190,6 +211,16 @@ impl FmtStrFormatter {
 mod tests {
     use super::*;
 
+    #[test]
+    fn t_do_format_center() {
+        let mut fmt = FmtStrFormatter::new();
+        fmt.register_fmt('T', "whatever".to_string());
+        assert_eq!(fmt.do_format("%=20T", 0), "      whatever      ");
+        assert_eq!(fmt.do_format("%=19T", 0), "     whatever      ");
+        assert_eq!(fmt.do_format("%=3T", 0), "wha");
+        assert_eq!(fmt.do_format("%=0T", 20), "      whatever      ");
+    }
+
     #[test]
     fn t_do_format_replaces_variables_with_values_one_variable() {
         let mut fmt = FmtStrFormatter::new();
