@@ -2,6 +2,7 @@ use nom::branch::alt;
 use nom::bytes::complete::{tag, take, take_till1, take_while};
 use nom::multi::many0;
 use nom::IResult;
+use std::cmp::Ordering;
 use std::str;
 
 /// Describes how formats should be padded: on the left, on the right, or not at all.
@@ -13,6 +14,8 @@ pub enum Padding {
     Left(usize),
     /// Pad the value on the right until it reaches specified width.
     Right(usize),
+    /// Pad the value on the left and right equally until it reaches specified width.
+    Center(usize),
 }
 
 /// Describes all the different "format specifiers" we support, plus a chunk of text that would be
@@ -45,6 +48,18 @@ fn spacing(input: &str) -> IResult<&str, Specifier> {
     Ok((input, Specifier::Spacing(chr)))
 }
 
+fn center_format(input: &str) -> IResult<&str, Specifier> {
+    let (input, _) = tag("%=")(input)?;
+    let (input, width) = take_while(|chr: char| chr.is_ascii() && (chr.is_numeric()))(input)?;
+    let (input, format) = take(1usize)(input)?;
+
+    // unwrap() won't fail because parser uses take!(1) to get exactly one character
+    let format = format.chars().next().unwrap();
+    let width = width.parse::<usize>().unwrap_or(0);
+
+    Ok((input, Specifier::Format(format, Padding::Center(width))))
+}
+
 fn padded_format(input: &str) -> IResult<&str, Specifier> {
     let (input, _) = tag("%")(input)?;
     let (input, width) =
@@ -55,12 +70,10 @@ fn padded_format(input: &str) -> IResult<&str, Specifier> {
     let format = format.chars().next().unwrap();
 
     let width = width.parse::<isize>().unwrap_or(0);
-    let padding = if width == 0isize {
-        Padding::None
-    } else if width > 0isize {
-        Padding::Left(width.abs() as usize)
-    } else {
-        Padding::Right(width.abs() as usize)
+    let padding = match width.cmp(&0isize) {
+        Ordering::Equal => Padding::None,
+        Ordering::Greater => Padding::Left(width.abs() as usize),
+        Ordering::Less => Padding::Right(width.abs() as usize),
     };
 
     Ok((input, Specifier::Format(format, padding)))
@@ -116,6 +129,7 @@ fn conditional_branch(input: &str) -> IResult<&str, Vec<Specifier>> {
     let alternatives = (
         escaped_percent_sign,
         spacing,
+        center_format,
         padded_format,
         text_inside_conditional,
     );
@@ -127,6 +141,7 @@ fn parser(input: &str) -> IResult<&str, Vec<Specifier>> {
         conditional,
         escaped_percent_sign,
         spacing,
+        center_format,
         padded_format,
         text_outside_conditional,
     );
