@@ -20,15 +20,9 @@ impl Matcher {
     /// Prepare a `Matcher` that will check items against the filter expression provided in
     /// `input`.
     ///
-    /// If `input` can't be parsed, returns a user-readable error.
+    /// If `input` can't be parsed, returns an internalized error message.
     pub fn parse(input: &str) -> Result<Matcher, String> {
-        let expr = filterparser::parse(input).map_err(|e| match e {
-            filterparser::Error::TrailingCharacters(tail) => {
-                format!("Parse error: trailing characters: {}", tail)
-            }
-            filterparser::Error::AtPos(pos) => format!("Parse error at position {}", pos),
-        })?;
-
+        let expr = filterparser::parse(input)?;
         Ok(Matcher {
             expr,
             text: input.to_string(),
@@ -49,90 +43,89 @@ impl Matcher {
 impl Operator {
     fn apply(&self, attr: &str, value: &Value) -> Result<bool, MatcherError> {
         match self {
-            Operator::Equals => match value {
-                Value::Str(ref s) => Ok(attr == s),
-                Value::Int(i) => match attr.parse::<i32>() {
-                    Ok(attr) => Ok(attr == *i),
-                    _ => Ok(false),
-                },
-                _ => Ok(false),
-            },
-            Operator::NotEquals => Operator::Equals
-                .apply(attr, value)
-                .and_then(|result| Ok(!result)),
-            Operator::RegexMatches => match value {
-                Value::Str(ref pattern) => {
-                    match Regex::new(
-                        pattern,
-                        CompFlags::EXTENDED | CompFlags::IGNORE_CASE | CompFlags::NO_SUB,
-                    ) {
-                        Ok(regex) => {
-                            let mut result = false;
-                            let max_matches = 1;
-                            if let Ok(matches) =
-                                regex.matches(attr, max_matches, MatchFlags::empty())
-                            {
-                                // Ok with non-empty Vec inside means a match was found
-                                result = !matches.is_empty();
-                            }
-                            Ok(result)
-                        }
-
-                        Err(errmsg) => Err(MatcherError::InvalidRegex {
-                            regex: pattern.clone(),
-                            errmsg,
-                        }),
+            Operator::Equals => Ok(attr == value.0),
+            Operator::NotEquals => Operator::Equals.apply(attr, value).map(|result| !result),
+            Operator::RegexMatches => match Regex::new(
+                &value.0,
+                CompFlags::EXTENDED | CompFlags::IGNORE_CASE | CompFlags::NO_SUB,
+            ) {
+                Ok(regex) => {
+                    let mut result = false;
+                    let max_matches = 1;
+                    if let Ok(matches) = regex.matches(attr, max_matches, MatchFlags::empty()) {
+                        // Ok with non-empty Vec inside means a match was found
+                        result = !matches.is_empty();
                     }
+                    Ok(result)
                 }
-                _ => Ok(false),
+
+                Err(errmsg) => Err(MatcherError::InvalidRegex {
+                    regex: value.0.clone(),
+                    errmsg,
+                }),
             },
             Operator::NotRegexMatches => Operator::RegexMatches
                 .apply(attr, value)
-                .and_then(|result| Ok(!result)),
-            Operator::LessThan => match value {
-                Value::Int(i) => Ok(attr.parse::<i32>().unwrap() < *i),
-                _ => Ok(false),
-            },
-            Operator::GreaterThan => match value {
-                Value::Int(i) => Ok(attr.parse::<i32>().unwrap() > *i),
-                _ => Ok(true),
-            },
-            Operator::LessThanOrEquals => match value {
-                Value::Int(i) => Ok(attr.parse::<i32>().unwrap() <= *i),
-                _ => Ok(false),
-            },
-            Operator::GreaterThanOrEquals => match value {
-                Value::Int(i) => Ok(attr.parse::<i32>().unwrap() >= *i),
-                _ => Ok(true),
-            },
-            Operator::Between => match value {
-                Value::Range(a, b) => {
-                    let low = std::cmp::min(*a, *b);
-                    let high = std::cmp::max(*a, *b);
-                    let i = attr.parse::<i32>().unwrap();
-                    Ok(i >= low && i <= high)
-                }
-                _ => Ok(false),
-            },
-            Operator::Contains => match value {
-                Value::Int(i) => self.apply(attr, &Value::Str(format!("{}", i))),
-                Value::Str(ref s) => {
-                    for token in attr.split(" ") {
-                        if token == s {
-                            return Ok(true);
-                        }
-                    }
+                .map(|result| !result),
+            Operator::LessThan => Ok(string_to_num(attr) < string_to_num(&value.0)),
+            Operator::GreaterThan => Ok(dbg!(string_to_num(attr)) > dbg!(string_to_num(&value.0))),
+            Operator::LessThanOrEquals => Ok(string_to_num(attr) <= string_to_num(&value.0)),
+            Operator::GreaterThanOrEquals => Ok(string_to_num(attr) >= string_to_num(&value.0)),
+            Operator::Between => {
+                let fields = value.0.split(':').collect::<Vec<_>>();
+                if fields.len() != 2 {
                     return Ok(false);
                 }
-                _ => Ok(false),
-            },
-            Operator::NotContains => Operator::Contains
-                .apply(attr, value)
-                .and_then(|result| Ok(!result)),
+
+                let a = string_to_num(fields[0]);
+                let b = string_to_num(fields[1]);
+
+                let low = std::cmp::min(a, b);
+                let high = std::cmp::max(a, b);
+                let i = string_to_num(attr);
+                Ok(i >= low && i <= high)
+            }
+            Operator::Contains => {
+                for token in attr.split(' ') {
+                    if token == value.0 {
+                        return Ok(true);
+                    }
+                }
+                Ok(false)
+            }
+            Operator::NotContains => Operator::Contains.apply(attr, value).map(|result| !result),
         }
     }
 }
 
+/// Convert numerical prefix of the string to i32.
+///
+/// Return 0 if there is no numeric prefix. On underflow, return `std::i32::MIN`. On overflow,
+/// return `std::i32::MAX`.
+fn string_to_num(input: &str) -> i32 {
+    let search_start = if input.starts_with('-') { 1 } else { 0 };
+
+    let numerics_end = input[search_start..]
+        .find(|c: char| !c.is_numeric())
+        .unwrap_or_else(|| input.len())
+        + search_start; // Adding the starting offset to get an index inside the original input
+
+    if numerics_end - search_start == 0 {
+        // No numeric prefix
+        return 0;
+    }
+
+    if let Ok(number) = input[..numerics_end].parse::<i32>() {
+        number
+    } else if search_start == 1 {
+        // Number starts with minus and couldn't be parsed => underflow
+        std::i32::MIN
+    } else {
+        // Number doesn't start with minus and couldn't be parsed => overflow
+        std::i32::MAX
+    }
+}
+
 fn evaluate_expression(expr: &Expression, item: &impl Matchable) -> Result<bool, MatcherError> {
     match expr {
         Comparison {
@@ -140,11 +133,9 @@ fn evaluate_expression(expr: &Expression, item: &impl Matchable) -> Result<bool,
             op,
             value,
         } => match item.attribute_value(&attribute) {
-            None => {
-                return Err(MatcherError::AttributeUnavailable {
-                    attr: attribute.clone(),
-                })
-            }
+            None => Err(MatcherError::AttributeUnavailable {
+                attr: attribute.clone(),
+            }),
 
             Some(ref attr) => op.apply(attr, &value),
         },
@@ -179,7 +170,7 @@ mod tests {
         pub fn new(values: &[(&str, &str)]) -> MockMatchable {
             MockMatchable {
                 values: values
-                    .into_iter()
+                    .iter()
                     .map(|(a, b)| (String::from(*a), String::from(*b)))
                     .collect::<BTreeMap<_, _>>(),
             }
@@ -212,7 +203,7 @@ mod tests {
             .unwrap()
             .matches(&mock)
             .unwrap());
-        assert!(Matcher::parse("answer = 0042")
+        assert!(!Matcher::parse("answer = 0042")
             .unwrap()
             .matches(&mock)
             .unwrap());
@@ -221,7 +212,7 @@ mod tests {
             .matches(&mock)
             .unwrap());
 
-        assert!(Matcher::parse("agent = 7").unwrap().matches(&mock).unwrap());
+        assert!(!Matcher::parse("agent = 7").unwrap().matches(&mock).unwrap());
         assert!(Matcher::parse("agent = 007")
             .unwrap()
             .matches(&mock)
@@ -274,7 +265,7 @@ mod tests {
             .matches(&mock)
             .unwrap());
 
-        assert!(!Matcher::parse("agent != 7")
+        assert!(Matcher::parse("agent != 7")
             .unwrap()
             .matches(&mock)
             .unwrap());
@@ -336,15 +327,15 @@ mod tests {
     }
 
     #[test]
-    fn t_test_regex_match_doesnt_work_with_numbers() {
+    fn t_test_regex_match_converts_numbers_to_strings_and_uses_them_as_regexes() {
         let mock = MockMatchable::new(&[("AAAA", "12345")]);
 
-        assert!(!Matcher::parse("AAAA =~ 12345")
+        assert!(Matcher::parse("AAAA =~ 12345")
             .unwrap()
             .matches(&mock)
             .unwrap());
-        assert!(!Matcher::parse("AAAA =~ 1").unwrap().matches(&mock).unwrap());
-        assert!(!Matcher::parse("AAAA =~ 45")
+        assert!(Matcher::parse("AAAA =~ 1").unwrap().matches(&mock).unwrap());
+        assert!(Matcher::parse("AAAA =~ 45")
             .unwrap()
             .matches(&mock)
             .unwrap());
@@ -352,7 +343,7 @@ mod tests {
     }
 
     #[test]
-    fn t_test_regex_match_doesnt_work_with_ranges() {
+    fn t_test_regex_match_treats_ranges_as_strings() {
         let mock = MockMatchable::new(&[("AAAA", "12345"), ("range", "0:123")]);
 
         assert!(!Matcher::parse("AAAA =~ 0:123456")
@@ -368,11 +359,11 @@ mod tests {
             .matches(&mock)
             .unwrap());
 
-        assert!(!Matcher::parse("range =~ 0:123")
+        assert!(Matcher::parse("range =~ 0:123")
             .unwrap()
             .matches(&mock)
             .unwrap());
-        assert!(!Matcher::parse("range =~ 0:12")
+        assert!(Matcher::parse("range =~ 0:12")
             .unwrap()
             .matches(&mock)
             .unwrap());
@@ -453,15 +444,15 @@ mod tests {
     }
 
     #[test]
-    fn t_test_not_regex_match_doesnt_work_with_numbers() {
+    fn t_test_not_regex_match_converts_numbers_into_strings_and_uses_them_as_regexes() {
         let mock = MockMatchable::new(&[("AAAA", "12345")]);
 
-        assert!(Matcher::parse("AAAA !~ 12345")
+        assert!(!Matcher::parse("AAAA !~ 12345")
             .unwrap()
             .matches(&mock)
             .unwrap());
-        assert!(Matcher::parse("AAAA !~ 1").unwrap().matches(&mock).unwrap());
-        assert!(Matcher::parse("AAAA !~ 45")
+        assert!(!Matcher::parse("AAAA !~ 1").unwrap().matches(&mock).unwrap());
+        assert!(!Matcher::parse("AAAA !~ 45")
             .unwrap()
             .matches(&mock)
             .unwrap());
@@ -679,7 +670,7 @@ mod tests {
     }
 
     #[test]
-    fn t_test_comparisons_dont_work_with_strings() {
+    fn t_test_comparisons_convert_string_arguments_to_numbers() {
         let mock = MockMatchable::new(&[("AAAA", "12345")]);
 
         assert!(Matcher::parse("AAAA > \"12344\"")
@@ -687,12 +678,12 @@ mod tests {
             .matches(&mock)
             .unwrap());
 
-        assert!(Matcher::parse("AAAA > \"12345\"")
+        assert!(!Matcher::parse("AAAA > \"12345\"")
             .unwrap()
             .matches(&mock)
             .unwrap());
 
-        assert!(Matcher::parse("AAAA > \"123456\"")
+        assert!(!Matcher::parse("AAAA > \"123456\"")
             .unwrap()
             .matches(&mock)
             .unwrap());
@@ -702,12 +693,12 @@ mod tests {
             .matches(&mock)
             .unwrap());
 
-        assert!(!Matcher::parse("AAAA < \"12346\"")
+        assert!(Matcher::parse("AAAA < \"12346\"")
             .unwrap()
             .matches(&mock)
             .unwrap());
 
-        assert!(!Matcher::parse("AAAA < \"123456\"")
+        assert!(Matcher::parse("AAAA < \"123456\"")
             .unwrap()
             .matches(&mock)
             .unwrap());
@@ -722,7 +713,7 @@ mod tests {
             .matches(&mock)
             .unwrap());
 
-        assert!(Matcher::parse("AAAA >= \"12346\"")
+        assert!(!Matcher::parse("AAAA >= \"12346\"")
             .unwrap()
             .matches(&mock)
             .unwrap());
@@ -732,12 +723,76 @@ mod tests {
             .matches(&mock)
             .unwrap());
 
-        assert!(!Matcher::parse("AAAA <= \"12345\"")
+        assert!(Matcher::parse("AAAA <= \"12345\"")
             .unwrap()
             .matches(&mock)
             .unwrap());
 
-        assert!(!Matcher::parse("AAAA <= \"12346\"")
+        assert!(Matcher::parse("AAAA <= \"12346\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+    }
+
+    #[test]
+    fn t_test_comparisons_use_numeric_prefix_of_the_string() {
+        let mock = MockMatchable::new(&[("AAAA", "12345xx")]);
+
+        assert!(Matcher::parse("AAAA >= \"12345\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(Matcher::parse("AAAA > \"1234a\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(!Matcher::parse("AAAA < \"12345a\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(!Matcher::parse("AAAA < \"1234a\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(!Matcher::parse("AAAA < \"9999b\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+    }
+
+    #[test]
+    fn t_test_comparisons_use_zero_if_string_cant_be_converted_to_number() {
+        let mock = MockMatchable::new(&[("zero", "0"), ("same_zero", "yeah")]);
+
+        assert!(!Matcher::parse("zero < \"unknown\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(!Matcher::parse("zero > \"unknown\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(Matcher::parse("zero <= \"unknown\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(Matcher::parse("zero >= \"unknown\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(!Matcher::parse("same_zero < \"0\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(!Matcher::parse("same_zero > \"0\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(Matcher::parse("same_zero <= \"0\"")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(Matcher::parse("same_zero >= \"0\"")
             .unwrap()
             .matches(&mock)
             .unwrap());
@@ -845,6 +900,28 @@ mod tests {
             .unwrap());
     }
 
+    #[test]
+    fn t_test_operator_between_converts_numeric_prefix_of_the_attribute() {
+        let mock = MockMatchable::new(&[("value", "123four"), ("practically_zero", "sure")]);
+
+        assert!(Matcher::parse("value between 122:124")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(!Matcher::parse("value between 124:130")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(Matcher::parse("practically_zero between 0:1")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+        assert!(!Matcher::parse("practically_zero between 1:100")
+            .unwrap()
+            .matches(&mock)
+            .unwrap());
+    }
+
     #[test]
     fn t_get_expression_method_returns_parsed_expression_as_string() {
         let expression = "AAAA between 1:30000";
@@ -969,4 +1046,27 @@ mod tests {
             .matches(&mock)
             .unwrap());
     }
+
+    #[test]
+    fn t_string_to_num_convers_numeric_prefix_to_i32() {
+        assert_eq!(string_to_num("7654"), 7654);
+        assert_eq!(string_to_num("123foo"), 123);
+        assert_eq!(string_to_num("-999999bar"), -999999);
+
+        assert_eq!(string_to_num("-2147483648min"), -2147483648);
+        assert_eq!(string_to_num("2147483647 is ok"), 2147483647);
+
+        // On under-/over-flow, returns min/max representable value
+        assert_eq!(
+            string_to_num("-2147483649 is too small for i32"),
+            -2147483648
+        );
+        assert_eq!(string_to_num("2147483648 is too large for i32"), 2147483647);
+    }
+
+    #[test]
+    fn t_string_to_num_returns_0_if_there_is_no_numeric_prefix() {
+        assert_eq!(string_to_num("hello"), 0);
+        assert_eq!(string_to_num(""), 0);
+    }
 }
