@@ -1,12 +1,14 @@
 use crate::htmlrenderer;
 use crate::logger::{self, Level};
-use libc::c_ulong;
+use libc::{c_ulong, close, execvp, exit, fork, waitpid};
 use percent_encoding::*;
+use std::ffi::CString;
 use std::fs::DirBuilder;
 use std::io::{self, Write};
 use std::os::unix::fs::DirBuilderExt;
 use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
+use std::ptr;
 use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
 use url::Url;
 
@@ -74,9 +76,20 @@ pub fn absolute_url(base_url: &str, link: &str) -> String {
         .to_owned()
 }
 
+/// Path to the home directory, if known. Doesn't work on Windows.
+#[cfg(not(target_os = "windows"))]
+pub fn home_dir() -> Option<PathBuf> {
+    // This function got deprecated because it examines HOME environment variable even on Windows,
+    // which is wrong. But Newsboat doesn't support Windows, so we're fine using that.
+    //
+    // Cf. https://github.com/rust-lang/rust/issues/28940
+    #[allow(deprecated)]
+    std::env::home_dir()
+}
+
 /// Replaces tilde (`~`) at the beginning of the path with the path to user's home directory.
 pub fn resolve_tilde(path: PathBuf) -> PathBuf {
-    if let (Some(home), Ok(suffix)) = (dirs::home_dir(), path.strip_prefix("~")) {
+    if let (Some(home), Ok(suffix)) = (home_dir(), path.strip_prefix("~")) {
         return home.join(suffix);
     }
 
@@ -377,19 +390,17 @@ pub fn substr_with_width_stfl(string: &str, max_width: usize) -> String {
                     tagbuf.clear();
                 }
             }
+        } else if c == '<' {
+            in_bracket = true;
+            tagbuf.push(c);
         } else {
-            if c == '<' {
-                in_bracket = true;
-                tagbuf.push(c);
-            } else {
-                // Control chars count as width 0
-                let w = UnicodeWidthChar::width(c).unwrap_or(0);
-                if width + w > max_width {
-                    break;
-                }
-                width += w;
-                result.push(c);
+            // Control chars count as width 0
+            let w = UnicodeWidthChar::width(c).unwrap_or(0);
+            if width + w > max_width {
+                break;
             }
+            width += w;
+            result.push(c);
         }
     }
     result
@@ -411,7 +422,8 @@ pub fn remove_soft_hyphens(text: &mut String) {
 ///
 /// 2. figuring out the `LinkType` for a particular enclosure, given its MIME type
 ///    (`utils::podcast_mime_to_link_type`).
-const PODCAST_MIME_TO_LINKTYPE: [(fn(&str) -> bool, htmlrenderer::LinkType); 2] = [
+type MimeMatcher = (fn(&str) -> bool, htmlrenderer::LinkType);
+const PODCAST_MIME_TO_LINKTYPE: [MimeMatcher; 2] = [
     (
         |mime| {
             // RFC 5334, section 10.1 says "historically, some implementations expect .ogg files to be
@@ -489,27 +501,61 @@ pub fn get_command_output(cmd: &str) -> String {
         .unwrap_or_else(|_| String::from(""))
 }
 
-// This function assumes that the user is not interested in command's output (not even errors on
-// stderr!), so it redirects everything to /dev/null.
+// This function assumes that the user is not interested in the command's output (not even errors
+// on stderr!), so it will close the spawned command's fds.
+// This used to be a simple std::process::Command::Spawn(), but this caused child processes to not
+// be reaped, hence the addition of double forking to this function.
+// Spawn() was replaced with a direct call to fork+execvp because it interacted badly with the
+// fork() call.
 pub fn run_command(cmd: &str, param: &str) {
-    let child = Command::new(cmd)
-        .arg(param)
-        // Prevent the command from blocking Newsboat by asking for input
-        .stdin(Stdio::null())
-        // Prevent the command from botching the screen by printing onto it.
-        .stdout(Stdio::null())
-        .stderr(Stdio::null())
-        .spawn();
-    if let Err(error) = child {
-        log!(
-            Level::Debug,
-            "utils::run_command: spawning a child for \"{}\" failed: {}",
-            cmd,
-            error
-        );
-    }
+    unsafe {
+        let forked_pid = fork();
 
-    // We deliberately *don't* wait for the child to finish.
+        match forked_pid {
+            -1 => {
+                // Parent process, fork failed.
+                log!(
+                    Level::Debug,
+                    "utils::run_command: failed to fork. Aborting run_command."
+                );
+                return;
+            }
+            0 => {
+                // Child process, continue and spawn the command.
+            }
+            _ => {
+                // Parent process, fork succeeded: reap child and return.
+                let mut status = 0;
+                if waitpid(forked_pid, &mut status, 0) == -1 {
+                    log!(Level::Debug, "utils::run_command: waitpid failed.");
+                }
+                return;
+            }
+        }
+
+        if fork() == 0 {
+            // Grand-child
+            match (CString::new(cmd), CString::new(param)) {
+                (Ok(c_cmd), Ok(c_param)) => {
+                    // close our fds to avoid clobbering the screen and exec the command
+                    close(0);
+                    close(1);
+                    close(2);
+                    let c_arg = [c_cmd.as_ptr(), c_param.as_ptr(), ptr::null()];
+                    execvp(c_cmd.as_ptr(), c_arg.as_ptr());
+                }
+                _ => log!(
+                    Level::UserError,
+                    "Conversion of \"{}\" and/or \"{}\" to CString failed.",
+                    cmd,
+                    param
+                ),
+            };
+        }
+
+        // Child process or grand child in case of failure to execvp, in both cases nothing to do.
+        exit(0);
+    }
 }
 
 pub fn run_program(cmd_with_args: &[&str], input: &str) -> String {
@@ -602,17 +648,21 @@ pub fn make_title(rs_str: String) -> String {
     }
 }
 
-/// Run the given command interactively with inherited stdin and stdout/stderr
+/// Run the given command interactively with inherited stdin and stdout/stderr. Return the lowest
+/// 8 bits of its exit code, or `None` if the command failed to start.
 /// ```
 /// use libnewsboat::utils::run_interactively;
 ///
 /// let result = run_interactively("echo true", "test");
-/// assert_eq!(result, 0);
+/// assert_eq!(result, Some(0));
 ///
 /// let result = run_interactively("exit 1", "test");
-/// assert_eq!(result, 1);
+/// assert_eq!(result, Some(1));
+///
+/// // Unfortunately, there is no easy way to provoke this function to return `None`, nor to test
+/// // that it returns just the lowest 8 bits.
 /// ```
-pub fn run_interactively(command: &str, caller: &str) -> i32 {
+pub fn run_interactively(command: &str, caller: &str) -> Option<u8> {
     log!(Level::Debug, &format!("{}: running `{}'", caller, command));
     Command::new("sh")
         .arg("-c")
@@ -626,8 +676,7 @@ pub fn run_interactively(command: &str, caller: &str) -> i32 {
         })
         .ok()
         .and_then(|exit_status| exit_status.code())
-        // return -1 if command got killed by signal
-        .unwrap_or(-1)
+        .map(|exit_code| exit_code as u8)
 }
 
 /// Get the current working directory.
@@ -711,24 +760,30 @@ pub fn strip_comments(line: &str) -> &str {
     let mut first_pound_chr_idx = line.len();
 
     for (idx, chr) in line.char_indices() {
-        if chr == '\\' {
-            prev_was_backslash = true;
-            continue;
-        } else if chr == '"' {
-            // If the quote is escaped or we're inside backticks, do nothing
-            if !prev_was_backslash && !inside_backticks {
-                inside_quotes = !inside_quotes;
+        match chr {
+            '\\' => {
+                prev_was_backslash = true;
+                continue;
             }
-        } else if chr == '`' {
-            // If the backtick is escaped, do nothing
-            if !prev_was_backslash {
-                inside_backticks = !inside_backticks;
+            '"' => {
+                // If the quote is escaped or we're inside backticks, do nothing
+                if !prev_was_backslash && !inside_backticks {
+                    inside_quotes = !inside_quotes;
+                }
             }
-        } else if chr == '#' {
-            if !prev_was_backslash && !inside_quotes && !inside_backticks {
-                first_pound_chr_idx = idx;
-                break;
+            '`' => {
+                // If the backtick is escaped, do nothing
+                if !prev_was_backslash {
+                    inside_backticks = !inside_backticks;
+                }
             }
+            '#' => {
+                if !prev_was_backslash && !inside_quotes && !inside_backticks {
+                    first_pound_chr_idx = idx;
+                    break;
+                }
+            }
+            _ => {}
         }
 
         // We call `continue` when we run into a backslash; here, we handle all the other
@@ -758,8 +813,6 @@ pub fn extract_filter(line: &str) -> (&str, &str) {
 
 #[cfg(test)]
 mod tests {
-    use tempfile;
-
     use super::*;
 
     #[test]
@@ -1129,13 +1182,13 @@ mod tests {
 
     #[test]
     fn t_unescape_url() {
-        assert!(unescape_url(String::from("foo%20bar")).unwrap() == String::from("foo bar"));
+        assert!(unescape_url(String::from("foo%20bar")).unwrap() == "foo bar");
         assert!(
             unescape_url(String::from(
                 "%21%23%24%26%27%28%29%2A%2B%2C%2F%3A%3B%3D%3F%40%5B%5D"
             ))
             .unwrap()
-                == String::from("!#$&'()*+,/:;=?@[]")
+                == "!#$&'()*+,/:;=?@[]"
         );
     }
 
