@@ -1,5 +1,5 @@
 use libnewsboat::cliargsparser::CliArgsParser;
-use std::{env, path::PathBuf};
+use std::env;
 use tempfile::TempDir;
 
 #[test]
@@ -13,15 +13,10 @@ fn t_cliargsparser_dash_c_resolves_tilde_to_homedir() {
 
     let check = |opts| {
         let args = CliArgsParser::new(opts);
-        assert_eq!(
-            args.cache_file,
-            Some(PathBuf::from(tmp.path().join(filename)))
-        );
+        assert_eq!(args.cache_file, Some(tmp.path().join(filename)));
         assert_eq!(
             args.lock_file,
-            Some(PathBuf::from(
-                tmp.path().join(filename.to_owned() + ".lock")
-            ))
+            Some(tmp.path().join(filename.to_owned() + ".lock"))
         );
     };
 
