@@ -1,5 +1,5 @@
 use libnewsboat::cliargsparser::CliArgsParser;
-use std::{env, path::PathBuf};
+use std::env;
 use tempfile::TempDir;
 
 #[test]
@@ -13,10 +13,7 @@ fn t_cliargsparser_dash_i_resolves_tilde_to_homedir() {
 
     let check = |opts| {
         let args = CliArgsParser::new(opts);
-        assert_eq!(
-            args.importfile,
-            Some(PathBuf::from(tmp.path().join(filename)))
-        );
+        assert_eq!(args.importfile, Some(tmp.path().join(filename)));
     };
 
     check(vec![
