@@ -20,7 +20,6 @@ using namespace podboat;
 namespace newsboat {
 
 ColorManager::ColorManager()
-	: colors_loaded_(false)
 {
 }
 
@@ -28,7 +27,7 @@ ColorManager::~ColorManager() {}
 
 void ColorManager::register_commands(ConfigParser& cfgparser)
 {
-	cfgparser.register_handler("color", this);
+	cfgparser.register_handler("color", *this);
 }
 
 void ColorManager::handle_action(const std::string& action,
@@ -74,10 +73,7 @@ void ColorManager::handle_action(const std::string& action,
 			element == "listfocus_unread" || element == "info" ||
 			element == "background" || element == "article" ||
 			element == "end-of-text-marker") {
-			fg_colors[element] = fgcolor;
-			bg_colors[element] = bgcolor;
-			attributes[element] = attribs;
-			colors_loaded_ = true;
+			element_styles[element] = {fgcolor, bgcolor, attribs};
 		} else
 			throw ConfigHandlerException(strprintf::fmt(
 					_("`%s' is not a valid configuration element"),
@@ -90,12 +86,14 @@ void ColorManager::handle_action(const std::string& action,
 
 void ColorManager::dump_config(std::vector<std::string>& config_output)
 {
-	for (const auto& color : fg_colors) {
+	for (const auto& element_style : element_styles) {
+		const std::string& element = element_style.first;
+		const TextStyle& style = element_style.second;
 		std::string configline = strprintf::fmt("color %s %s %s",
-				color.first,
-				color.second,
-				bg_colors[color.first]);
-		for (const auto& attrib : attributes[color.first]) {
+				element,
+				style.fg_color,
+				style.bg_color);
+		for (const auto& attrib : style.attributes) {
 			configline.append(" ");
 			configline.append(attrib);
 		}
@@ -103,30 +101,24 @@ void ColorManager::dump_config(std::vector<std::string>& config_output)
 	}
 }
 
-/*
- * this is podboat-specific color management
- * TODO: refactor this
- */
-void ColorManager::set_pb_colors(podboat::PbView* v)
+void ColorManager::apply_colors(Stfl::Form& form) const
 {
-	auto fgcit = fg_colors.begin();
-	auto bgcit = bg_colors.begin();
-	auto attit = attributes.begin();
-
-	for (; fgcit != fg_colors.end(); ++fgcit, ++bgcit, ++attit) {
+	for (const auto& element_style : element_styles) {
+		const std::string& element = element_style.first;
+		const TextStyle& style = element_style.second;
 		std::string colorattr;
-		if (fgcit->second != "default") {
+		if (style.fg_color != "default") {
 			colorattr.append("fg=");
-			colorattr.append(fgcit->second);
+			colorattr.append(style.fg_color);
 		}
-		if (bgcit->second != "default") {
+		if (style.bg_color != "default") {
 			if (colorattr.length() > 0) {
 				colorattr.append(",");
 			}
 			colorattr.append("bg=");
-			colorattr.append(bgcit->second);
+			colorattr.append(style.bg_color);
 		}
-		for (const auto& attr : attit->second) {
+		for (const auto& attr : style.attributes) {
 			if (colorattr.length() > 0) {
 				colorattr.append(",");
 			}
@@ -136,11 +128,27 @@ void ColorManager::set_pb_colors(podboat::PbView* v)
 
 		LOG(Level::DEBUG,
 			"ColorManager::set_pb_colors: %s %s\n",
-			fgcit->first,
+			element,
 			colorattr);
 
-		v->dllist_form.set(fgcit->first, colorattr);
-		v->help_form.set(fgcit->first, colorattr);
+		form.set(element, colorattr);
+
+		if (element == "article") {
+			std::string bold = colorattr;
+			std::string ul = colorattr;
+			if (bold.length() > 0) {
+				bold.append(",");
+			}
+			if (ul.length() > 0) {
+				ul.append(",");
+			}
+			bold.append("attr=bold");
+			ul.append("attr=underline");
+			// STFL will just ignore those in forms which don't have the
+			// `color_bold` and `color_underline` variables.
+			form.set("color_bold", bold.c_str());
+			form.set("color_underline", ul.c_str());
+		}
 	}
 }
 
