@@ -204,6 +204,7 @@ ConfigContainer::ConfigContainer()
 	{"reload-threads", ConfigData("1", ConfigDataType::INT)},
 	{"reload-time", ConfigData("60", ConfigDataType::INT)},
 	{"save-path", ConfigData("~/", ConfigDataType::PATH)},
+	{"scrolloff", ConfigData("0", ConfigDataType::INT)},
 	{
 		"search-highlight-colors",
 		ConfigData("black yellow bold",
@@ -244,6 +245,11 @@ ConfigContainer::ConfigContainer()
 	{"ocnews-passwordeval", ConfigData("", ConfigDataType::STR)},
 	{"ocnews-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"ocnews-url", ConfigData("", ConfigDataType::STR)},
+	{"miniflux-login", ConfigData("", ConfigDataType::STR)},
+	{"miniflux-password", ConfigData("", ConfigDataType::STR)},
+	{"miniflux-passwordfile", ConfigData("", ConfigDataType::PATH)},
+	{"miniflux-passwordeval", ConfigData("", ConfigDataType::STR)},
+	{"miniflux-url", ConfigData("", ConfigDataType::STR)},
 	{
 		"urls-source",
 		ConfigData("local",
@@ -254,6 +260,7 @@ ConfigContainer::ConfigContainer()
 			"newsblur",
 			"feedhq",
 			"ocnews",
+			"miniflux",
 			"inoreader"}))},
 	{"use-proxy", ConfigData("no", ConfigDataType::BOOL)},
 	{"user-agent", ConfigData("", ConfigDataType::STR)},
@@ -325,7 +332,7 @@ void ConfigContainer::register_commands(ConfigParser& cfgparser)
 	// ConfigContainer
 	std::lock_guard<std::recursive_mutex> guard(config_data_mtx);
 	for (const auto& cfg : config_data) {
-		cfgparser.register_handler(cfg.first, this);
+		cfgparser.register_handler(cfg.first, *this);
 	}
 }
 
