@@ -41,6 +41,8 @@
 #include "inoreaderurlreader.h"
 #include "itemrenderer.h"
 #include "logger.h"
+#include "minifluxapi.h"
+#include "minifluxurlreader.h"
 #include "newsblurapi.h"
 #include "newsblururlreader.h"
 #include "ocnewsapi.h"
@@ -90,9 +92,6 @@ Controller::~Controller()
 	delete rsscache;
 	delete urlcfg;
 	delete api;
-
-	feedcontainer.clear_feeds_items();
-	feedcontainer.feeds.clear();
 }
 
 void Controller::set_view(View* vv)
@@ -173,21 +172,22 @@ int Controller::run(const CliArgsParser& args)
 	colorman.register_commands(cfgparser);
 
 	KeyMap keys(KM_NEWSBOAT);
-	cfgparser.register_handler("bind-key", &keys);
-	cfgparser.register_handler("unbind-key", &keys);
-	cfgparser.register_handler("macro", &keys);
+	cfgparser.register_handler("bind-key", keys);
+	cfgparser.register_handler("unbind-key", keys);
+	cfgparser.register_handler("macro", keys);
+	cfgparser.register_handler("run-on-startup", keys);
 
-	cfgparser.register_handler("ignore-article", &ign);
-	cfgparser.register_handler("always-download", &ign);
-	cfgparser.register_handler("reset-unread-on-update", &ign);
+	cfgparser.register_handler("ignore-article", ign);
+	cfgparser.register_handler("always-download", ign);
+	cfgparser.register_handler("reset-unread-on-update", ign);
 
-	cfgparser.register_handler("define-filter", &filters);
-	cfgparser.register_handler("highlight", &rxman);
-	cfgparser.register_handler("highlight-article", &rxman);
+	cfgparser.register_handler("define-filter", filters);
+	cfgparser.register_handler("highlight", rxman);
+	cfgparser.register_handler("highlight-article", rxman);
 
 	try {
-		cfgparser.parse("/etc/" PROGRAM_NAME "/config");
-		cfgparser.parse(configpaths.config_file());
+		cfgparser.parse_file("/etc/" PROGRAM_NAME "/config");
+		cfgparser.parse_file(configpaths.config_file());
 	} catch (const ConfigException& ex) {
 		LOG(Level::ERROR,
 			"an exception occurred while parsing the configuration "
@@ -288,6 +288,30 @@ int Controller::run(const CliArgsParser& args)
 	} else if (type == "ocnews") {
 		api = new OcNewsApi(&cfg);
 		urlcfg = new OcNewsUrlReader(configpaths.url_file(), api);
+	} else if (type == "miniflux") {
+		const auto miniflux_url = cfg.get_configvalue("miniflux-url");
+		if (miniflux_url.empty()) {
+			std::cerr <<
+				_("ERROR: You must set `miniflux-url` to use Miniflux\n");
+			return EXIT_FAILURE;
+		}
+
+		const std::string user = cfg.get_configvalue("miniflux-login");
+		const std::string pass = cfg.get_configvalue("miniflux-password");
+		const std::string pass_file = cfg.get_configvalue("miniflux-passwordfile");
+		const std::string pass_eval = cfg.get_configvalue("miniflux-passwordeval");
+		const bool creds_set = !user.empty() &&
+			(!pass.empty() || !pass_file.empty() || !pass_eval.empty());
+		if (!creds_set) {
+			std::cerr <<
+				_("ERROR: You must set `miniflux-login` and one of `miniflux-password`, "
+					"`miniflux-passwordfile` or `miniflux-passwordeval` to use "
+					"Miniflux\n");
+			return EXIT_FAILURE;
+		}
+
+		api = new MinifluxApi(&cfg);
+		urlcfg = new MinifluxUrlReader(configpaths.url_file(), api);
 	} else if (type == "inoreader") {
 		const auto all_set = !cfg.get_configvalue("inoreader-app-id").empty()
 			&& !cfg.get_configvalue("inoreader-app-key").empty();
@@ -355,6 +379,11 @@ int Controller::run(const CliArgsParser& args)
 					_("It looks like you haven't configured any "
 						"feeds in your Inoreader account. Please do "
 						"so, and try again."));
+		} else if (type == "miniflux") {
+			msg = strprintf::fmt(
+					_("It looks like you haven't configured any "
+						"feeds in your Miniflux account. Please do "
+						"so, and try again."));
 		} else {
 			assert(0); // shouldn't happen
 		}
@@ -494,8 +523,7 @@ int Controller::run(const CliArgsParser& args)
 		std::cout.flush();
 	}
 	try {
-		std::lock_guard<std::mutex> feedslock(feeds_mutex);
-		rsscache->cleanup_cache(feedcontainer.feeds);
+		rsscache->cleanup_cache(feedcontainer.get_all_feeds());
 		if (!args.silent()) {
 			std::cout << _("done.") << std::endl;
 		}
@@ -512,14 +540,12 @@ int Controller::run(const CliArgsParser& args)
 
 void Controller::update_feedlist()
 {
-	std::lock_guard<std::mutex> feedslock(feeds_mutex);
-	v->set_feedlist(feedcontainer.feeds);
+	v->set_feedlist(feedcontainer.get_all_feeds());
 }
 
 void Controller::update_visible_feeds()
 {
-	std::lock_guard<std::mutex> feedslock(feeds_mutex);
-	v->update_visible_feeds(feedcontainer.feeds);
+	v->update_visible_feeds(feedcontainer.get_all_feeds());
 }
 
 void Controller::mark_all_read(const std::string& feedurl)
@@ -535,14 +561,12 @@ void Controller::mark_all_read(const std::string& feedurl)
 
 	if (feedurl.empty()) { // Mark all feeds as read
 		if (api) {
-			std::lock_guard<std::mutex> feedslock(feeds_mutex);
-			for (const auto& feed : feedcontainer.feeds) {
+			for (const auto& feed : feedcontainer.get_all_feeds()) {
 				api->mark_all_read(feed->rssurl());
 			}
 		}
 		feedcontainer.mark_all_feeds_read();
 	} else { // Mark a specific feed as read
-		std::lock_guard<std::mutex> feedslock(feeds_mutex);
 		const auto feed = feedcontainer.get_feed_by_url(feedurl);
 		if (!feed) {
 			return;
@@ -565,24 +589,25 @@ void Controller::mark_article_read(const std::string& guid, bool read)
 
 void Controller::mark_all_read(unsigned int pos)
 {
-	if (pos < feedcontainer.feeds.size()) {
-		ScopeMeasure m("Controller::mark_all_read");
-		std::lock_guard<std::mutex> feedslock(feeds_mutex);
-		const auto feed = feedcontainer.get_feed(pos);
-		if (feed->is_query_feed()) {
-			rsscache->mark_all_read(feed);
-		} else {
-			rsscache->mark_all_read(feed->rssurl());
-			if (api) {
-				api->mark_all_read(feed->rssurl());
-			}
-		}
-		m.stopover(
-			"after rsscache->mark_all_read, before iteration over "
-			"items");
-
-		feedcontainer.mark_all_feed_items_read(pos);
+	ScopeMeasure m("Controller::mark_all_read");
+	const auto feed = feedcontainer.get_feed(pos);
+	if (feed == nullptr) {
+		return;
 	}
+
+	if (feed->is_query_feed()) {
+		rsscache->mark_all_read(feed);
+	} else {
+		rsscache->mark_all_read(feed->rssurl());
+		if (api) {
+			api->mark_all_read(feed->rssurl());
+		}
+	}
+	m.stopover(
+		"after rsscache->mark_all_read, before iteration over "
+		"items");
+
+	feedcontainer.mark_all_feed_items_read(feed);
 }
 
 void Controller::replace_feed(std::shared_ptr<RssFeed> oldfeed,
@@ -590,8 +615,6 @@ void Controller::replace_feed(std::shared_ptr<RssFeed> oldfeed,
 	unsigned int pos,
 	bool unattended)
 {
-	std::lock_guard<std::mutex> feedslock(feeds_mutex);
-
 	LOG(Level::DEBUG, "Controller::replace_feed: saving");
 	rsscache->externalize_rssfeed(
 		newfeed, ign.matches_resetunread(newfeed->rssurl()));
@@ -606,17 +629,15 @@ void Controller::replace_feed(std::shared_ptr<RssFeed> oldfeed,
 
 	feed->set_tags(urlcfg->get_tags(oldfeed->rssurl()));
 	feed->set_order(oldfeed->get_order());
-	feedcontainer.feeds[pos] = feed;
+	feedcontainer.replace_feed(pos, feed);
 	queueManager.autoenqueue(feed);
 	for (const auto& item : feed->items()) {
 		rsscache->update_rssitem_unread_and_enqueued(item, feed->rssurl());
 	}
 
-	oldfeed->clear_items();
-
-	v->notify_itemlist_change(feedcontainer.feeds[pos]);
+	v->notify_itemlist_change(feed);
 	if (!unattended) {
-		v->set_feedlist(feedcontainer.feeds);
+		v->set_feedlist(feedcontainer.get_all_feeds());
 	}
 }
 
@@ -851,12 +872,7 @@ void Controller::export_read_information(const std::string& readinfofile)
 
 void Controller::update_config()
 {
-	if (colorman.colors_loaded()) {
-		v->set_colors(colorman.get_fgcolors(),
-			colorman.get_bgcolors(),
-			colorman.get_attributes());
-		v->apply_colors_to_all_formactions();
-	}
+	v->apply_colors_to_all_formactions();
 
 	if (cfg.get_configvalue("error-log").length() > 0) {
 		try {
@@ -874,7 +890,7 @@ void Controller::update_config()
 
 void Controller::load_configfile(const std::string& filename)
 {
-	if (cfgparser.parse(filename)) {
+	if (cfgparser.parse_file(filename)) {
 		update_config();
 	} else {
 		v->show_error(strprintf::fmt(
