@@ -17,7 +17,8 @@ DialogsFormAction::DialogsFormAction(View* vv,
 	ConfigContainer* cfg)
 	: FormAction(vv, formstr, cfg)
 	, update_list(true)
-	, dialogs_list("dialogs", FormAction::f)
+	, dialogs_list("dialogs", FormAction::f,
+		  cfg->get_configvalue_as_int("scrolloff"))
 {
 }
 
@@ -56,8 +57,7 @@ void DialogsFormAction::prepare()
 							get_parent_formaction().get())
 						? "*"
 						: " ",
-						fa.second)),
-				std::to_string(fa.first));
+						fa.second)));
 			i++;
 		}
 
@@ -98,9 +98,11 @@ bool DialogsFormAction::process_operation(Operation op,
 		}
 	}
 	break;
+	case OP_PREV:
 	case OP_SK_UP:
 		dialogs_list.move_up(cfg->get_configvalue_as_bool("wrap-scroll"));
 		break;
+	case OP_NEXT:
 	case OP_SK_DOWN:
 		dialogs_list.move_down(cfg->get_configvalue_as_bool("wrap-scroll"));
 		break;
@@ -134,7 +136,7 @@ void DialogsFormAction::handle_cmdline(const std::string& cmd)
 {
 	unsigned int idx = 0;
 	if (1 == sscanf(cmd.c_str(), "%u", &idx)) {
-		if (idx <= v->formaction_stack_size()) {
+		if (idx >= 1 && idx <= v->formaction_stack_size()) {
 			dialogs_list.set_position(idx - 1);
 		} else {
 			v->show_error(_("Invalid position!"));
