@@ -28,20 +28,18 @@ FeedListFormAction::FeedListFormAction(View* vv,
 	FilterContainer& f,
 	ConfigContainer* cfg,
 	RegexManager& r)
-	: ListFormAction(vv, formstr, cfg)
+	: ListFormAction(vv, formstr, "feeds", cfg)
 	, zero_feedpos(false)
 	, apply_filter(false)
-	, search_dummy_feed(new RssFeed(cc))
 	, filterpos(0)
 	, set_filterpos(false)
 	, rxman(r)
 	, filters(f)
-	, feeds_list("feeds", FormAction::f)
+	, cache(cc)
 {
 	valid_cmds.push_back("tag");
 	valid_cmds.push_back("goto");
 	std::sort(valid_cmds.begin(), valid_cmds.end());
-	search_dummy_feed->set_search_feed(true);
 	register_format_styles();
 }
 
@@ -88,8 +86,12 @@ bool FeedListFormAction::process_operation(Operation op,
 	bool automatic,
 	std::vector<std::string>* args)
 {
-	std::string feedpos = f.get("feedposname");
-	unsigned int pos = utils::to_u(feedpos);
+	unsigned int pos = 0;
+	if (visible_feeds.size() >= 1) {
+		const auto selected_pos = list.get_position();
+		pos = visible_feeds[selected_pos].second;
+	}
+	const std::string feedpos = std::to_string(pos);
 	bool quit = false;
 REDO:
 	switch (op) {
@@ -129,24 +131,6 @@ REDO:
 	case OP_RELOADURLS:
 		v->get_ctrl()->reload_urls_file();
 		break;
-	case OP_SK_UP:
-		feeds_list.move_up(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_DOWN:
-		feeds_list.move_down(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_HOME:
-		feeds_list.move_to_first();
-		break;
-	case OP_SK_END:
-		feeds_list.move_to_last();
-		break;
-	case OP_SK_PGUP:
-		feeds_list.move_page_up(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_PGDOWN:
-		feeds_list.move_page_down(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
 	case OP_SORT: {
 		/// This string is related to the letters in parentheses in the
 		/// "Sort by (f)irsttag/..." and "Reverse Sort by
@@ -232,8 +216,7 @@ REDO:
 	case OP_OPENINBROWSER:
 		if (visible_feeds.size() > 0 && feedpos.length() > 0) {
 			std::shared_ptr<RssFeed> feed =
-				v->get_ctrl()->get_feedcontainer()->get_feed(
-					pos);
+				v->get_ctrl()->get_feedcontainer()->get_feed(pos);
 			if (feed) {
 				if (!feed->is_query_feed()) {
 					LOG(Level::INFO,
@@ -242,17 +225,12 @@ REDO:
 						"at position `%s': %s",
 						feedpos,
 						feed->link());
-					if (!feed->link().empty()) {
-						if (int err = v->open_in_browser(feed->link())) {
-							v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
-							return false;
-						}
-					} else if (!feed->rssurl().empty()) {
-						if (int err = v->open_in_browser(feed->rssurl())) {
-							v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
-							return false;
-						}
 
+					std::string url;
+					if (!feed->link().empty()) {
+						url = feed->link();
+					} else if (!feed->rssurl().empty()) {
+						url = feed->rssurl();
 					} else {
 						// rssurl can't be empty, so if we got to this branch,
 						// something is clearly wrong with Newsboat internals.
@@ -263,10 +241,19 @@ REDO:
 							"because both `link' and `rssurl' fields are "
 							"empty");
 					}
+
+					if (!url.empty()) {
+						const auto exit_code = v->open_in_browser(url);
+						if (!exit_code.has_value()) {
+							v->show_error(_("Failed to spawn browser"));
+							return false;
+						} else if (*exit_code != 0) {
+							v->show_error(strprintf::fmt(_("Browser returned error code %i"), *exit_code));
+							return false;
+						}
+					}
 				} else {
-					v->show_error(
-						_("Cannot open query feeds in "
-							"the browser!"));
+					v->show_error(_("Cannot open query feeds in the browser!"));
 				}
 			}
 		} else {
@@ -276,19 +263,22 @@ REDO:
 	case OP_OPENALLUNREADINBROWSER:
 		if (visible_feeds.size() > 0 && feedpos.length() > 0) {
 			std::shared_ptr<RssFeed> feed =
-				v->get_ctrl()->get_feedcontainer()->get_feed(
-					pos);
+				v->get_ctrl()->get_feedcontainer()->get_feed(pos);
 			if (feed) {
 				LOG(Level::INFO,
 					"FeedListFormAction: opening all "
 					"unread "
 					"items in feed at position `%s'",
 					feedpos.c_str());
-				if (int err = open_unread_items_in_browser(feed, false)) {
-					v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
+
+				const auto exit_code = open_unread_items_in_browser(feed, false);
+				if (!exit_code.has_value()) {
+					v->show_error(_("Failed to spawn browser"));
+					return false;
+				} else if (*exit_code != 0) {
+					v->show_error(strprintf::fmt(_("Browser returned error code %i"), *exit_code));
 					return false;
 				}
-
 			}
 		} else {
 			v->show_error(_("No feed selected!"));
@@ -297,8 +287,7 @@ REDO:
 	case OP_OPENALLUNREADINBROWSER_AND_MARK:
 		if (visible_feeds.size() > 0 && feedpos.length() > 0) {
 			std::shared_ptr<RssFeed> feed =
-				v->get_ctrl()->get_feedcontainer()->get_feed(
-					pos);
+				v->get_ctrl()->get_feedcontainer()->get_feed(pos);
 			if (feed) {
 				LOG(Level::INFO,
 					"FeedListFormAction: opening all "
@@ -307,8 +296,12 @@ REDO:
 					"marking read",
 					feedpos.c_str());
 
-				if (int err = open_unread_items_in_browser(feed, true)) {
-					v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
+				const auto exit_code = open_unread_items_in_browser(feed, true);
+				if (!exit_code.has_value()) {
+					v->show_error(_("Failed to spawn browser"));
+					return false;
+				} else if (*exit_code != 0) {
+					v->show_error(strprintf::fmt(_("Browser returned error code %i"), *exit_code));
 					return false;
 				}
 
@@ -344,7 +337,7 @@ REDO:
 				v->set_status("");
 				bool show_read = cfg->get_configvalue_as_bool("show-read-feeds");
 				if (visible_feeds.size() > (pos + 1) && show_read) {
-					feeds_list.set_position(pos + 1);
+					list.set_position(pos + 1);
 				}
 			} catch (const DbException& e) {
 				v->show_error(strprintf::fmt(
@@ -413,21 +406,24 @@ REDO:
 	}
 	break;
 	case OP_MARKALLFEEDSREAD:
-		LOG(Level::INFO, "FeedListFormAction: marking all feeds read");
-		v->set_status(_("Marking all feeds read..."));
-		if (tag == "") {
-			v->get_ctrl()->mark_all_read("");
-		} else {
-			// we're in tag view, so let's only touch feeds that are
-			// visible
-			for (const auto& feedptr_pos_pair : visible_feeds) {
-				auto rss_feed_ptr = feedptr_pos_pair.first;
-				auto feedurl = rss_feed_ptr->rssurl();
-				v->get_ctrl()->mark_all_read(feedurl);
+		if (v->confirm(_("Do you really want to mark all feeds as read (y:Yes n:No)? "),
+				_("yn")) == *_("y")) {
+			LOG(Level::INFO, "FeedListFormAction: marking all feeds read");
+			v->set_status(_("Marking all feeds read..."));
+			if (tag == "") {
+				v->get_ctrl()->mark_all_read("");
+			} else {
+				// we're in tag view, so let's only touch feeds that are
+				// visible
+				for (const auto& feedptr_pos_pair : visible_feeds) {
+					auto rss_feed_ptr = feedptr_pos_pair.first;
+					auto feedurl = rss_feed_ptr->rssurl();
+					v->get_ctrl()->mark_all_read(feedurl);
+				}
 			}
+			v->set_status("");
+			do_redraw = true;
 		}
-		v->set_status("");
-		do_redraw = true;
 		break;
 	case OP_CLEARTAG:
 		tag = "";
@@ -574,7 +570,7 @@ void FeedListFormAction::set_feedlist(
 {
 	assert(cfg != nullptr); // must not happen
 
-	const unsigned int width = feeds_list.get_width();
+	const unsigned int width = list.get_width();
 
 	std::string feedlist_format = cfg->get_configvalue("feedlist-format");
 
@@ -586,11 +582,10 @@ void FeedListFormAction::set_feedlist(
 		listfmt.add_line(format_line(feedlist_format,
 				feed.first,
 				feed.second,
-				width),
-			std::to_string(feed.second));
+				width));
 	}
 
-	feeds_list.stfl_replace_lines(listfmt);
+	list.stfl_replace_lines(listfmt);
 
 	update_form_title(width);
 }
@@ -613,7 +608,7 @@ KeyMapHintEntry* FeedListFormAction::get_keymap_hint()
 
 bool FeedListFormAction::jump_to_previous_unread_feed(unsigned int& feedpos)
 {
-	const unsigned int curpos = feeds_list.get_position();
+	const unsigned int curpos = list.get_position();
 	LOG(Level::DEBUG,
 		"FeedListFormAction::jump_to_previous_unread_feed: searching "
 		"for "
@@ -630,7 +625,7 @@ bool FeedListFormAction::jump_to_previous_unread_feed(unsigned int& feedpos)
 				"FeedListFormAction::jump_to_previous_unread_"
 				"feed:"
 				" hit");
-			feeds_list.set_position(i);
+			list.set_position(i);
 			feedpos = visible_feeds[i].second;
 			return true;
 		}
@@ -647,7 +642,7 @@ bool FeedListFormAction::jump_to_previous_unread_feed(unsigned int& feedpos)
 				"FeedListFormAction::jump_to_previous_unread_"
 				"feed:"
 				" hit");
-			feeds_list.set_position(i);
+			list.set_position(i);
 			feedpos = visible_feeds[i].second;
 			return true;
 		}
@@ -657,7 +652,7 @@ bool FeedListFormAction::jump_to_previous_unread_feed(unsigned int& feedpos)
 
 void FeedListFormAction::goto_feed(const std::string& str)
 {
-	const unsigned int curpos = feeds_list.get_position();
+	const unsigned int curpos = list.get_position();
 	LOG(Level::DEBUG,
 		"FeedListFormAction::goto_feed: curpos = %u str = `%s'",
 		curpos,
@@ -665,14 +660,14 @@ void FeedListFormAction::goto_feed(const std::string& str)
 	for (unsigned int i = curpos + 1; i < visible_feeds.size(); ++i) {
 		if (strcasestr(visible_feeds[i].first->title().c_str(),
 				str.c_str()) != nullptr) {
-			feeds_list.set_position(i);
+			list.set_position(i);
 			return;
 		}
 	}
 	for (unsigned int i = 0; i <= curpos; ++i) {
 		if (strcasestr(visible_feeds[i].first->title().c_str(),
 				str.c_str()) != nullptr) {
-			feeds_list.set_position(i);
+			list.set_position(i);
 			return;
 		}
 	}
@@ -680,30 +675,25 @@ void FeedListFormAction::goto_feed(const std::string& str)
 
 bool FeedListFormAction::jump_to_random_unread_feed(unsigned int& feedpos)
 {
-	bool unread_feeds_available = false;
+	std::vector<unsigned int> unread_indexes;
 	for (unsigned int i = 0; i < visible_feeds.size(); ++i) {
 		if (visible_feeds[i].first->unread_item_count() > 0) {
-			unread_feeds_available = true;
-			break;
+			unread_indexes.push_back(i);
 		}
 	}
-	if (unread_feeds_available) {
-		for (;;) {
-			unsigned int pos =
-				utils::get_random_value(visible_feeds.size());
-			if (visible_feeds[pos].first->unread_item_count() > 0) {
-				feeds_list.set_position(pos);
-				feedpos = visible_feeds[pos].second;
-				break;
-			}
-		}
+	if (!unread_indexes.empty()) {
+		const unsigned int selected = utils::get_random_value(unread_indexes.size());
+		const unsigned int pos = unread_indexes[selected];
+		list.set_position(pos);
+		feedpos = visible_feeds[pos].second;
+		return true;
 	}
-	return unread_feeds_available;
+	return false;
 }
 
 bool FeedListFormAction::jump_to_next_unread_feed(unsigned int& feedpos)
 {
-	const unsigned int curpos = feeds_list.get_position();
+	const unsigned int curpos = list.get_position();
 	LOG(Level::DEBUG,
 		"FeedListFormAction::jump_to_next_unread_feed: searching for "
 		"unread feed");
@@ -719,7 +709,7 @@ bool FeedListFormAction::jump_to_next_unread_feed(unsigned int& feedpos)
 				"FeedListFormAction::jump_to_next_unread_feed:"
 				" "
 				"hit");
-			feeds_list.set_position(i);
+			list.set_position(i);
 			feedpos = visible_feeds[i].second;
 			return true;
 		}
@@ -735,7 +725,7 @@ bool FeedListFormAction::jump_to_next_unread_feed(unsigned int& feedpos)
 				"FeedListFormAction::jump_to_next_unread_feed:"
 				" "
 				"hit");
-			feeds_list.set_position(i);
+			list.set_position(i);
 			feedpos = visible_feeds[i].second;
 			return true;
 		}
@@ -745,7 +735,7 @@ bool FeedListFormAction::jump_to_next_unread_feed(unsigned int& feedpos)
 
 bool FeedListFormAction::jump_to_previous_feed(unsigned int& feedpos)
 {
-	const unsigned int curpos = feeds_list.get_position();
+	const unsigned int curpos = list.get_position();
 
 	if (curpos > 0) {
 		unsigned int i = curpos - 1;
@@ -753,7 +743,7 @@ bool FeedListFormAction::jump_to_previous_feed(unsigned int& feedpos)
 			"FeedListFormAction::jump_to_previous_feed: "
 			"visible_feeds[%u]",
 			i);
-		feeds_list.set_position(i);
+		list.set_position(i);
 		feedpos = visible_feeds[i].second;
 		return true;
 	}
@@ -762,7 +752,7 @@ bool FeedListFormAction::jump_to_previous_feed(unsigned int& feedpos)
 
 bool FeedListFormAction::jump_to_next_feed(unsigned int& feedpos)
 {
-	const unsigned int curpos = feeds_list.get_position();
+	const unsigned int curpos = list.get_position();
 
 	if ((curpos + 1) < visible_feeds.size()) {
 		unsigned int i = curpos + 1;
@@ -770,7 +760,7 @@ bool FeedListFormAction::jump_to_next_feed(unsigned int& feedpos)
 			"FeedListFormAction::jump_to_next_feed: "
 			"visible_feeds[%u]",
 			i);
-		feeds_list.set_position(i);
+		list.set_position(i);
 		feedpos = visible_feeds[i].second;
 		return true;
 	}
@@ -779,7 +769,7 @@ bool FeedListFormAction::jump_to_next_feed(unsigned int& feedpos)
 
 std::shared_ptr<RssFeed> FeedListFormAction::get_feed()
 {
-	const unsigned int curpos = feeds_list.get_position();
+	const unsigned int curpos = list.get_position();
 	return visible_feeds[curpos].first;
 }
 
@@ -855,7 +845,7 @@ void FeedListFormAction::mark_pos_if_visible(unsigned int pos)
 				"match, "
 				"setting position to %u",
 				vpos);
-			feeds_list.set_position(vpos);
+			list.set_position(vpos);
 			return;
 		}
 		vpos++;
@@ -869,7 +859,7 @@ void FeedListFormAction::mark_pos_if_visible(unsigned int pos)
 				"match "
 				"in 2nd try, setting position to %u",
 				vpos);
-			feeds_list.set_position(vpos);
+			list.set_position(vpos);
 			return;
 		}
 		vpos++;
@@ -878,7 +868,7 @@ void FeedListFormAction::mark_pos_if_visible(unsigned int pos)
 
 void FeedListFormAction::save_filterpos()
 {
-	const unsigned int i = feeds_list.get_position();
+	const unsigned int i = list.get_position();
 	if (i < visible_feeds.size()) {
 		filterpos = visible_feeds[i].second;
 		set_filterpos = true;
@@ -891,9 +881,9 @@ void FeedListFormAction::register_format_styles()
 	const std::string textview = strprintf::fmt(
 			"{!list[feeds] .expand:vh style_normal[listnormal]: "
 			"style_focus[listfocus]:fg=yellow,bg=blue,attr=bold "
-			"pos_name[feedposname]: pos[feeds_pos]:0 %s richtext:1}",
+			"pos[feeds_pos]:0 offset[feeds_offset]:0 %s richtext:1}",
 			attrstr);
-	feeds_list.stfl_replace_list(0, textview);
+	list.stfl_replace_list(0, textview);
 }
 
 void FeedListFormAction::update_form_title(unsigned int width)
@@ -962,10 +952,9 @@ void FeedListFormAction::op_start_search()
 			return;
 		}
 		if (!items.empty()) {
-			search_dummy_feed->item_mutex.lock();
-			search_dummy_feed->clear_items();
+			std::shared_ptr<RssFeed> search_dummy_feed(new RssFeed(cache));
+			search_dummy_feed->set_search_feed(true);
 			search_dummy_feed->add_items(items);
-			search_dummy_feed->item_mutex.unlock();
 			v->push_searchresult(search_dummy_feed, searchphrase);
 		} else {
 			v->show_error(_("No results."));
@@ -981,7 +970,7 @@ void FeedListFormAction::handle_cmdline_num(unsigned int idx)
 		if (i == -1) {
 			v->show_error(_("Position not visible!"));
 		} else {
-			feeds_list.set_position(i);
+			list.set_position(i);
 		}
 	} else {
 		v->show_error(_("Invalid position!"));
@@ -995,14 +984,14 @@ void FeedListFormAction::set_pos()
 		unsigned int i = 0;
 		for (const auto& feed : visible_feeds) {
 			if (feed.second == filterpos) {
-				feeds_list.set_position(i);
+				list.set_position(i);
 				return;
 			}
 			i++;
 		}
-		feeds_list.set_position(0);
+		list.set_position(0);
 	} else if (zero_feedpos) {
-		feeds_list.set_position(0);
+		list.set_position(0);
 		zero_feedpos = false;
 	}
 }
