@@ -19,17 +19,36 @@ HelpFormAction::HelpFormAction(View* vv,
 	: FormAction(vv, formstr, cfg)
 	, quit(false)
 	, apply_search(false)
+	, textview("helptext", FormAction::f)
 {
 }
 
 HelpFormAction::~HelpFormAction() {}
 
-void HelpFormAction::process_operation(Operation op,
+bool HelpFormAction::process_operation(Operation op,
 	bool /* automatic */,
 	std::vector<std::string>* /* args */)
 {
 	bool hardquit = false;
 	switch (op) {
+	case OP_SK_UP:
+		textview.scroll_up();
+		break;
+	case OP_SK_DOWN:
+		textview.scroll_down();
+		break;
+	case OP_SK_HOME:
+		textview.scroll_to_top();
+		break;
+	case OP_SK_END:
+		textview.scroll_to_bottom();
+		break;
+	case OP_SK_PGUP:
+		textview.scroll_page_up();
+		break;
+	case OP_SK_PGDOWN:
+		textview.scroll_page_down();
+		break;
 	case OP_QUIT:
 		quit = true;
 		break;
@@ -56,30 +75,30 @@ void HelpFormAction::process_operation(Operation op,
 	} else if (quit) {
 		v->pop_current_formaction();
 	}
+	return true;
 }
 
 void HelpFormAction::prepare()
 {
 	if (do_redraw) {
-		std::string listwidth = f->get("helptext:w");
-		unsigned int width = utils::to_u(listwidth);
+		f.run(-3); // compute all widget dimensions
+
+		const unsigned int width = textview.get_width();
 
 		FmtStrFormatter fmt;
 		fmt.register_fmt('N', PROGRAM_NAME);
 		fmt.register_fmt('V', utils::program_version());
-		f->set("head",
+		f.set("head",
 			fmt.do_format(cfg->get_configvalue("help-title-format"),
 				width));
 
-		std::vector<KeyMapDesc> descs;
-		v->get_keys()->get_keymap_descriptions(
-			descs, v->get_keys()->get_flag_from_context(context));
+		const auto descs = v->get_keymap()->get_keymap_descriptions(context);
 
 		std::string highlighted_searchphrase =
 			strprintf::fmt("<hl>%s</>", searchphrase);
 		std::vector<std::string> colors = utils::tokenize(
 				cfg->get_configvalue("search-highlight-colors"), " ");
-		f->set("highlight", make_colorstring(colors));
+		f.set("highlight", make_colorstring(colors));
 		ListFormatter listfmt;
 
 		unsigned int unbound_count = 0;
@@ -205,7 +224,7 @@ void HelpFormAction::prepare()
 			}
 		}
 
-		f->modify("helptext", "replace_inner", listfmt.format_list());
+		textview.stfl_replace_lines(listfmt.get_lines_count(), listfmt.format_list());
 
 		do_redraw = false;
 	}
