@@ -13,9 +13,9 @@ extern "C" {
 		void* hst,
 		const char* line);
 
-	char* rs_history_prev(void* hst);
+	char* rs_history_previous_line(void* hst);
 
-	char* rs_history_next(void* hst);
+	char* rs_history_next_line(void* hst);
 
 	void rs_history_load_from_file(
 		void* hst,
@@ -44,14 +44,14 @@ void History::add_line(const std::string& line)
 	rs_history_add_line(rs_hst, line.c_str());
 }
 
-std::string History::prev()
+std::string History::previous_line()
 {
-	return RustString(rs_history_prev(rs_hst));
+	return RustString(rs_history_previous_line(rs_hst));
 }
 
-std::string History::next()
+std::string History::next_line()
 {
-	return RustString(rs_history_next(rs_hst));
+	return RustString(rs_history_next_line(rs_hst));
 }
 
 void History::load_from_file(const std::string& file)
