@@ -28,11 +28,10 @@ ItemListFormAction::ItemListFormAction(View* vv,
 	FilterContainer& f,
 	ConfigContainer* cfg,
 	RegexManager& r)
-	: ListFormAction(vv, formstr, cfg)
+	: ListFormAction(vv, formstr, "items", cfg)
 	, pos(0)
 	, apply_filter(false)
 	, show_searchresult(false)
-	, search_dummy_feed(new RssFeed(cc))
 	, set_filterpos(false)
 	, filterpos(0)
 	, rxman(r)
@@ -42,9 +41,7 @@ ItemListFormAction::ItemListFormAction(View* vv,
 	, listfmt(&rxman, "articlelist")
 	, rsscache(cc)
 	, filters(f)
-	, items_list("items", FormAction::f)
 {
-	search_dummy_feed->set_search_feed(true);
 	register_format_styles();
 }
 
@@ -63,7 +60,7 @@ bool ItemListFormAction::process_operation(Operation op,
 	 *   - if an item was selected, then fetch it and do something with it
 	 */
 
-	const unsigned int itempos = items_list.get_position();
+	const unsigned int itempos = list.get_position();
 
 	switch (op) {
 	case OP_OPEN: {
@@ -74,7 +71,7 @@ bool ItemListFormAction::process_operation(Operation op,
 			old_itempos = itempos;
 			v->push_itemview(feed,
 				visible_items[itempos].first->guid(),
-				show_searchresult ? searchphrase : "");
+				show_searchresult ? search_phrase : "");
 			invalidate(itempos);
 		} else {
 			v->show_error(
@@ -82,24 +79,6 @@ bool ItemListFormAction::process_operation(Operation op,
 		}
 	}
 	break;
-	case OP_SK_UP:
-		items_list.move_up(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_DOWN:
-		items_list.move_down(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_HOME:
-		items_list.move_to_first();
-		break;
-	case OP_SK_END:
-		items_list.move_to_last();
-		break;
-	case OP_SK_PGUP:
-		items_list.move_page_up(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
-	case OP_SK_PGDOWN:
-		items_list.move_page_down(cfg->get_configvalue_as_bool("wrap-scroll"));
-		break;
 	case OP_DELETE: {
 		ScopeMeasure m1("OP_DELETE");
 		if (!visible_items.empty()) {
@@ -114,7 +93,7 @@ bool ItemListFormAction::process_operation(Operation op,
 				visible_items[itempos].first->guid(),
 				visible_items[itempos].first->deleted());
 			if (itempos < visible_items.size() - 1) {
-				items_list.set_position(itempos + 1);
+				list.set_position(itempos + 1);
 			}
 			invalidate(itempos);
 		} else {
@@ -126,11 +105,15 @@ bool ItemListFormAction::process_operation(Operation op,
 	case OP_DELETE_ALL: {
 		ScopeMeasure m1("OP_DELETE_ALL");
 		if (visible_items.size() > 0) {
-			v->get_ctrl()->mark_all_read(pos);
+			if (!feed->is_search_feed()) {
+				v->get_ctrl()->mark_all_read(pos);
+			} else {
+				v->get_ctrl()->mark_all_read(feed);
+			}
 			for (const auto& pair : visible_items) {
 				pair.first->set_deleted(true);
 			}
-			if (feed->is_query_feed()) {
+			if (feed->is_query_feed() || feed->is_search_feed()) {
 				for (const auto& pair : visible_items) {
 					rsscache->mark_item_deleted(pair.first->guid(), true);
 				}
@@ -151,9 +134,13 @@ bool ItemListFormAction::process_operation(Operation op,
 		LOG(Level::INFO, "ItemListFormAction: opening item at pos `%u'", itempos);
 		if (!visible_items.empty()) {
 			if (itempos < visible_items.size()) {
-				auto link = visible_items[itempos].first->link();
-				if (int err = v->open_in_browser(link)) {
-					v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
+				const auto link = visible_items[itempos].first->link();
+				const auto exit_code = v->open_in_browser(link);
+				if (!exit_code.has_value()) {
+					v->show_error(_("Failed to spawn browser"));
+					break;
+				} else if (*exit_code != 0) {
+					v->show_error(strprintf::fmt(_("Browser returned error code %i"), *exit_code));
 					break;
 				}
 				visible_items[itempos].first->set_unread(false);
@@ -165,7 +152,7 @@ bool ItemListFormAction::process_operation(Operation op,
 						"next-unread")) {
 					if (itempos <
 						visible_items.size() - 1) {
-						items_list.set_position(itempos + 1);
+						list.set_position(itempos + 1);
 					}
 				} else {
 					process_operation(OP_NEXTUNREAD);
@@ -182,9 +169,13 @@ bool ItemListFormAction::process_operation(Operation op,
 		LOG(Level::INFO, "ItemListFormAction: opening item at pos `%u'", itempos);
 		if (!visible_items.empty()) {
 			if (itempos < visible_items.size()) {
-				auto link = visible_items[itempos].first->link();
-				if (int err = v->open_in_browser(link)) {
-					v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
+				const auto link = visible_items[itempos].first->link();
+				const auto exit_code = v->open_in_browser(link);
+				if (!exit_code.has_value()) {
+					v->show_error(_("Failed to spawn browser"));
+					return false;
+				} else if (*exit_code != 0) {
+					v->show_error(strprintf::fmt(_("Browser returned error code %i"), *exit_code));
 					return false;
 				}
 				invalidate(itempos);
@@ -201,8 +192,12 @@ bool ItemListFormAction::process_operation(Operation op,
 				"ItemListFormAction: opening all unread items "
 				"in "
 				"browser");
-			if (int err = open_unread_items_in_browser(feed, false)) {
-				v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
+			const auto exit_code = open_unread_items_in_browser(feed, false);
+			if (!exit_code.has_value()) {
+				v->show_error(_("Failed to spawn browser"));
+				return false;
+			} else if (*exit_code != 0) {
+				v->show_error(strprintf::fmt(_("Browser returned error code %i"), *exit_code));
 				return false;
 			}
 		}
@@ -214,8 +209,12 @@ bool ItemListFormAction::process_operation(Operation op,
 				"ItemListFormAction: opening all unread items "
 				"in "
 				"browser and marking read");
-			if (int err = open_unread_items_in_browser(feed, true)) {
-				v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
+			const auto exit_code = open_unread_items_in_browser(feed, true);
+			if (!exit_code.has_value()) {
+				v->show_error(_("Failed to spawn browser"));
+				return false;
+			} else if (*exit_code != 0) {
+				v->show_error(strprintf::fmt(_("Browser returned error code %i"), *exit_code));
 				return false;
 			}
 			invalidate_everything();
@@ -273,7 +272,7 @@ bool ItemListFormAction::process_operation(Operation op,
 			if (!cfg->get_configvalue_as_bool(
 					"toggleitemread-jumps-to-next-unread")) {
 				if (itempos < visible_items.size() - 1) {
-					items_list.set_position(itempos + 1);
+					list.set_position(itempos + 1);
 				}
 			} else {
 				process_operation(OP_NEXTUNREAD);
@@ -433,7 +432,7 @@ bool ItemListFormAction::process_operation(Operation op,
 		LOG(Level::INFO,
 			"ItemListFormAction: jumping to next unread item");
 		if (!jump_to_next_unread_item(false)) {
-			if (!v->get_next_unread(this)) {
+			if (!v->get_next_unread(*this)) {
 				v->show_error(_("No unread items."));
 			}
 		}
@@ -442,7 +441,7 @@ bool ItemListFormAction::process_operation(Operation op,
 		LOG(Level::INFO,
 			"ItemListFormAction: jumping to previous unread item");
 		if (!jump_to_previous_unread_item(false)) {
-			if (!v->get_previous_unread(this)) {
+			if (!v->get_previous_unread(*this)) {
 				v->show_error(_("No unread items."));
 			}
 		}
@@ -450,7 +449,7 @@ bool ItemListFormAction::process_operation(Operation op,
 	case OP_NEXT:
 		LOG(Level::INFO, "ItemListFormAction: jumping to next item");
 		if (!jump_to_next_item(false)) {
-			if (!v->get_next(this)) {
+			if (!v->get_next(*this)) {
 				v->show_error(_("Already on last item."));
 			}
 		}
@@ -459,35 +458,35 @@ bool ItemListFormAction::process_operation(Operation op,
 		LOG(Level::INFO,
 			"ItemListFormAction: jumping to previous item");
 		if (!jump_to_previous_item(false)) {
-			if (!v->get_previous(this)) {
+			if (!v->get_previous(*this)) {
 				v->show_error(_("Already on first item."));
 			}
 		}
 		break;
 	case OP_RANDOMUNREAD:
 		if (!jump_to_random_unread_item()) {
-			if (!v->get_random_unread(this)) {
+			if (!v->get_random_unread(*this)) {
 				v->show_error(_("No unread items."));
 			}
 		}
 		break;
 	case OP_NEXTUNREADFEED:
-		if (!v->get_next_unread_feed(this)) {
+		if (!v->get_next_unread_feed(*this)) {
 			v->show_error(_("No unread feeds."));
 		}
 		break;
 	case OP_PREVUNREADFEED:
-		if (!v->get_prev_unread_feed(this)) {
+		if (!v->get_prev_unread_feed(*this)) {
 			v->show_error(_("No unread feeds."));
 		}
 		break;
 	case OP_NEXTFEED:
-		if (!v->get_next_feed(this)) {
+		if (!v->get_next_feed(*this)) {
 			v->show_error(_("Already on last feed."));
 		}
 		break;
 	case OP_PREVFEED:
-		if (!v->get_prev_feed(this)) {
+		if (!v->get_prev_feed(*this)) {
 			v->show_error(_("Already on first feed."));
 		}
 		break;
@@ -527,13 +526,13 @@ bool ItemListFormAction::process_operation(Operation op,
 					LOG(Level::DEBUG,
 						"ItemListFormAction:: "
 						"reset itempos to last");
-					items_list.set_position(visible_items.size() - 1);
+					list.set_position(visible_items.size() - 1);
 				}
 				if (sortorder == "date-asc") {
 					LOG(Level::DEBUG,
 						"ItemListFormAction:: "
 						"reset itempos to first");
-					items_list.set_position(0);
+					list.set_position(0);
 				}
 			}
 			invalidate_everything();
@@ -560,7 +559,7 @@ bool ItemListFormAction::process_operation(Operation op,
 			}
 			if (!cfg->get_configvalue_as_bool(
 					"show-read-articles")) {
-				items_list.set_position(0);
+				list.set_position(0);
 			}
 			invalidate_everything();
 		}
@@ -787,7 +786,7 @@ void ItemListFormAction::finished_qna(Operation op)
 
 	case OP_PIPE_TO: {
 		if (!visible_items.empty()) {
-			unsigned int itempos = items_list.get_position();
+			unsigned int itempos = list.get_position();
 			std::string cmd = qna_responses[0];
 			std::ostringstream ostr;
 			v->get_ctrl()->write_item(
@@ -835,7 +834,7 @@ void ItemListFormAction::qna_end_editflags()
 		return;
 	}
 
-	const unsigned int itempos = items_list.get_position();
+	const unsigned int itempos = list.get_position();
 	if (itempos < visible_items.size()) {
 		visible_items[itempos].first->set_flags(qna_responses[0]);
 		v->get_ctrl()->update_flags(visible_items[itempos].first);
@@ -848,7 +847,7 @@ void ItemListFormAction::qna_end_editflags()
 
 void ItemListFormAction::qna_start_search()
 {
-	searchphrase = qna_responses[0];
+	const std::string searchphrase = qna_responses[0];
 	if (searchphrase.length() == 0) {
 		return;
 	}
@@ -859,9 +858,6 @@ void ItemListFormAction::qna_start_search()
 	try {
 		std::string utf8searchphrase = utils::convert_text(
 				searchphrase, "utf-8", nl_langinfo(CODESET));
-		if (show_searchresult) {
-			feed->set_rssurl("search:");
-		}
 		items = v->get_ctrl()->search_for_items(
 				utf8searchphrase, feed);
 	} catch (const DbException& e) {
@@ -877,11 +873,9 @@ void ItemListFormAction::qna_start_search()
 		return;
 	}
 
-	{
-		std::lock_guard<std::mutex> lock(search_dummy_feed->item_mutex);
-		search_dummy_feed->clear_items();
-		search_dummy_feed->add_items(items);
-	}
+	std::shared_ptr<RssFeed> search_dummy_feed(new RssFeed(rsscache));
+	search_dummy_feed->set_search_feed(true);
+	search_dummy_feed->add_items(items);
 
 	if (show_searchresult) {
 		v->pop_current_formaction();
@@ -946,7 +940,7 @@ void ItemListFormAction::prepare()
 
 	if (cfg->get_configvalue_as_bool("mark-as-read-on-hover")) {
 		if (!visible_items.empty()) {
-			const unsigned int itempos = items_list.get_position();
+			const unsigned int itempos = list.get_position();
 			if (visible_items[itempos].first->unread()) {
 				visible_items[itempos].first->set_unread(false);
 				v->get_ctrl()->mark_article_read(
@@ -957,7 +951,7 @@ void ItemListFormAction::prepare()
 		}
 	}
 
-	const unsigned int width = items_list.get_width();
+	const unsigned int width = list.get_width();
 
 	if (old_width != width) {
 		invalidate_everything();
@@ -981,7 +975,7 @@ void ItemListFormAction::prepare()
 					width,
 					itemlist_format,
 					datetime_format);
-			listfmt.add_line(line, std::to_string(item.second));
+			listfmt.add_line(line);
 		}
 		break;
 
@@ -992,14 +986,14 @@ void ItemListFormAction::prepare()
 					width,
 					itemlist_format,
 					datetime_format);
-			listfmt.set_line(itempos, line, std::to_string(item.second));
+			listfmt.set_line(itempos, line);
 		}
 		break;
 	case InvalidationMode::NONE:
 		break;
 	}
 
-	items_list.stfl_replace_lines(listfmt);
+	list.stfl_replace_lines(listfmt);
 
 	invalidated_itempos.clear();
 	invalidation_mode = InvalidationMode::NONE;
@@ -1061,7 +1055,7 @@ std::string ItemListFormAction::item2formatted_line(const ItemPtrPosPair& item,
 
 void ItemListFormAction::init()
 {
-	items_list.set_position(0);
+	list.set_position(0);
 	f.set("msg", "");
 	set_keymap_hints();
 	invalidate_everything();
@@ -1113,7 +1107,7 @@ void ItemListFormAction::set_head(const std::string& s,
 
 bool ItemListFormAction::jump_to_previous_unread_item(bool start_with_last)
 {
-	const int itempos =  items_list.get_position();
+	const int itempos =  list.get_position();
 	for (int i = (start_with_last ? itempos : (itempos - 1)); i >= 0; --i) {
 		LOG(Level::DEBUG,
 			"ItemListFormAction::jump_to_previous_unread_item: "
@@ -1121,13 +1115,13 @@ bool ItemListFormAction::jump_to_previous_unread_item(bool start_with_last)
 			i,
 			visible_items[i].first->unread() ? "true" : "false");
 		if (visible_items[i].first->unread()) {
-			items_list.set_position(i);
+			list.set_position(i);
 			return true;
 		}
 	}
 	for (int i = visible_items.size() - 1; i >= itempos; --i) {
 		if (visible_items[i].first->unread()) {
-			items_list.set_position(i);
+			list.set_position(i);
 			return true;
 		}
 	}
@@ -1136,29 +1130,24 @@ bool ItemListFormAction::jump_to_previous_unread_item(bool start_with_last)
 
 bool ItemListFormAction::jump_to_random_unread_item()
 {
-	bool has_unread_available = false;
+	std::vector<unsigned int> unread_indexes;
 	for (unsigned int i = 0; i < visible_items.size(); ++i) {
 		if (visible_items[i].first->unread()) {
-			has_unread_available = true;
-			break;
+			unread_indexes.push_back(i);
 		}
 	}
-	if (has_unread_available) {
-		for (;;) {
-			unsigned int pos =
-				utils::get_random_value(visible_items.size());
-			if (visible_items[pos].first->unread()) {
-				items_list.set_position(pos);
-				break;
-			}
-		}
+	if (!unread_indexes.empty()) {
+		const unsigned int selected = utils::get_random_value(unread_indexes.size());
+		const unsigned int pos = unread_indexes[selected];
+		list.set_position(pos);
+		return true;
 	}
-	return has_unread_available;
+	return false;
 }
 
 bool ItemListFormAction::jump_to_next_unread_item(bool start_with_first)
 {
-	const unsigned int itempos = items_list.get_position();
+	const unsigned int itempos = list.get_position();
 	LOG(Level::DEBUG,
 		"ItemListFormAction::jump_to_next_unread_item: itempos = %u "
 		"visible_items.size = %" PRIu64,
@@ -1171,7 +1160,7 @@ bool ItemListFormAction::jump_to_next_unread_item(bool start_with_first)
 			"ItemListFormAction::jump_to_next_unread_item: i = %u",
 			i);
 		if (visible_items[i].first->unread()) {
-			items_list.set_position(i);
+			list.set_position(i);
 			return true;
 		}
 	}
@@ -1181,7 +1170,7 @@ bool ItemListFormAction::jump_to_next_unread_item(bool start_with_first)
 			"ItemListFormAction::jump_to_next_unread_item: i = %u",
 			i);
 		if (visible_items[i].first->unread()) {
-			items_list.set_position(i);
+			list.set_position(i);
 			return true;
 		}
 	}
@@ -1190,7 +1179,7 @@ bool ItemListFormAction::jump_to_next_unread_item(bool start_with_first)
 
 bool ItemListFormAction::jump_to_previous_item(bool start_with_last)
 {
-	const unsigned int itempos = items_list.get_position();
+	const unsigned int itempos = list.get_position();
 
 	int i = (start_with_last ? itempos : (itempos - 1));
 	if (i >= 0) {
@@ -1198,7 +1187,7 @@ bool ItemListFormAction::jump_to_previous_item(bool start_with_last)
 			"ItemListFormAction::jump_to_previous_item: "
 			"visible_items[%u]",
 			i);
-		items_list.set_position(i);
+		list.set_position(i);
 		return true;
 	}
 	return false;
@@ -1206,7 +1195,7 @@ bool ItemListFormAction::jump_to_previous_item(bool start_with_last)
 
 bool ItemListFormAction::jump_to_next_item(bool start_with_first)
 {
-	const unsigned int itempos = items_list.get_position();
+	const unsigned int itempos = list.get_position();
 	LOG(Level::DEBUG,
 		"ItemListFormAction::jump_to_next_item: itempos = %" PRIu64
 		" visible_items.size = %" PRIu64,
@@ -1217,7 +1206,7 @@ bool ItemListFormAction::jump_to_next_item(bool start_with_first)
 		LOG(Level::DEBUG,
 			"ItemListFormAction::jump_to_next_item: i = %u",
 			i);
-		items_list.set_position(i);
+		list.set_position(i);
 		return true;
 	}
 	return false;
@@ -1225,7 +1214,7 @@ bool ItemListFormAction::jump_to_next_item(bool start_with_first)
 
 std::string ItemListFormAction::get_guid()
 {
-	const unsigned int itempos = items_list.get_position();
+	const unsigned int itempos = list.get_position();
 	return visible_items[itempos].first->guid();
 }
 
@@ -1252,7 +1241,7 @@ void ItemListFormAction::handle_cmdline_num(unsigned int idx)
 		if (i == -1) {
 			v->show_error(_("Position not visible!"));
 		} else {
-			items_list.set_position(i);
+			list.set_position(i);
 		}
 	} else {
 		v->show_error(_("Invalid position!"));
@@ -1271,7 +1260,7 @@ void ItemListFormAction::handle_cmdline(const std::string& cmd)
 		}
 		if (tokens[0] == "save" && tokens.size() >= 2) {
 			std::string filename = utils::resolve_tilde(tokens[1]);
-			const unsigned int itempos = items_list.get_position();
+			const unsigned int itempos = list.get_position();
 			LOG(Level::INFO,
 				"ItemListFormAction::handle_cmdline: saving item at pos `%u' to `%s'",
 				itempos,
@@ -1302,7 +1291,7 @@ void ItemListFormAction::recalculate_form()
 	FormAction::recalculate_form();
 	invalidate_everything();
 
-	const unsigned int itempos = items_list.get_position();
+	const unsigned int itempos = list.get_position();
 
 	// If the old position was set and it is less than the itempos, use it
 	// for the feed's itempos Correct the problem when you open itemview and
@@ -1310,7 +1299,7 @@ void ItemListFormAction::recalculate_form()
 	// applies when "show-read-articles" is set to false
 	if ((old_itempos != -1) && itempos > (unsigned int)old_itempos &&
 		!cfg->get_configvalue_as_bool("show-read-articles")) {
-		items_list.set_position(old_itempos);
+		list.set_position(old_itempos);
 		old_itempos = -1; // Reset
 	}
 }
@@ -1335,7 +1324,7 @@ void ItemListFormAction::save_article(const std::string& filename,
 
 void ItemListFormAction::save_filterpos()
 {
-	const unsigned int i = items_list.get_position();
+	const unsigned int i = list.get_position();
 	if (i < visible_items.size()) {
 		filterpos = visible_items[i].second;
 		set_filterpos = true;
@@ -1348,9 +1337,9 @@ void ItemListFormAction::register_format_styles()
 	const std::string textview = strprintf::fmt(
 			"{list[items] .expand:vh style_normal[listnormal]: "
 			"style_focus[listfocus]:fg=yellow,bg=blue,attr=bold "
-			"pos[items_pos]:0 %s richtext:1}",
+			"pos[items_pos]:0 offset[items_offset]:0 %s richtext:1}",
 			attrstr);
-	items_list.stfl_replace_list(0, textview);
+	list.stfl_replace_list(0, textview);
 }
 
 std::string ItemListFormAction::gen_flags(std::shared_ptr<RssItem> item)
@@ -1378,12 +1367,12 @@ void ItemListFormAction::prepare_set_filterpos()
 		unsigned int i = 0;
 		for (const auto& item : visible_items) {
 			if (item.second == filterpos) {
-				items_list.set_position(i);
+				list.set_position(i);
 				return;
 			}
 			i++;
 		}
-		items_list.set_position(0);
+		list.set_position(0);
 	}
 }
 
@@ -1402,7 +1391,7 @@ void ItemListFormAction::set_feed(std::shared_ptr<RssFeed> fd)
 std::string ItemListFormAction::title()
 {
 	if (feed->rssurl() == "") {
-		return strprintf::fmt(_("Search Result - '%s'"), searchphrase);
+		return strprintf::fmt(_("Search Result - '%s'"), search_phrase);
 	} else {
 		if (feed->is_query_feed()) {
 			return strprintf::fmt(_("Query Feed - %s"),
