@@ -33,7 +33,7 @@ std::string item_renderer::get_feedtitle(std::shared_ptr<RssItem> item)
 void prepare_header(
 	std::shared_ptr<RssItem> item,
 	std::vector<std::pair<LineType, std::string>>& lines,
-	std::vector<LinkPair>& /*links*/)
+	std::vector<LinkPair>& /*links*/, bool raw = false)
 {
 	const auto add_line =
 		[&lines]
@@ -46,10 +46,22 @@ void prepare_header(
 		}
 	};
 
+	const auto stfl_quote_if_needed =
+		[raw]
+	(const std::string& str) {
+		if (raw) {
+			return str;
+		} else {
+			return utils::quote_for_stfl(str);
+		};
+	};
+
 	const std::string feedtitle = item_renderer::get_feedtitle(item);
-	add_line(feedtitle, _("Feed: "));
-	add_line(item->title(), _("Title: "));
-	add_line(item->author(), _("Author: "));
+	add_line(stfl_quote_if_needed(feedtitle), _("Feed: "));
+	add_line(stfl_quote_if_needed(utils::utf8_to_locale(item->title())),
+		_("Title: "));
+	add_line(stfl_quote_if_needed(utils::utf8_to_locale(item->author())),
+		_("Author: "));
 	add_line(item->pubDate(), _("Date: "));
 	add_line(item->link(), _("Link: "), LineType::softwrappable);
 	add_line(item->flags(), _("Flags: "));
@@ -93,10 +105,10 @@ void render_html(
 		HtmlRenderer rnd(raw);
 		rnd.render(source, lines, thelinks, url);
 	} else {
-		char* argv[4];
-		argv[0] = const_cast<char*>("/bin/sh");
-		argv[1] = const_cast<char*>("-c");
-		argv[2] = const_cast<char*>(renderer.c_str());
+		const char* argv[4];
+		argv[0] = "/bin/sh";
+		argv[1] = "-c";
+		argv[2] = renderer.c_str();
 		argv[3] = nullptr;
 		LOG(Level::DEBUG,
 			"item_renderer::render_html: source = %s",
@@ -125,9 +137,10 @@ std::string item_renderer::to_plain_text(
 	std::vector<std::pair<LineType, std::string>> lines;
 	std::vector<LinkPair> links;
 
-	prepare_header(item, lines, links);
+	prepare_header(item, lines, links, true);
 	const auto base = get_item_base_link(item);
-	render_html(cfg, item->description(), lines, links, base, true);
+	render_html(cfg, utils::utf8_to_locale(item->description()), lines, links,
+		base, true);
 
 	TextFormatter txtfmt;
 	txtfmt.add_lines(lines);
@@ -153,7 +166,7 @@ std::pair<std::string, size_t> item_renderer::to_stfl_list(
 
 	prepare_header(item, lines, links);
 	const std::string baseurl = get_item_base_link(item);
-	const auto body = item->description();
+	const auto body = utils::utf8_to_locale(item->description());
 	render_html(cfg, body, lines, links, baseurl, false);
 
 	TextFormatter txtfmt;
@@ -195,7 +208,8 @@ std::pair<std::string, size_t> item_renderer::source_to_stfl_list(
 	std::vector<LinkPair> links;
 
 	prepare_header(item, lines, links);
-	render_source(lines, utils::quote_for_stfl(item->description()));
+	render_source(lines, utils::quote_for_stfl(utils::utf8_to_locale(
+				item->description())));
 
 	TextFormatter txtfmt;
 	txtfmt.add_lines(lines);
