@@ -243,16 +243,21 @@ bool ItemViewFormAction::process_operation(Operation op,
 	}
 	break;
 	case OP_OPENINBROWSER:
-	case OP_OPENBROWSER_AND_MARK:
+	case OP_OPENBROWSER_AND_MARK: {
 		LOG(Level::INFO, "ItemViewFormAction::process_operation: starting browser");
 		v->set_status(_("Starting browser..."));
-		if (int err = v->open_in_browser(item->link())) {
-			v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
+		const auto exit_code = v->open_in_browser(item->link());
+		if (!exit_code.has_value()) {
+			v->show_error(_("Failed to spawn browser"));
+			return false;
+		} else if (*exit_code != 0) {
+			v->show_error(strprintf::fmt(_("Browser returned error code %i"), *exit_code));
 			return false;
 		}
 
 		v->set_status("");
-		break;
+	}
+	break;
 	case OP_BOOKMARK:
 		if (automatic) {
 			qna_responses.clear();
@@ -335,7 +340,7 @@ bool ItemViewFormAction::process_operation(Operation op,
 	case OP_NEXTUNREAD:
 		LOG(Level::INFO,
 			"ItemViewFormAction::process_operation: jumping to next unread article");
-		if (v->get_next_unread(itemlist.get(), this)) {
+		if (v->get_next_unread(*itemlist, this)) {
 			do_redraw = true;
 		} else {
 			v->pop_current_formaction();
@@ -346,7 +351,7 @@ bool ItemViewFormAction::process_operation(Operation op,
 		LOG(Level::INFO,
 			"ItemViewFormAction::process_operation: jumping to previous unread "
 			"article");
-		if (v->get_previous_unread(itemlist.get(), this)) {
+		if (v->get_previous_unread(*itemlist, this)) {
 			do_redraw = true;
 		} else {
 			v->pop_current_formaction();
@@ -356,7 +361,7 @@ bool ItemViewFormAction::process_operation(Operation op,
 	case OP_NEXT:
 		LOG(Level::INFO,
 			"ItemViewFormAction::process_operation: jumping to next article");
-		if (v->get_next(itemlist.get(), this)) {
+		if (v->get_next(*itemlist, this)) {
 			do_redraw = true;
 		} else {
 			v->pop_current_formaction();
@@ -366,7 +371,7 @@ bool ItemViewFormAction::process_operation(Operation op,
 	case OP_PREV:
 		LOG(Level::INFO,
 			"ItemViewFormAction::process_operation: jumping to previous article");
-		if (v->get_previous(itemlist.get(), this)) {
+		if (v->get_previous(*itemlist, this)) {
 			do_redraw = true;
 		} else {
 			v->pop_current_formaction();
@@ -376,7 +381,7 @@ bool ItemViewFormAction::process_operation(Operation op,
 	case OP_RANDOMUNREAD:
 		LOG(Level::INFO,
 			"ItemViewFormAction::process_operation: jumping to random unread article");
-		if (v->get_random_unread(itemlist.get(), this)) {
+		if (v->get_random_unread(*itemlist, this)) {
 			do_redraw = true;
 		} else {
 			v->pop_current_formaction();
@@ -428,8 +433,12 @@ bool ItemViewFormAction::process_operation(Operation op,
 		if (idx < links.size()) {
 			v->set_status(_("Starting browser..."));
 
-			if (int err = v->open_in_browser(links[idx].first)) {
-				v->show_error(strprintf::fmt(_("Browser returned error code %i"), err));
+			const auto exit_code = v->open_in_browser(links[idx].first);
+			if (!exit_code.has_value()) {
+				v->show_error(_("Failed to spawn browser"));
+				return false;
+			} else if (*exit_code != 0) {
+				v->show_error(strprintf::fmt(_("Browser returned error code %i"), *exit_code));
 				return false;
 			}
 
