@@ -84,15 +84,15 @@ static const std::vector<OpDesc> opdescs = {
 		OP_NEXT,
 		"next",
 		"J",
-		_("Go to next article"),
-		KM_FEEDLIST | KM_ARTICLELIST | KM_ARTICLE
+		_("Go to next entry"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_ARTICLE | KM_DIALOGS | KM_DIRBROWSER | KM_FILEBROWSER | KM_FILTERSELECT | KM_TAGSELECT | KM_URLVIEW | KM_PODBOAT
 	},
 	{
 		OP_PREV,
 		"prev",
 		"K",
-		_("Go to previous article"),
-		KM_FEEDLIST | KM_ARTICLELIST | KM_ARTICLE
+		_("Go to previous entry"),
+		KM_FEEDLIST | KM_ARTICLELIST | KM_ARTICLE | KM_DIALOGS | KM_DIRBROWSER | KM_FILEBROWSER | KM_FILTERSELECT | KM_TAGSELECT | KM_URLVIEW | KM_PODBOAT
 	},
 	{
 		OP_NEXTUNREAD,
@@ -678,8 +678,7 @@ std::string KeyMap::getopname(Operation op)
 	return "<none>";
 }
 
-void KeyMap::handle_action(const std::string& action,
-	const std::vector<std::string>& params)
+void KeyMap::handle_action(const std::string& action, const std::string& params)
 {
 	/*
 	 * The keymap acts as ConfigActionHandler so that all the key-related
@@ -687,92 +686,88 @@ void KeyMap::handle_action(const std::string& action,
 	 */
 	LOG(Level::DEBUG, "KeyMap::handle_action(%s, ...) called", action);
 	if (action == "bind-key") {
-		if (params.size() < 2)
+		const auto tokens = utils::tokenize_quoted(params);
+		if (tokens.size() < 2)
 			throw ConfigHandlerException(
 				ActionHandlerStatus::TOO_FEW_PARAMS);
 		std::string context = "all";
-		if (params.size() >= 3) {
-			context = params[2];
+		if (tokens.size() >= 3) {
+			context = tokens[2];
 		}
 		if (!is_valid_context(context))
 			throw ConfigHandlerException(strprintf::fmt(
 					_("`%s' is not a valid context"), context));
-		Operation op = get_opcode(params[1]);
+		const Operation op = get_opcode(tokens[1]);
 		if (op == OP_NIL) {
 			throw ConfigHandlerException(
 				strprintf::fmt(_("`%s' is not a valid "
 						"key command"),
-					params[1]));
+					tokens[1]));
 		}
-		set_key(op, params[0], context);
+		set_key(op, tokens[0], context);
 	} else if (action == "unbind-key") {
-		if (params.size() < 1) {
+		const auto tokens = utils::tokenize_quoted(params);
+		if (tokens.size() < 1) {
 			throw ConfigHandlerException(
 				ActionHandlerStatus::TOO_FEW_PARAMS);
 		}
 		std::string context = "all";
-		if (params.size() >= 2) {
-			context = params[1];
+		if (tokens.size() >= 2) {
+			context = tokens[1];
 		}
-		if (params[0] == "-a") {
+		if (tokens[0] == "-a") {
 			unset_all_keys(context);
 		} else {
-			unset_key(params[0], context);
+			unset_key(tokens[0], context);
 		}
 	} else if (action == "macro") {
-		if (params.size() < 2) {
+		std::string remaining_params = params;
+		const auto token = utils::extract_token_quoted(remaining_params);
+		const std::vector<MacroCmd> cmds = parse_operation_sequence(remaining_params);
+		if (!token.has_value() || cmds.empty()) {
 			throw ConfigHandlerException(ActionHandlerStatus::TOO_FEW_PARAMS);
 		}
-		auto it = params.begin();
-		std::string macrokey = *it;
-		std::vector<MacroCmd> cmds;
-		MacroCmd tmpcmd;
-		tmpcmd.op = OP_NIL;
-		bool first = true;
-		++it;
-
-		while (it != params.end()) {
-			if (first && *it != ";") {
-				tmpcmd.op = get_opcode(*it);
-				LOG(Level::DEBUG,
-					"KeyMap::handle_action: new operation `%s' (op = %u)",
-					*it,
-					tmpcmd.op);
-				if (tmpcmd.op == OP_NIL) {
-					throw ConfigHandlerException(
-						strprintf::fmt(
-							_("`%s' is not a valid operation"),
-							*it));
-				}
-				first = false;
-			} else {
-				if (*it == ";") {
-					if (tmpcmd.op != OP_NIL) {
-						cmds.push_back(tmpcmd);
-					}
-					tmpcmd.op = OP_NIL;
-					tmpcmd.args.clear();
-					first = true;
-				} else {
-					LOG(Level::DEBUG,
-						"KeyMap::handle_action: new parameter `%s' (op = %u)",
-						*it,
-						tmpcmd.op);
-					tmpcmd.args.push_back(*it);
-				}
-			}
-			++it;
-		}
-		if (tmpcmd.op != OP_NIL) {
-			cmds.push_back(tmpcmd);
-		}
+		const std::string macrokey = token.value();
 
 		macros_[macrokey] = cmds;
+	} else if (action == "run-on-startup") {
+		startup_operations_sequence = parse_operation_sequence(params);
 	} else {
 		throw ConfigHandlerException(ActionHandlerStatus::INVALID_PARAMS);
 	}
 }
 
+
+std::vector<MacroCmd> KeyMap::parse_operation_sequence(const std::string& line)
+{
+	const auto operations = utils::tokenize_quoted(line, ";");
+
+	std::vector<MacroCmd> cmds;
+	for (auto operation : operations) {
+		const auto command_name = utils::extract_token_quoted(operation);
+		if (!command_name.has_value()) {
+			continue;
+		}
+		const auto arguments = utils::tokenize_quoted(operation);
+		MacroCmd cmd;
+		cmd.op = get_opcode(command_name.value());
+		if (cmd.op == OP_NIL) {
+			throw ConfigHandlerException(strprintf::fmt(_("`%s' is not a valid operation"),
+					command_name.value()));
+		}
+		cmd.args = arguments;
+
+		cmds.push_back(cmd);
+	}
+
+	return cmds;
+}
+
+std::vector<MacroCmd> KeyMap::get_startup_operation_sequence()
+{
+	return startup_operations_sequence;
+}
+
 std::vector<std::string> KeyMap::get_keys(Operation op,
 	const std::string& context)
 {
