@@ -7,8 +7,10 @@ namespace newsboat {
 
 ListFormAction::ListFormAction(View* v,
 	std::string formstr,
+	std::string list_name,
 	ConfigContainer* cfg)
 	: FormAction(v, formstr, cfg)
+	, list(list_name, FormAction::f, cfg->get_configvalue_as_int("scrolloff"))
 {
 }
 
@@ -44,13 +46,33 @@ bool ListFormAction::process_operation(Operation op,
 	case OP_CMD_START_9:
 		FormAction::start_cmdline("9");
 		break;
+
+	case OP_SK_UP:
+		list.move_up(cfg->get_configvalue_as_bool("wrap-scroll"));
+		break;
+	case OP_SK_DOWN:
+		list.move_down(cfg->get_configvalue_as_bool("wrap-scroll"));
+		break;
+	case OP_SK_HOME:
+		list.move_to_first();
+		break;
+	case OP_SK_END:
+		list.move_to_last();
+		break;
+	case OP_SK_PGUP:
+		list.move_page_up(cfg->get_configvalue_as_bool("wrap-scroll"));
+		break;
+	case OP_SK_PGDOWN:
+		list.move_page_down(cfg->get_configvalue_as_bool("wrap-scroll"));
+		break;
 	default:
 		break;
 	}
 	return true;
 }
 
-int ListFormAction::open_unread_items_in_browser(std::shared_ptr<RssFeed> feed,
+nonstd::optional<std::uint8_t> ListFormAction::open_unread_items_in_browser(
+	std::shared_ptr<RssFeed> feed,
 	bool markread)
 {
 	int tabcount = 0;
@@ -58,9 +80,11 @@ int ListFormAction::open_unread_items_in_browser(std::shared_ptr<RssFeed> feed,
 		if (tabcount <
 			cfg->get_configvalue_as_int("max-browser-tabs")) {
 			if (item->unread()) {
-				if (int err = v->open_in_browser(item->link())) {
-					return err;
+				const auto exit_code = v->open_in_browser(item->link());
+				if (!exit_code.has_value() || *exit_code != 0) {
+					return exit_code;
 				}
+
 				tabcount += 1;
 				item->set_unread(!markread);
 			}
