@@ -1,6 +1,7 @@
 #include "matcherexception.h"
 
 #include "config.h"
+#include "ruststring.h"
 #include "strprintf.h"
 
 namespace newsboat {
@@ -23,4 +24,11 @@ const char* MatcherException::what() const throw()
 	return errmsg.c_str();
 }
 
+MatcherException MatcherException::from_rust_error(MatcherErrorFfi error)
+{
+	const std::string info = RustString(error.info);
+	const std::string info2 = RustString(error.info2);
+	return MatcherException(error.type, info, info2);
+}
+
 } // namespace newsboat
