@@ -1,6 +1,8 @@
 #include "queueloader.h"
 
+#include <cerrno>
 #include <cstdlib>
+#include <cstdio>
 #include <cstring>
 #include <fstream>
 #include <iostream>
@@ -18,15 +20,19 @@ using namespace newsboat;
 
 namespace podboat {
 
-QueueLoader::QueueLoader(const std::string& file, PbController* c)
+QueueLoader::QueueLoader(const std::string& file, ConfigContainer& cfg_,
+	std::function<void()> cb_require_view_update_)
 	: queuefile(file)
-	, ctrl(c)
+	, cfg(cfg_)
+	, cb_require_view_update(cb_require_view_update_)
 {
 }
 
-void QueueLoader::reload(std::vector<Download>& downloads, bool remove_unplayed)
+void QueueLoader::reload(std::vector<Download>& downloads,
+	bool also_remove_finished)
 {
 	std::vector<Download> dltemp;
+	std::vector<Download> deletion_list;
 	std::fstream f;
 
 	for (const auto& dl : downloads) {
@@ -37,31 +43,38 @@ void QueueLoader::reload(std::vector<Download>& downloads, bool remove_unplayed)
 				"DlStatus::DOWNLOADING status");
 			return;
 		}
+		bool keep_entry = false;
 		switch (dl.status()) {
 		case DlStatus::QUEUED:
 		case DlStatus::CANCELLED:
 		case DlStatus::FAILED:
 		case DlStatus::ALREADY_DOWNLOADED:
 		case DlStatus::READY:
+		case DlStatus::PLAYED:
 			LOG(Level::DEBUG,
 				"QueueLoader::reload: storing %s to new vector",
 				dl.url());
-			dltemp.push_back(dl);
+			keep_entry = true;
 			break;
-		case DlStatus::PLAYED:
 		case DlStatus::FINISHED:
-			if (!remove_unplayed) {
+			if (!also_remove_finished) {
 				LOG(Level::DEBUG,
 					"QueueLoader::reload: storing %s to "
 					"new "
 					"vector",
 					dl.url());
-				dltemp.push_back(dl);
+				keep_entry = true;
 			}
 			break;
 		default:
 			break;
 		}
+
+		if (keep_entry) {
+			dltemp.push_back(dl);
+		} else {
+			deletion_list.push_back(dl);
+		}
 	}
 
 	f.open(queuefile.c_str(), std::fstream::in);
@@ -107,13 +120,13 @@ void QueueLoader::reload(std::vector<Download>& downloads, bool remove_unplayed)
 					}
 				}
 
-				for (const auto& dl : downloads) {
+				for (const auto& dl : deletion_list) {
 					if (fields[0] == dl.url()) {
 						LOG(Level::INFO,
 							"QueueLoader::reload: "
-							"found `%s' in new "
+							"found `%s' in scheduled for deletion "
 							"vector",
-							line);
+							fields[0]);
 						url_found = true;
 						break;
 					}
@@ -126,7 +139,7 @@ void QueueLoader::reload(std::vector<Download>& downloads, bool remove_unplayed)
 						"nowhere -> storing to new "
 						"vector",
 						line);
-					Download d(ctrl);
+					Download d(cb_require_view_update);
 					std::string fn;
 					if (fields.size() == 1) {
 						fn = get_filename(fields[0]);
@@ -153,6 +166,11 @@ void QueueLoader::reload(std::vector<Download>& downloads, bool remove_unplayed)
 								d.set_status(
 									DlStatus::
 									PLAYED);
+							if (fields[2] ==
+								"finished")
+								d.set_status(
+									DlStatus::
+									FINISHED);
 						} else
 							d.set_status(DlStatus::
 								ALREADY_DOWNLOADED); // TODO: scrap DlStatus::ALREADY_DOWNLOADED state
@@ -193,20 +211,39 @@ void QueueLoader::reload(std::vector<Download>& downloads, bool remove_unplayed)
 			if (dl.status() == DlStatus::PLAYED) {
 				f << " played";
 			}
+			if (dl.status() == DlStatus::FINISHED) {
+				f << " finished";
+			}
 			f << std::endl;
 		}
 		f.close();
 	}
 
+	if (cfg.get_configvalue_as_bool("delete-played-files")) {
+		for (const auto& dl : deletion_list) {
+			const std::string filename = dl.filename();
+			LOG(Level::INFO,
+				"Deleting file %s",
+				filename);
+			if (std::remove(filename.c_str()) != 0) {
+				if (errno != ENOENT) {
+					LOG(Level::ERROR,
+						"Failed to delete file %s, error code: %d (%s)",
+						filename, errno, strerror(errno));
+				}
+			}
+		}
+	}
+
 	downloads = dltemp;
 }
 
 std::string QueueLoader::get_filename(const std::string& str)
 {
-	std::string fn = ctrl->get_dlpath();
+	std::string fn = cfg.get_configvalue("download-path");
 
-	if (fn[fn.length() - 1] != NEWSBEUTER_PATH_SEP[0]) {
-		fn.append(NEWSBEUTER_PATH_SEP);
+	if (fn[fn.length() - 1] != NEWSBEUTER_PATH_SEP) {
+		fn.push_back(NEWSBEUTER_PATH_SEP);
 	}
 	char buf[1024];
 	snprintf(buf, sizeof(buf), "%s", str.c_str());
