@@ -64,12 +64,12 @@ std::string QueueManager::generate_enqueue_filename(std::shared_ptr<RssItem>
 	std::shared_ptr<RssFeed> feed)
 {
 	const std::string& url = item->enclosure_url();
-	const std::string& title = item->title();
+	const std::string& title = utils::utf8_to_locale(item->title());
 	const time_t pubDate = item->pubDate_timestamp();
 
 	std::string dlformat = cfg->get_configvalue("download-path");
-	if (dlformat[dlformat.length() - 1] != NEWSBEUTER_PATH_SEP[0]) {
-		dlformat.append(NEWSBEUTER_PATH_SEP);
+	if (dlformat[dlformat.length() - 1] != NEWSBEUTER_PATH_SEP) {
+		dlformat.push_back(NEWSBEUTER_PATH_SEP);
 	}
 
 	const std::string filemask = cfg->get_configvalue("download-filename-format");
@@ -100,8 +100,7 @@ std::string QueueManager::generate_enqueue_filename(std::shared_ptr<RssItem>
 
 	if (feed->rssurl() != item->feedurl() &&
 		item->get_feedptr() != nullptr) {
-		std::string feedtitle = utils::quote_for_stfl(
-				item->get_feedptr()->title());
+		std::string feedtitle = item->get_feedptr()->title();
 		utils::remove_soft_hyphens(feedtitle);
 		fmt.register_fmt('N', feedtitle);
 	} else {
