@@ -40,7 +40,6 @@ RssFeed::RssFeed(Cache* c)
 
 RssFeed::~RssFeed()
 {
-	clear_items();
 }
 
 unsigned int RssFeed::unread_item_count()
@@ -63,7 +62,12 @@ bool RssFeed::matches_tag(const std::string& tag)
 
 std::string RssFeed::get_firsttag()
 {
-	return tags_.empty() ? "" : tags_.front();
+	for (const auto& t : tags_) {
+		if (t.substr(0, 1) != "~") {
+			return t;
+		}
+	}
+	return "";
 }
 
 std::string RssFeed::get_tags()
@@ -203,8 +207,7 @@ void RssFeed::set_rssurl(const std::string& u)
 		 * query:Title:unread = "yes" and age between 0:7
 		 *
 		 * So we split by colons to get title and the query itself. */
-		std::vector<std::string> tokens =
-			utils::tokenize_quoted(u, ":");
+		const auto tokens = utils::tokenize(u, ":");
 
 		if (tokens.size() < 3) {
 			throw _s("too few arguments");
