@@ -7,6 +7,7 @@
 #include "cache.h"
 #include "dbexception.h"
 #include "rssfeed.h"
+#include "scopemeasure.h"
 #include "strprintf.h"
 #include "utils.h"
 
@@ -47,6 +48,7 @@ void RssItem::set_author(const std::string& a)
 
 void RssItem::set_description(const std::string& d)
 {
+	std::lock_guard<std::mutex> guard(description_mutex);
 	description_ = d;
 }
 
@@ -144,7 +146,15 @@ nonstd::optional<std::string> RssItem::attribute_value(const std::string&
 	} else if (attribname == "author") {
 		return utils::utf8_to_locale(author());
 	} else if (attribname == "content") {
-		return utils::utf8_to_locale(description());
+		ScopeMeasure sm("RssItem::attribute_value(\"content\")");
+		std::lock_guard<std::mutex> guard(description_mutex);
+		if (description_.has_value()) {
+			return utils::utf8_to_locale(description_.value());
+		} else if (ch) {
+			std::string description = ch->fetch_description(this);
+			return utils::utf8_to_locale(description);
+		}
+		return "";
 	} else if (attribname == "date") {
 		return pubDate();
 	} else if (attribname == "guid") {
