@@ -152,7 +152,7 @@ json TtRssApi::run_op(const std::string& op,
 	}
 
 	std::string result = utils::retrieve_url(
-			url, cfg, auth_info, &req_data, cached_handle);
+			url, cfg, auth_info, &req_data, utils::HTTPMethod::POST, cached_handle);
 
 	LOG(Level::DEBUG,
 		"TtRssApi::run_op(%s,...): post=%s reply = %s",
@@ -415,16 +415,13 @@ rsspp::Feed TtRssApi::fetch_feed(const std::string& id, CURL* cached_handle)
 			}
 
 			if (!item_obj["attachments"].is_null()) {
-				if (item_obj["attachments"].size() >= 1) {
-					json a =
-						item_obj["attachments"].front();
-					if (!a["content_url"].is_null()) {
-						item.enclosure_url =
-							a["content_url"];
-					}
-					if (!a["content_type"].is_null()) {
+				for (const json& a : item_obj["attachments"]) {
+					if (!a["content_url"].is_null() && !a["content_type"].is_null()
+						&& newsboat::utils::is_valid_podcast_type(a["content_type"])) {
 						item.enclosure_type =
 							a["content_type"];
+						item.enclosure_url = a["content_url"];
+						break;
 					}
 				}
 			}
