@@ -46,6 +46,8 @@ GCRY_THREAD_OPTION_PTHREAD_IMPL;
 
 #include "rs_utils.h"
 
+using HTTPMethod = newsboat::utils::HTTPMethod;
+
 namespace newsboat {
 
 namespace utils {
@@ -110,50 +112,65 @@ std::vector<std::string> utils::tokenize_quoted(const std::string& str,
 	 *
 	 */
 	std::vector<std::string> tokens;
-	std::string::size_type last_pos = str.find_first_not_of(delimiters, 0);
-	std::string::size_type pos = last_pos;
-
-	while (pos != std::string::npos && last_pos != std::string::npos) {
-		if (str[last_pos] == '#') { // stop as soon as we found a comment
-			break;
+	std::string remaining = str;
+	while (!remaining.empty()) {
+		auto token = extract_token_quoted(remaining, delimiters);
+		if (token.has_value()) {
+			tokens.push_back(token.value());
 		}
-
-		if (str[last_pos] == '"') {
-			++last_pos;
-			pos = last_pos;
-
-			std::string token;
-			while (pos < str.length()) {
-				if (str[pos] == '"') {
-					// We've reached the end of this quoted token.
-					++pos;
-					break;
-				} else if (str[pos] == '\\') {
-					if (pos + 1 < str.length()) {
-						append_escapes(token, str[pos + 1]);
-					}
-					pos += 2;
-				} else {
-					token.push_back(str[pos]);
-					++pos;
-				}
-			}
-			tokens.push_back(token);
-
-			if (pos == str.length()) {
-				pos = std::string::npos;
-			}
-		} else {
-			pos = str.find_first_of(delimiters, last_pos);
-			tokens.push_back(str.substr(last_pos, pos - last_pos));
-		}
-
-		last_pos = str.find_first_not_of(delimiters, pos);
 	}
 
 	return tokens;
 }
 
+nonstd::optional<std::string> utils::extract_token_quoted(std::string& str,
+	std::string delimiters)
+{
+	auto first_non_delimiter = str.find_first_not_of(delimiters, 0);
+	if (first_non_delimiter == std::string::npos) {
+		str = "";
+		return {};
+	}
+	str = str.substr(first_non_delimiter);
+
+	if (str[0] == '#') { // stop as soon as we find a comment
+		str = "";
+		return {};
+	}
+
+	std::string token;
+	if (str[0] == '"') {
+		std::string::size_type pos = 1;
+		while (pos < str.length()) {
+			if (str[pos] == '"') {
+				// We've reached the end of this quoted token.
+				++pos;
+				break;
+			} else if (str[pos] == '\\') {
+				pos += 1;
+				if (pos < str.length()) {
+					append_escapes(token, str[pos]);
+					pos += 1;
+				}
+			} else {
+				token.push_back(str[pos]);
+				++pos;
+			}
+		}
+		str = str.substr(pos);
+	} else {
+		auto end_of_token = str.find_first_of(delimiters);
+		token = str.substr(0, end_of_token);
+		if (end_of_token == std::string::npos) {
+			str = "";
+		} else {
+			str = str.substr(end_of_token);
+		}
+	}
+
+	return token;
+}
+
 std::vector<std::string> utils::tokenize(const std::string& str,
 	std::string delimiters)
 {
@@ -172,24 +189,6 @@ std::vector<std::string> utils::tokenize(const std::string& str,
 	return tokens;
 }
 
-std::vector<std::wstring> utils::wtokenize(const std::wstring& str,
-	std::wstring delimiters)
-{
-	/*
-	 * This function tokenizes a string by the delimiters. Plain and simple.
-	 */
-	std::vector<std::wstring> tokens;
-	std::wstring::size_type last_pos = str.find_first_not_of(delimiters, 0);
-	std::wstring::size_type pos = str.find_first_of(delimiters, last_pos);
-
-	while (std::string::npos != pos || std::string::npos != last_pos) {
-		tokens.push_back(str.substr(last_pos, pos - last_pos));
-		last_pos = str.find_first_not_of(delimiters, pos);
-		pos = str.find_first_of(delimiters, last_pos);
-	}
-	return tokens;
-}
-
 std::vector<std::string> utils::tokenize_spaced(const std::string& str,
 	std::string delimiters)
 {
@@ -419,10 +418,33 @@ static size_t my_write_data(void* buffer, size_t size, size_t nmemb,
 	return size * nmemb;
 }
 
+std::string utils::http_method_str(const HTTPMethod method)
+{
+	std::string str = "";
+
+	switch (method) {
+	case HTTPMethod::GET:
+		str = "GET";
+		break;
+	case HTTPMethod::POST:
+		str = "POST";
+		break;
+	case HTTPMethod::PUT:
+		str = "PUT";
+		break;
+	case HTTPMethod::DELETE:
+		str = "DELETE";
+		break;
+	}
+
+	return str;
+}
+
 std::string utils::retrieve_url(const std::string& url,
 	ConfigContainer* cfgcont,
 	const std::string& authinfo,
-	const std::string* postdata,
+	const std::string* body,
+	const HTTPMethod method, /* = GET */
 	CURL* cached_handle)
 {
 	std::string buf;
@@ -438,10 +460,22 @@ std::string utils::retrieve_url(const std::string& url,
 	curl_easy_setopt(easyhandle, CURLOPT_WRITEFUNCTION, my_write_data);
 	curl_easy_setopt(easyhandle, CURLOPT_WRITEDATA, &buf);
 
-	if (postdata != nullptr) {
+	switch (method) {
+	case HTTPMethod::GET:
+		break;
+	case HTTPMethod::POST:
 		curl_easy_setopt(easyhandle, CURLOPT_POST, 1);
+		break;
+	case HTTPMethod::PUT:
+	case HTTPMethod::DELETE:
+		const std::string method_str = http_method_str(method);
+		curl_easy_setopt(easyhandle, CURLOPT_CUSTOMREQUEST, method_str.c_str());
+		break;
+	}
+
+	if (body != nullptr) {
 		curl_easy_setopt(
-			easyhandle, CURLOPT_POSTFIELDS, postdata->c_str());
+			easyhandle, CURLOPT_POSTFIELDS, body->c_str());
 	}
 
 	if (!authinfo.empty()) {
@@ -457,11 +491,12 @@ std::string utils::retrieve_url(const std::string& url,
 		curl_easy_cleanup(easyhandle);
 	}
 
-	if (postdata != nullptr) {
+	if (body != nullptr) {
 		LOG(Level::DEBUG,
-			"utils::retrieve_url(%s)[%s]: %s",
+			"utils::retrieve_url(%s %s)[%s]: %s",
+			http_method_str(method),
 			url,
-			postdata,
+			body,
 			buf);
 	} else {
 		LOG(Level::DEBUG, "utils::retrieve_url(%s)[-]: %s", url, buf);
@@ -595,28 +630,6 @@ size_t utils::strwidth_stfl(const std::string& str)
 	return rs_strwidth_stfl(str.c_str());
 }
 
-size_t utils::wcswidth_stfl(const std::wstring& str, size_t size)
-{
-	size_t reduce_count = 0;
-	size_t len = std::min(str.length(), size);
-	if (len > 1) {
-		for (size_t idx = 0; idx < len - 1; ++idx) {
-			if (str[idx] == L'<' && str[idx + 1] != L'>') {
-				reduce_count += 3;
-				idx += 3;
-			}
-		}
-	}
-
-	int width = wcswidth(str.c_str(), size);
-	if (width < 0) {
-		LOG(Level::ERROR, "oh, oh, wcswidth just failed");
-		return str.length() - reduce_count;
-	}
-
-	return width - reduce_count;
-}
-
 std::string utils::substr_with_width(const std::string& str,
 	const size_t max_width)
 {
@@ -870,10 +883,18 @@ std::string utils::make_title(const std::string& const_url)
 	return RustString(rs_make_title(const_url.c_str()));
 }
 
-int32_t utils::run_interactively(const std::string& command,
+nonstd::optional<std::uint8_t> utils::run_interactively(
+	const std::string& command,
 	const std::string& caller)
 {
-	return rs_run_interactively(command.c_str(), caller.c_str());
+	bool success = false;
+	const auto exit_code = rs_run_interactively(command.c_str(), caller.c_str(),
+			&success);
+	if (success) {
+		return exit_code;
+	}
+
+	return nonstd::nullopt;
 }
 
 std::string utils::getcwd()
