@@ -29,7 +29,6 @@ extern "C" {
 #include "dialogsformaction.h"
 #include "exception.h"
 #include "feedlist.h"
-#include "feedlistformaction.h"
 #include "filebrowser.h"
 #include "fmtstrformatter.h"
 #include "formaction.h"
@@ -70,6 +69,7 @@ View::View(Controller* c)
 	, tab_count(0)
 	, rsscache(nullptr)
 	, filters(ctrl->get_filtercontainer())
+	, colorman(ctrl->get_colormanager())
 {
 	if (getenv("ESCDELAY") == nullptr) {
 		set_escdelay(25);
@@ -118,16 +118,31 @@ void View::show_error(const std::string& msg)
 	set_status(msg);
 }
 
+bool View::run_commands(const std::vector<MacroCmd>& commands)
+{
+	for (auto command : commands) {
+		if (formaction_stack_size() == 0) {
+			return true;
+		}
+		std::shared_ptr<FormAction> fa = get_current_formaction();
+		fa->prepare();
+		fa->get_form().run(-1);
+		if (!fa->process_op(command.op, true, &command.args)) {
+			// Operation failed, abort
+			return false;
+		}
+	}
+	return true;
+}
+
 int View::run()
 {
 	bool have_macroprefix = false;
-	std::vector<MacroCmd> macrocmds;
 
-	// create feedlist
-	auto feedlist = std::make_shared<FeedListFormAction>(
+	feedlist_form = std::make_shared<FeedListFormAction>(
 			this, feedlist_str, rsscache, filters, cfg, rxman);
-	apply_colors(feedlist);
-	formaction_stack.push_back(feedlist);
+	apply_colors(feedlist_form);
+	formaction_stack.push_back(feedlist_form);
 	current_formaction = formaction_stack_size() - 1;
 
 	get_current_formaction()->init();
@@ -136,6 +151,12 @@ int View::run()
 
 	curs_set(0);
 
+	if (!run_commands(keys->get_startup_operation_sequence())) {
+		Stfl::reset();
+		std::cerr << _("Error: Failed to execute startup commands") << std::endl;
+		return EXIT_FAILURE;
+	}
+
 	/*
 	 * This is the main "event" loop of newsboat.
 	 */
@@ -147,93 +168,79 @@ int View::run()
 		// we signal "oh, you will receive an operation soon"
 		fa->prepare();
 
-		if (!macrocmds.empty()) {
-			// if there is any macro command left to process, we do
-			// so
+		// we then receive the event and ignore timeouts.
+		const char* event = fa->get_form().run(60000);
 
-			fa->get_form().run(-1);
-			if (!fa->process_op(
-					macrocmds[0].op, true, &macrocmds[0].args)) {
-
-				// Operation failed, abort
-				macrocmds.clear();
-			} else {
-				// remove first macro command, since it has already been processed
-				macrocmds.erase(macrocmds.begin());
-			}
-		} else {
-			// we then receive the event and ignore timeouts.
-			const char* event = fa->get_form().run(60000);
-
-			if (ctrl_c_hit) {
-				ctrl_c_hit = false;
-				cancel_input(fa);
-				if (!get_cfg()->get_configvalue_as_bool(
-						"confirm-exit") ||
-					confirm(_("Do you really want to quit "
-							"(y:Yes n:No)? "),
-						_("yn")) == *_("y")) {
-					Stfl::reset();
-					return EXIT_FAILURE;
-				}
-			}
-
-			if (!event || strcmp(event, "TIMEOUT") == 0) {
-				continue;
-			}
-
-			if (is_inside_qna) {
-				LOG(Level::DEBUG,
-					"View::run: we're inside QNA input");
-				if (is_inside_cmdline &&
-					strcmp(event, "TAB") == 0) {
-					handle_cmdline_completion(fa);
-					continue;
-				}
-				if (strcmp(event, "^U") == 0) {
-					clear_line(fa);
-					continue;
-				} else if (strcmp(event, "^K") == 0) {
-					clear_eol(fa);
-					continue;
-				} else if (strcmp(event, "^G") == 0) {
-					cancel_input(fa);
-					continue;
-				} else if (strcmp(event, "^W") == 0) {
-					delete_word(fa);
-					continue;
-				}
-			}
-
-			LOG(Level::DEBUG, "View::run: event = %s", event);
-
-			if (have_macroprefix) {
-				have_macroprefix = false;
-				LOG(Level::DEBUG,
-					"View::run: running macro `%s'",
-					event);
-				macrocmds = keys->get_macro(event);
-				set_status("");
-			} else {
-				const Operation op = keys->get_operation(event, fa->id());
-
-				LOG(Level::DEBUG,
-					"View::run: event = %s op = %u",
-					event,
-					op);
-
-				if (OP_MACROPREFIX == op) {
-					have_macroprefix = true;
-					set_status("macro-");
-				}
-
-				// now we handle the operation to the
-				// formaction.
-				fa->process_op(op);
+		if (ctrl_c_hit) {
+			ctrl_c_hit = false;
+			cancel_input(fa);
+			if (!get_cfg()->get_configvalue_as_bool(
+					"confirm-exit") ||
+				confirm(_("Do you really want to quit "
+						"(y:Yes n:No)? "),
+					_("yn")) == *_("y")) {
+				Stfl::reset();
+				return EXIT_FAILURE;
 			}
 		}
+
+		if (!event || strcmp(event, "TIMEOUT") == 0) {
+			continue;
+		}
+
+		if (is_inside_qna) {
+			LOG(Level::DEBUG,
+				"View::run: we're inside QNA input");
+			if (is_inside_cmdline &&
+				strcmp(event, "TAB") == 0) {
+				handle_cmdline_completion(fa);
+				continue;
+			}
+			if (strcmp(event, "^U") == 0) {
+				clear_line(fa);
+				continue;
+			} else if (strcmp(event, "^K") == 0) {
+				clear_eol(fa);
+				continue;
+			} else if (strcmp(event, "^G") == 0) {
+				cancel_input(fa);
+				continue;
+			} else if (strcmp(event, "^W") == 0) {
+				delete_word(fa);
+				continue;
+			}
+		}
+
+		LOG(Level::DEBUG, "View::run: event = %s", event);
+
+		if (have_macroprefix) {
+			have_macroprefix = false;
+			LOG(Level::DEBUG,
+				"View::run: running macro `%s'",
+				event);
+			run_commands(keys->get_macro(event));
+			set_status("");
+		} else {
+			const Operation op = keys->get_operation(event, fa->id());
+
+			LOG(Level::DEBUG,
+				"View::run: event = %s op = %u",
+				event,
+				op);
+
+			if (OP_MACROPREFIX == op) {
+				have_macroprefix = true;
+				set_status("macro-");
+			}
+
+			// now we handle the operation to the
+			// formaction.
+			fa->process_op(op);
+		}
 	}
 
+	feedlist_form.reset();
+
 	Stfl::reset();
 	return EXIT_SUCCESS;
 }
@@ -332,7 +339,7 @@ void View::open_in_pager(const std::string& filename)
 	pop_current_formaction();
 }
 
-int View::open_in_browser(const std::string& url)
+nonstd::optional<std::uint8_t> View::open_in_browser(const std::string& url)
 {
 	formaction_stack.push_back(std::shared_ptr<FormAction>());
 	current_formaction = formaction_stack_size() - 1;
@@ -350,7 +357,7 @@ int View::open_in_browser(const std::string& url)
 		cmdline.append(" " + escaped_url);
 	}
 	Stfl::reset();
-	const int ret = utils::run_interactively(cmdline, "View::open_in_browser");
+	const auto ret = utils::run_interactively(cmdline, "View::open_in_browser");
 	pop_current_formaction();
 	return ret;
 }
@@ -358,12 +365,9 @@ int View::open_in_browser(const std::string& url)
 void View::update_visible_feeds(std::vector<std::shared_ptr<RssFeed>> feeds)
 {
 	try {
-		if (formaction_stack_size() > 0) {
+		if (feedlist_form != nullptr) {
 			std::lock_guard<std::mutex> lock(mtx);
-			std::shared_ptr<FeedListFormAction> feedlist =
-				std::dynamic_pointer_cast<FeedListFormAction,
-				FormAction>(formaction_stack[0]);
-			feedlist->update_visible_feeds(feeds);
+			feedlist_form->update_visible_feeds(feeds);
 		}
 	} catch (const MatcherException& e) {
 		set_status(strprintf::fmt(
@@ -385,11 +389,8 @@ void View::set_feedlist(std::vector<std::shared_ptr<RssFeed>> feeds)
 			}
 		}
 
-		if (formaction_stack_size() > 0) {
-			std::shared_ptr<FeedListFormAction> feedlist =
-				std::dynamic_pointer_cast<FeedListFormAction,
-				FormAction>(formaction_stack[0]);
-			feedlist->set_feedlist(feeds);
+		if (feedlist_form != nullptr) {
+			feedlist_form->set_feedlist(feeds);
 		}
 	} catch (const MatcherException& e) {
 		set_status(strprintf::fmt(
@@ -425,7 +426,8 @@ void View::push_searchresult(std::shared_ptr<RssFeed> feed,
 	}
 }
 
-void View::push_itemlist(std::shared_ptr<RssFeed> feed)
+std::shared_ptr<ItemListFormAction> View::push_itemlist(
+	std::shared_ptr<RssFeed> feed)
 {
 	assert(feed != nullptr);
 
@@ -444,8 +446,10 @@ void View::push_itemlist(std::shared_ptr<RssFeed> feed)
 		itemlist->init();
 		formaction_stack.push_back(itemlist);
 		current_formaction = formaction_stack_size() - 1;
+		return itemlist;
 	} else {
 		show_error(_("Error: feed contains no items!"));
+		return nullptr;
 	}
 }
 
@@ -456,14 +460,9 @@ void View::push_itemlist(unsigned int pos)
 	LOG(Level::DEBUG,
 		"View::push_itemlist: retrieved feed at position %d",
 		pos);
-	push_itemlist(feed);
-	if (feed->total_item_count() > 0) {
-		std::shared_ptr<ItemListFormAction> itemlist =
-			std::dynamic_pointer_cast<ItemListFormAction,
-			FormAction>(get_current_formaction());
-		if (itemlist) {
-			itemlist->set_pos(pos);
-		}
+	auto itemlist = push_itemlist(feed);
+	if (itemlist) {
+		itemlist->set_pos(pos);
 	}
 }
 
@@ -661,28 +660,25 @@ void View::notify_itemlist_change(std::shared_ptr<RssFeed> feed)
 	}
 }
 
-bool View::get_random_unread(ItemListFormAction* itemlist,
+bool View::get_random_unread(ItemListFormAction& itemlist,
 	ItemViewFormAction* itemview)
 {
 	unsigned int feedpos;
-	std::shared_ptr<FeedListFormAction> feedlist =
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0]);
 	if (!cfg->get_configvalue_as_bool("goto-next-feed")) {
 		return false;
 	}
-	if (feedlist->jump_to_random_unread_feed(feedpos)) {
+	if (feedlist_form->jump_to_random_unread_feed(feedpos)) {
 		LOG(Level::DEBUG,
-			"View::get_previous_unread: found feed with unread "
+			"View::get_random_unread: found feed with unread "
 			"articles");
-		prepare_query_feed(feedlist->get_feed());
-		itemlist->set_feed(feedlist->get_feed());
-		itemlist->set_pos(feedpos);
-		itemlist->init();
-		if (itemlist->jump_to_random_unread_item()) {
+		prepare_query_feed(feedlist_form->get_feed());
+		itemlist.set_feed(feedlist_form->get_feed());
+		itemlist.set_pos(feedpos);
+		itemlist.init();
+		if (itemlist.jump_to_random_unread_item()) {
 			if (itemview) {
-				itemview->set_feed(itemlist->get_feed());
-				itemview->set_guid(itemlist->get_guid());
+				itemview->set_feed(itemlist.get_feed());
+				itemview->set_guid(itemlist.get_guid());
 				itemview->init();
 			}
 			return true;
@@ -691,23 +687,20 @@ bool View::get_random_unread(ItemListFormAction* itemlist,
 	return false;
 }
 
-bool View::get_previous_unread(ItemListFormAction* itemlist,
+bool View::get_previous_unread(ItemListFormAction& itemlist,
 	ItemViewFormAction* itemview)
 {
 	unsigned int feedpos;
 	LOG(Level::DEBUG,
 		"View::get_previous_unread: trying to find previous unread");
-	std::shared_ptr<FeedListFormAction> feedlist =
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0]);
-	if (itemlist->jump_to_previous_unread_item(false)) {
+	if (itemlist.jump_to_previous_unread_item(false)) {
 		LOG(Level::DEBUG,
 			"View::get_previous_unread: found unread article in "
 			"same "
 			"feed");
 		if (itemview) {
-			itemview->set_feed(itemlist->get_feed());
-			itemview->set_guid(itemlist->get_guid());
+			itemview->set_feed(itemlist.get_feed());
+			itemview->set_guid(itemlist.get_guid());
 			itemview->init();
 		}
 		return true;
@@ -715,18 +708,18 @@ bool View::get_previous_unread(ItemListFormAction* itemlist,
 		LOG(Level::DEBUG,
 			"View::get_previous_unread: goto-next-feed = false");
 		show_error(_("No unread items."));
-	} else if (feedlist->jump_to_previous_unread_feed(feedpos)) {
+	} else if (feedlist_form->jump_to_previous_unread_feed(feedpos)) {
 		LOG(Level::DEBUG,
 			"View::get_previous_unread: found feed with unread "
 			"articles");
-		prepare_query_feed(feedlist->get_feed());
-		itemlist->set_feed(feedlist->get_feed());
-		itemlist->set_pos(feedpos);
-		itemlist->init();
-		if (itemlist->jump_to_previous_unread_item(true)) {
+		prepare_query_feed(feedlist_form->get_feed());
+		itemlist.set_feed(feedlist_form->get_feed());
+		itemlist.set_pos(feedpos);
+		itemlist.init();
+		if (itemlist.jump_to_previous_unread_item(true)) {
 			if (itemview) {
-				itemview->set_feed(itemlist->get_feed());
-				itemview->set_guid(itemlist->get_guid());
+				itemview->set_feed(itemlist.get_feed());
+				itemview->set_guid(itemlist.get_guid());
 				itemview->init();
 			}
 			return true;
@@ -735,55 +728,44 @@ bool View::get_previous_unread(ItemListFormAction* itemlist,
 	return false;
 }
 
-bool View::get_next_unread_feed(ItemListFormAction* itemlist)
+bool View::get_next_unread_feed(ItemListFormAction& itemlist)
 {
-	std::shared_ptr<FeedListFormAction> feedlist =
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0]);
 	unsigned int feedpos;
-	assert(feedlist != nullptr);
-	if (feedlist->jump_to_next_unread_feed(feedpos)) {
-		prepare_query_feed(feedlist->get_feed());
-		itemlist->set_feed(feedlist->get_feed());
-		itemlist->set_pos(feedpos);
-		itemlist->init();
+	if (feedlist_form->jump_to_next_unread_feed(feedpos)) {
+		prepare_query_feed(feedlist_form->get_feed());
+		itemlist.set_feed(feedlist_form->get_feed());
+		itemlist.set_pos(feedpos);
+		itemlist.init();
 		return true;
 	}
 	return false;
 }
 
-bool View::get_prev_unread_feed(ItemListFormAction* itemlist)
+bool View::get_prev_unread_feed(ItemListFormAction& itemlist)
 {
-	std::shared_ptr<FeedListFormAction> feedlist =
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0]);
 	unsigned int feedpos;
-	assert(feedlist != nullptr);
-	if (feedlist->jump_to_previous_unread_feed(feedpos)) {
-		prepare_query_feed(feedlist->get_feed());
-		itemlist->set_feed(feedlist->get_feed());
-		itemlist->set_pos(feedpos);
-		itemlist->init();
+	if (feedlist_form->jump_to_previous_unread_feed(feedpos)) {
+		prepare_query_feed(feedlist_form->get_feed());
+		itemlist.set_feed(feedlist_form->get_feed());
+		itemlist.set_pos(feedpos);
+		itemlist.init();
 		return true;
 	}
 	return false;
 }
 
-bool View::get_next_unread(ItemListFormAction* itemlist,
+bool View::get_next_unread(ItemListFormAction& itemlist,
 	ItemViewFormAction* itemview)
 {
 	unsigned int feedpos;
-	std::shared_ptr<FeedListFormAction> feedlist =
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0]);
 	LOG(Level::DEBUG, "View::get_next_unread: trying to find next unread");
-	if (itemlist->jump_to_next_unread_item(false)) {
+	if (itemlist.jump_to_next_unread_item(false)) {
 		LOG(Level::DEBUG,
 			"View::get_next_unread: found unread article in same "
 			"feed");
 		if (itemview) {
-			itemview->set_feed(itemlist->get_feed());
-			itemview->set_guid(itemlist->get_guid());
+			itemview->set_feed(itemlist.get_feed());
+			itemview->set_guid(itemlist.get_guid());
 			itemview->init();
 		}
 		return true;
@@ -791,18 +773,18 @@ bool View::get_next_unread(ItemListFormAction* itemlist,
 		LOG(Level::DEBUG,
 			"View::get_next_unread: goto-next-feed = false");
 		show_error(_("No unread items."));
-	} else if (feedlist->jump_to_next_unread_feed(feedpos)) {
+	} else if (feedlist_form->jump_to_next_unread_feed(feedpos)) {
 		LOG(Level::DEBUG,
 			"View::get_next_unread: found feed with unread "
 			"articles");
-		prepare_query_feed(feedlist->get_feed());
-		itemlist->set_feed(feedlist->get_feed());
-		itemlist->set_pos(feedpos);
-		itemlist->init();
-		if (itemlist->jump_to_next_unread_item(true)) {
+		prepare_query_feed(feedlist_form->get_feed());
+		itemlist.set_feed(feedlist_form->get_feed());
+		itemlist.set_pos(feedpos);
+		itemlist.init();
+		if (itemlist.jump_to_next_unread_item(true)) {
 			if (itemview) {
-				itemview->set_feed(itemlist->get_feed());
-				itemview->set_guid(itemlist->get_guid());
+				itemview->set_feed(itemlist.get_feed());
+				itemview->set_guid(itemlist.get_guid());
 				itemview->init();
 			}
 			return true;
@@ -811,34 +793,31 @@ bool View::get_next_unread(ItemListFormAction* itemlist,
 	return false;
 }
 
-bool View::get_previous(ItemListFormAction* itemlist,
+bool View::get_previous(ItemListFormAction& itemlist,
 	ItemViewFormAction* itemview)
 {
 	unsigned int feedpos;
-	std::shared_ptr<FeedListFormAction> feedlist =
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0]);
-	if (itemlist->jump_to_previous_item(false)) {
+	if (itemlist.jump_to_previous_item(false)) {
 		LOG(Level::DEBUG, "View::get_previous: article in same feed");
 		if (itemview) {
-			itemview->set_feed(itemlist->get_feed());
-			itemview->set_guid(itemlist->get_guid());
+			itemview->set_feed(itemlist.get_feed());
+			itemview->set_guid(itemlist.get_guid());
 			itemview->init();
 		}
 		return true;
 	} else if (cfg->get_configvalue_as_bool("goto-next-feed") == false) {
 		LOG(Level::DEBUG, "View::get_previous: goto-next-feed = false");
 		show_error(_("Already on first item."));
-	} else if (feedlist->jump_to_previous_feed(feedpos)) {
+	} else if (feedlist_form->jump_to_previous_feed(feedpos)) {
 		LOG(Level::DEBUG, "View::get_previous: previous feed");
-		prepare_query_feed(feedlist->get_feed());
-		itemlist->set_feed(feedlist->get_feed());
-		itemlist->set_pos(feedpos);
-		itemlist->init();
-		if (itemlist->jump_to_previous_item(true)) {
+		prepare_query_feed(feedlist_form->get_feed());
+		itemlist.set_feed(feedlist_form->get_feed());
+		itemlist.set_pos(feedpos);
+		itemlist.init();
+		if (itemlist.jump_to_previous_item(true)) {
 			if (itemview) {
-				itemview->set_feed(itemlist->get_feed());
-				itemview->set_guid(itemlist->get_guid());
+				itemview->set_feed(itemlist.get_feed());
+				itemview->set_guid(itemlist.get_guid());
 				itemview->init();
 			}
 			return true;
@@ -847,33 +826,30 @@ bool View::get_previous(ItemListFormAction* itemlist,
 	return false;
 }
 
-bool View::get_next(ItemListFormAction* itemlist, ItemViewFormAction* itemview)
+bool View::get_next(ItemListFormAction& itemlist, ItemViewFormAction* itemview)
 {
 	unsigned int feedpos;
-	std::shared_ptr<FeedListFormAction> feedlist =
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0]);
-	if (itemlist->jump_to_next_item(false)) {
+	if (itemlist.jump_to_next_item(false)) {
 		LOG(Level::DEBUG, "View::get_next: article in same feed");
 		if (itemview) {
-			itemview->set_feed(itemlist->get_feed());
-			itemview->set_guid(itemlist->get_guid());
+			itemview->set_feed(itemlist.get_feed());
+			itemview->set_guid(itemlist.get_guid());
 			itemview->init();
 		}
 		return true;
 	} else if (cfg->get_configvalue_as_bool("goto-next-feed") == false) {
 		LOG(Level::DEBUG, "View::get_next: goto-next-feed = false");
 		show_error(_("Already on last item."));
-	} else if (feedlist->jump_to_next_feed(feedpos)) {
+	} else if (feedlist_form->jump_to_next_feed(feedpos)) {
 		LOG(Level::DEBUG, "View::get_next: next feed");
-		prepare_query_feed(feedlist->get_feed());
-		itemlist->set_feed(feedlist->get_feed());
-		itemlist->set_pos(feedpos);
-		itemlist->init();
-		if (itemlist->jump_to_next_item(true)) {
+		prepare_query_feed(feedlist_form->get_feed());
+		itemlist.set_feed(feedlist_form->get_feed());
+		itemlist.set_pos(feedpos);
+		itemlist.init();
+		if (itemlist.jump_to_next_item(true)) {
 			if (itemview) {
-				itemview->set_feed(itemlist->get_feed());
-				itemview->set_guid(itemlist->get_guid());
+				itemview->set_feed(itemlist.get_feed());
+				itemview->set_guid(itemlist.get_guid());
 				itemview->init();
 			}
 			return true;
@@ -882,35 +858,27 @@ bool View::get_next(ItemListFormAction* itemlist, ItemViewFormAction* itemview)
 	return false;
 }
 
-bool View::get_next_feed(ItemListFormAction* itemlist)
+bool View::get_next_feed(ItemListFormAction& itemlist)
 {
-	std::shared_ptr<FeedListFormAction> feedlist =
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0]);
 	unsigned int feedpos;
-	assert(feedlist != nullptr);
-	if (feedlist->jump_to_next_feed(feedpos)) {
-		prepare_query_feed(feedlist->get_feed());
-		itemlist->set_feed(feedlist->get_feed());
-		itemlist->set_pos(feedpos);
-		itemlist->init();
+	if (feedlist_form->jump_to_next_feed(feedpos)) {
+		prepare_query_feed(feedlist_form->get_feed());
+		itemlist.set_feed(feedlist_form->get_feed());
+		itemlist.set_pos(feedpos);
+		itemlist.init();
 		return true;
 	}
 	return false;
 }
 
-bool View::get_prev_feed(ItemListFormAction* itemlist)
+bool View::get_prev_feed(ItemListFormAction& itemlist)
 {
-	std::shared_ptr<FeedListFormAction> feedlist =
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0]);
 	unsigned int feedpos;
-	assert(feedlist != nullptr);
-	if (feedlist->jump_to_previous_feed(feedpos)) {
-		prepare_query_feed(feedlist->get_feed());
-		itemlist->set_feed(feedlist->get_feed());
-		itemlist->set_pos(feedpos);
-		itemlist->init();
+	if (feedlist_form->jump_to_previous_feed(feedpos)) {
+		prepare_query_feed(feedlist_form->get_feed());
+		itemlist.set_feed(feedlist_form->get_feed());
+		itemlist.set_pos(feedpos);
+		itemlist.init();
 		return true;
 	}
 	return false;
@@ -1008,15 +976,6 @@ void View::remove_formaction(unsigned int pos)
 	}
 }
 
-void View::set_colors(std::map<std::string, std::string>& fgc,
-	std::map<std::string, std::string>& bgc,
-	std::map<std::string, std::vector<std::string>>& attribs)
-{
-	fg_colors = fgc;
-	bg_colors = bgc;
-	attributes = attribs;
-}
-
 void View::apply_colors_to_all_formactions()
 {
 	for (const auto& form : formaction_stack) {
@@ -1030,70 +989,15 @@ void View::apply_colors_to_all_formactions()
 
 void View::apply_colors(std::shared_ptr<FormAction> fa)
 {
-	auto fgcit = fg_colors.begin();
-	auto bgcit = bg_colors.begin();
-	auto attit = attributes.begin();
-
 	LOG(Level::DEBUG, "View::apply_colors: fa = %s", fa->id());
 
-	std::string article_colorstr;
-
-	for (; fgcit != fg_colors.end(); ++fgcit, ++bgcit, ++attit) {
-		std::string colorattr;
-		if (fgcit->second != "default") {
-			colorattr.append("fg=");
-			colorattr.append(fgcit->second);
-		}
-		if (bgcit->second != "default") {
-			if (colorattr.length() > 0) {
-				colorattr.append(",");
-			}
-			colorattr.append("bg=");
-			colorattr.append(bgcit->second);
-		}
-		for (const auto& attr : attit->second) {
-			if (colorattr.length() > 0) {
-				colorattr.append(",");
-			}
-			colorattr.append("attr=");
-			colorattr.append(attr);
-		}
-
-		if (fgcit->first == "article") {
-			article_colorstr = colorattr;
-			if (fa->id() == "article") {
-				std::string bold = article_colorstr;
-				std::string ul = article_colorstr;
-				if (bold.length() > 0) {
-					bold.append(",");
-				}
-				if (ul.length() > 0) {
-					ul.append(",");
-				}
-				bold.append("attr=bold");
-				ul.append("attr=underline");
-				fa->get_form().set("color_bold", bold.c_str());
-				fa->get_form().set(
-					"color_underline", ul.c_str());
-			}
-		}
-
-		LOG(Level::DEBUG,
-			"View::apply_colors: %s %s %s\n",
-			fa->id(),
-			fgcit->first,
-			colorattr);
-
-		fa->get_form().set(fgcit->first, colorattr);
-	}
+	colorman.apply_colors(fa->get_form());
 }
 
 void View::feedlist_mark_pos_if_visible(unsigned int pos)
 {
-	if (formaction_stack_size() > 0) {
-		std::dynamic_pointer_cast<FeedListFormAction, FormAction>(
-			formaction_stack[0])
-		->mark_pos_if_visible(pos);
+	if (feedlist_form != nullptr) {
+		feedlist_form->mark_pos_if_visible(pos);
 	}
 }
 
