@@ -7,7 +7,7 @@
 #include "rssfeed.h"
 #include "rssignores.h"
 #include "rssparser.h"
-#include "test-helpers.h"
+#include "test-helpers/tempfile.h"
 
 using namespace newsboat;
 
@@ -324,37 +324,6 @@ TEST_CASE("fetch_descriptions fills out feed item's descriptions", "[Cache]")
 	}
 }
 
-TEST_CASE("get_unread_count returns number of yet unread articles", "[Cache]")
-{
-	TestHelpers::TempFile dbfile;
-	ConfigContainer cfg;
-	std::unique_ptr<Cache> rsscache(new Cache(dbfile.get_path(), &cfg));
-	std::unique_ptr<RssParser> parser(new RssParser(
-			"file://data/rss.xml", rsscache.get(), &cfg, nullptr));
-	std::shared_ptr<RssFeed> feed = parser->parse();
-	// Marking one article as read to make sure get_unread_count() really
-	// counts only unread articles
-	feed->items()[0]->set_unread(false);
-	rsscache->externalize_rssfeed(feed, false);
-
-	REQUIRE(rsscache->get_unread_count() == 7);
-
-	// Let's add another article to make sure get_unread_count looks at all
-	// feeds present in the cache
-	parser.reset(new RssParser(
-			"file://data/atom10_1.xml", rsscache.get(), &cfg, nullptr));
-	feed = parser->parse();
-	feed->items()[0]->set_unread(false);
-	feed->items()[2]->set_unread(false);
-	rsscache->externalize_rssfeed(feed, false);
-	REQUIRE(rsscache->get_unread_count() == 8);
-
-	// Lastly, let's make sure the info is indeed retrieved from the
-	// database and isn't just stored in the Cache object
-	rsscache.reset(new Cache(dbfile.get_path(), &cfg));
-	REQUIRE(rsscache->get_unread_count() == 8);
-}
-
 TEST_CASE("get_read_item_guids returns GUIDs of items that are marked read",
 	"[Cache]")
 {
@@ -647,7 +616,6 @@ TEST_CASE(
 	feed2) {
 		REQUIRE(feed1->title_raw() == feed2->title_raw());
 		REQUIRE(feed1->title() == feed2->title());
-		REQUIRE(feed1->description_raw() == feed2->description_raw());
 		REQUIRE(feed1->description() == feed2->description());
 		REQUIRE(feed1->link() == feed2->link());
 		REQUIRE(feed1->rssurl() == feed2->rssurl());
@@ -665,16 +633,9 @@ TEST_CASE(
 			++fst_it, ++snd_it) {
 			REQUIRE((*fst_it)->guid() == (*snd_it)->guid());
 			REQUIRE((*fst_it)->title() == (*snd_it)->title());
-			REQUIRE((*fst_it)->title_raw() ==
-				(*snd_it)->title_raw());
 			REQUIRE((*fst_it)->link() == (*snd_it)->link());
 			REQUIRE((*fst_it)->author() == (*snd_it)->author());
-			REQUIRE((*fst_it)->author_raw() ==
-				(*snd_it)->author_raw());
-			REQUIRE((*fst_it)->description() ==
-				(*snd_it)->description());
-			REQUIRE((*fst_it)->description_raw() ==
-				(*snd_it)->description_raw());
+			REQUIRE((*fst_it)->description() == (*snd_it)->description());
 			REQUIRE((*fst_it)->size() == (*snd_it)->size());
 			REQUIRE((*fst_it)->length() == (*snd_it)->length());
 			REQUIRE((*fst_it)->pubDate() == (*snd_it)->pubDate());
