@@ -3,7 +3,10 @@
 #include <cstring>
 
 #include "cliargsparser.h"
-#include "test-helpers.h"
+#include "test-helpers/envvar.h"
+#include "test-helpers/opts.h"
+#include "test-helpers/stringmaker/optional.h"
+#include "test-helpers/tempdir.h"
 
 using namespace newsboat;
 
@@ -16,7 +19,6 @@ TEST_CASE(
 		CliArgsParser args(opts.argc(), opts.argv());
 
 		REQUIRE(args.should_print_usage());
-		REQUIRE(args.should_return());
 		REQUIRE(args.return_code() == EXIT_FAILURE);
 	};
 
@@ -60,6 +62,33 @@ TEST_CASE(
 	}
 }
 
+TEST_CASE("Resolves tilde to homedir in -i/--import-from-opml",
+	"[CliArgsParser]")
+{
+	TestHelpers::TempDir tmp;
+
+	TestHelpers::EnvVar home("HOME");
+	home.set(tmp.get_path());
+
+	const std::string filename("feedlist.opml");
+	const std::string arg = std::string("~/") + filename;
+
+	auto check = [&filename, &tmp](TestHelpers::Opts opts) {
+		CliArgsParser args(opts.argc(), opts.argv());
+
+		REQUIRE(args.do_import());
+		REQUIRE(args.importfile() == tmp.get_path() + filename);
+	};
+
+	SECTION("-i") {
+		check({"newsboat", "-i", arg});
+	}
+
+	SECTION("--import-from-opml") {
+		check({"newsboat", "--import-from-opml", arg});
+	}
+}
+
 TEST_CASE(
 	"Asks to print usage and exit with failure if both "
 	"-i/--import-from-opml and -e/--export-to-opml are provided",
@@ -72,7 +101,6 @@ TEST_CASE(
 		CliArgsParser args(opts.argc(), opts.argv());
 
 		REQUIRE(args.should_print_usage());
-		REQUIRE(args.should_return());
 		REQUIRE(args.return_code() == EXIT_FAILURE);
 	};
 
@@ -138,7 +166,6 @@ TEST_CASE("Asks to print usage and exit with success if -h/--help is provided",
 		CliArgsParser args(opts.argc(), opts.argv());
 
 		REQUIRE(args.should_print_usage());
-		REQUIRE(args.should_return());
 		REQUIRE(args.return_code() == EXIT_SUCCESS);
 	};
 
@@ -152,8 +179,8 @@ TEST_CASE("Asks to print usage and exit with success if -h/--help is provided",
 }
 
 TEST_CASE(
-	"Sets `url_file`, `set_url_file`, and "
-	"`using_nonstandard_configs` if -u/--url-file is provided",
+	"Sets `url_file` and `using_nonstandard_configs` if -u/--url-file "
+	"is provided",
 	"[CliArgsParser]")
 {
 	const std::string filename("urlfile");
@@ -161,7 +188,6 @@ TEST_CASE(
 	auto check = [&filename](TestHelpers::Opts opts) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
-		REQUIRE(args.set_url_file());
 		REQUIRE(args.url_file() == filename);
 		REQUIRE(args.using_nonstandard_configs());
 	};
@@ -175,10 +201,34 @@ TEST_CASE(
 	}
 }
 
+TEST_CASE("Resolves tilde to homedir in -u/--url-file", "[CliArgsParser]")
+{
+	TestHelpers::TempDir tmp;
+
+	TestHelpers::EnvVar home("HOME");
+	home.set(tmp.get_path());
+
+	const std::string filename("urlfile");
+	const std::string arg = std::string("~/") + filename;
+
+	auto check = [&filename, &tmp](TestHelpers::Opts opts) {
+		CliArgsParser args(opts.argc(), opts.argv());
+
+		REQUIRE(args.url_file() == tmp.get_path() + filename);
+	};
+
+	SECTION("-u") {
+		check({"newsboat", "-u", arg});
+	}
+
+	SECTION("--url-file") {
+		check({"newsboat", "--url-file", arg});
+	}
+}
+
 TEST_CASE(
-	"Sets `cache_file`, `lock_file`, `set_cache_file`, `set_lock_file`, "
-	"and "
-	"`using_nonstandard_configs` if -c/--cache-file is provided",
+	"Sets `cache_file`, `lock_file`, and `using_nonstandard_configs` "
+	"if -c/--cache-file is provided",
 	"[CliArgsParser]")
 {
 	const std::string filename("cache.db");
@@ -186,9 +236,7 @@ TEST_CASE(
 	auto check = [&filename](TestHelpers::Opts opts) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
-		REQUIRE(args.set_cache_file());
 		REQUIRE(args.cache_file() == filename);
-		REQUIRE(args.set_lock_file());
 		REQUIRE(args.lock_file() == filename + ".lock");
 		REQUIRE(args.using_nonstandard_configs());
 	};
@@ -202,9 +250,35 @@ TEST_CASE(
 	}
 }
 
+TEST_CASE("Resolves tilde to homedir in -c/--cache-file", "[CliArgsParser]")
+{
+	TestHelpers::TempDir tmp;
+
+	TestHelpers::EnvVar home("HOME");
+	home.set(tmp.get_path());
+
+	const std::string filename("mycache.db");
+	const std::string arg = std::string("~/") + filename;
+
+	auto check = [&filename, &tmp](TestHelpers::Opts opts) {
+		CliArgsParser args(opts.argc(), opts.argv());
+
+		REQUIRE(args.cache_file() == tmp.get_path() + filename);
+		REQUIRE(args.lock_file() == tmp.get_path() + filename + ".lock");
+	};
+
+	SECTION("-c") {
+		check({"newsboat", "-c", arg});
+	}
+
+	SECTION("--cache-file") {
+		check({"newsboat", "--cache-file", arg});
+	}
+}
+
 TEST_CASE(
-	"Sets `config_file`, `set_config_file`, and "
-	"`using_nonstandard_configs` if -C/--config-file is provided",
+	"Sets `config_file` and `using_nonstandard_configs` if -C/--config-file "
+	"is provided",
 	"[CliArgsParser]")
 {
 	const std::string filename("config file");
@@ -212,7 +286,6 @@ TEST_CASE(
 	auto check = [&filename](TestHelpers::Opts opts) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
-		REQUIRE(args.set_config_file());
 		REQUIRE(args.config_file() == filename);
 		REQUIRE(args.using_nonstandard_configs());
 	};
@@ -226,6 +299,32 @@ TEST_CASE(
 	}
 }
 
+TEST_CASE("Resolves tilde to homedir in -C/--config-file", "[CliArgsParser]")
+{
+	TestHelpers::TempDir tmp;
+
+	TestHelpers::EnvVar home("HOME");
+	home.set(tmp.get_path());
+
+	const std::string filename("newsboat-config");
+	const std::string arg = std::string("~/") + filename;
+
+	auto check = [&filename, &tmp](TestHelpers::Opts opts) {
+		CliArgsParser args(opts.argc(), opts.argv());
+
+		REQUIRE(args.config_file() == tmp.get_path() + filename);
+		REQUIRE(args.using_nonstandard_configs());
+	};
+
+	SECTION("-C") {
+		check({"newsboat", "-C", arg});
+	}
+
+	SECTION("--config-file") {
+		check({"newsboat", "--config-file", arg});
+	}
+}
+
 TEST_CASE("Sets `do_vacuum` if -X/--vacuum is provided", "[CliArgsParser]")
 {
 	auto check = [](TestHelpers::Opts opts) {
@@ -246,7 +345,7 @@ TEST_CASE("Sets `do_vacuum` if -X/--vacuum is provided", "[CliArgsParser]")
 TEST_CASE("Increases `show_version` with each -v/-V/--version provided",
 	"[CliArgsParser]")
 {
-	auto check = [](TestHelpers::Opts opts, int expected_version) {
+	auto check = [](TestHelpers::Opts opts, unsigned int expected_version) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
 		REQUIRE(args.show_version() == expected_version);
@@ -303,7 +402,8 @@ TEST_CASE("Sets `execute_cmds` if -x/--execute is provided", "[CliArgsParser]")
 	auto check = [](TestHelpers::Opts opts) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
-		REQUIRE(args.execute_cmds());
+		REQUIRE_FALSE(args.cmds_to_execute() == nonstd::nullopt);
+		REQUIRE_FALSE(args.cmds_to_execute().value().empty());
 	};
 
 	SECTION("-x") {
@@ -366,8 +466,7 @@ TEST_CASE("Requests silent mode if -q/--quiet is provided", "[CliArgsParser]")
 }
 
 TEST_CASE(
-	"Sets `do_read_import` and `readinfofile` if -I/--import-from-file "
-	"is provided",
+	"Sets `readinfofile` if -I/--import-from-file is provided",
 	"[CliArgsParser]")
 {
 	const std::string filename("filename");
@@ -375,7 +474,6 @@ TEST_CASE(
 	auto check = [&filename](TestHelpers::Opts opts) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
-		REQUIRE(args.do_read_import());
 		REQUIRE(args.readinfo_import_file() == filename);
 	};
 
@@ -388,9 +486,34 @@ TEST_CASE(
 	}
 }
 
+TEST_CASE("Resolves tilde to homedir in -I/--import-from-file",
+	"[CliArgsParser]")
+{
+	TestHelpers::TempDir tmp;
+
+	TestHelpers::EnvVar home("HOME");
+	home.set(tmp.get_path());
+
+	const std::string filename("read.txt");
+	const std::string arg = std::string("~/") + filename;
+
+	auto check = [&filename, &tmp](TestHelpers::Opts opts) {
+		CliArgsParser args(opts.argc(), opts.argv());
+
+		REQUIRE(args.readinfo_import_file() == tmp.get_path() + filename);
+	};
+
+	SECTION("-I") {
+		check({"newsboat", "-I", arg});
+	}
+
+	SECTION("--import-from-file") {
+		check({"newsboat", "--import-from-file", arg});
+	}
+}
+
 TEST_CASE(
-	"Sets `do_read_export` and `readinfofile` if -E/--export-to-file "
-	"is provided",
+	"Sets `readinfofile` if -E/--export-to-file is provided",
 	"[CliArgsParser]")
 {
 	const std::string filename("filename");
@@ -398,7 +521,6 @@ TEST_CASE(
 	auto check = [&filename](TestHelpers::Opts opts) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
-		REQUIRE(args.do_read_export());
 		REQUIRE(args.readinfo_export_file() == filename);
 	};
 
@@ -411,6 +533,31 @@ TEST_CASE(
 	}
 }
 
+TEST_CASE("Resolves tilde to homedir in -E/--export-to-file", "[CliArgsParser]")
+{
+	TestHelpers::TempDir tmp;
+
+	TestHelpers::EnvVar home("HOME");
+	home.set(tmp.get_path());
+
+	const std::string filename("read.txt");
+	const std::string arg = std::string("~/") + filename;
+
+	auto check = [&filename, &tmp](TestHelpers::Opts opts) {
+		CliArgsParser args(opts.argc(), opts.argv());
+
+		REQUIRE(args.readinfo_export_file() == tmp.get_path() + filename);
+	};
+
+	SECTION("-E") {
+		check({"newsboat", "-E", arg});
+	}
+
+	SECTION("--export-to-file") {
+		check({"newsboat", "--export-to-file", arg});
+	}
+}
+
 TEST_CASE(
 	"Asks to print usage info and exit with failure if both "
 	"-I/--import-from-file and -E/--export-to-file are provided",
@@ -423,7 +570,6 @@ TEST_CASE(
 		CliArgsParser args(opts.argc(), opts.argv());
 
 		REQUIRE(args.should_print_usage());
-		REQUIRE(args.should_return());
 		REQUIRE(args.return_code() == EXIT_FAILURE);
 	};
 
@@ -436,7 +582,7 @@ TEST_CASE(
 	}
 }
 
-TEST_CASE("Sets `set_log_file` and `log_file` if -d/--log-file is provided",
+TEST_CASE("Sets `log_file` if -d/--log-file is provided",
 	"[CliArgsParser]")
 {
 	const std::string filename("log file.txt");
@@ -444,7 +590,6 @@ TEST_CASE("Sets `set_log_file` and `log_file` if -d/--log-file is provided",
 	auto check = [&filename](TestHelpers::Opts opts) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
-		REQUIRE(args.set_log_file());
 		REQUIRE(args.log_file() == filename);
 	};
 
@@ -457,15 +602,38 @@ TEST_CASE("Sets `set_log_file` and `log_file` if -d/--log-file is provided",
 	}
 }
 
+TEST_CASE("Resolves tilde to homedir in -d/--log-file", "[CliArgsParser]")
+{
+	TestHelpers::TempDir tmp;
+
+	TestHelpers::EnvVar home("HOME");
+	home.set(tmp.get_path());
+
+	const std::string filename("newsboat.log");
+	const std::string arg = std::string("~/") + filename;
+
+	auto check = [&filename, &tmp](TestHelpers::Opts opts) {
+		CliArgsParser args(opts.argc(), opts.argv());
+
+		REQUIRE(args.log_file() == tmp.get_path() + filename);
+	};
+
+	SECTION("-d") {
+		check({"newsboat", "-d", arg});
+	}
+
+	SECTION("--log-file") {
+		check({"newsboat", "--log-file", arg});
+	}
+}
+
 TEST_CASE(
-	"Sets `set_log_level` and `log_level` if argument to "
-	"-l/--log-level is in range of [1; 6]",
+	"Sets `log_level` if argument to -l/--log-level is in range of [1; 6]",
 	"[CliArgsParser]")
 {
 	auto check = [](TestHelpers::Opts opts, Level expected) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
-		REQUIRE(args.set_log_level());
 		REQUIRE(args.log_level() == expected);
 	};
 
@@ -502,8 +670,7 @@ TEST_CASE(
 	auto check = [](TestHelpers::Opts opts) {
 		CliArgsParser args(opts.argc(), opts.argv());
 
-		REQUIRE_FALSE(args.display_msg().empty());
-		REQUIRE(args.should_return());
+		REQUIRE_FALSE(args.display_msg() == "");
 		REQUIRE(args.return_code() == EXIT_FAILURE);
 	};
 
