@@ -105,7 +105,7 @@ TEST_CASE("set_feeds() sets FeedContainer's feed vector to the given one",
 
 	feedcontainer.set_feeds(feeds);
 
-	REQUIRE(feedcontainer.feeds == feeds);
+	REQUIRE(feedcontainer.get_all_feeds() == feeds);
 }
 
 TEST_CASE("get_feed_by_url() returns feed by its URL", "[FeedContainer]")
@@ -149,7 +149,8 @@ TEST_CASE(
 	REQUIRE(feed == nullptr);
 }
 
-TEST_CASE("Throws on get_feed() with pos out of range", "[FeedContainer]")
+TEST_CASE("get_feed() returns nullptr if pos is out of range",
+	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
 	ConfigContainer cfg;
@@ -157,8 +158,8 @@ TEST_CASE("Throws on get_feed() with pos out of range", "[FeedContainer]")
 	feedcontainer.set_feeds(get_five_empty_feeds(&rsscache));
 
 	REQUIRE_NOTHROW(feedcontainer.get_feed(4));
-	CHECK_THROWS_AS(feedcontainer.get_feed(5), std::out_of_range);
-	CHECK_THROWS_AS(feedcontainer.get_feed(-1), std::out_of_range);
+	REQUIRE(feedcontainer.get_feed(5) == nullptr);
+	REQUIRE(feedcontainer.get_feed(-1) == nullptr);
 }
 
 TEST_CASE("Returns correct number using get_feed_count_by_tag()",
@@ -566,6 +567,44 @@ TEST_CASE("Sorting by lastupdated-asc puts empty feeds on top",
 	}
 }
 
+TEST_CASE("Sorting by firsttag-asc reverses the order of feeds with the same first tag",
+	"[FeedContainer]")
+{
+	FeedContainer feedcontainer;
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
+	const auto feeds = get_five_empty_feeds(&rsscache);
+	feedcontainer.set_feeds(feeds);
+
+	feeds[0]->set_tags({""});
+	feeds[1]->set_tags({"Taggy"});
+	feeds[2]->set_tags({"~tag10"});
+	feeds[3]->set_tags({"~AAA", "Taggy"});
+	feeds[4]->set_tags({"tag2"});
+
+	SECTION("by firsttag asc, feeds with the same first tag are sorted in reverse") {
+		cfg.set_configvalue("feed-sort-order", "firsttag-asc");
+		feedcontainer.sort_feeds(cfg.get_feed_sort_strategy());
+		const auto sorted_feeds = feedcontainer.get_all_feeds();
+		REQUIRE(sorted_feeds[0] == feeds[2]);
+		REQUIRE(sorted_feeds[1] == feeds[0]);
+		REQUIRE(sorted_feeds[2] == feeds[4]);
+		REQUIRE(sorted_feeds[3] == feeds[3]);
+		REQUIRE(sorted_feeds[4] == feeds[1]);
+	}
+
+	SECTION("by firsttag desc, feeds with the same first tag are sorted in order") {
+		cfg.set_configvalue("feed-sort-order", "firsttag-desc");
+		feedcontainer.sort_feeds(cfg.get_feed_sort_strategy());
+		const auto sorted_feeds = feedcontainer.get_all_feeds();
+		REQUIRE(sorted_feeds[0] == feeds[1]);
+		REQUIRE(sorted_feeds[1] == feeds[3]);
+		REQUIRE(sorted_feeds[2] == feeds[4]);
+		REQUIRE(sorted_feeds[3] == feeds[0]);
+		REQUIRE(sorted_feeds[4] == feeds[2]);
+	}
+}
+
 TEST_CASE("mark_all_feed_items_read() marks all of feed's items as read",
 	"[FeedContainer]")
 {
@@ -581,7 +620,7 @@ TEST_CASE("mark_all_feed_items_read() marks all of feed's items as read",
 	}
 	feedcontainer.set_feeds(feeds);
 
-	feedcontainer.mark_all_feed_items_read(0);
+	feedcontainer.mark_all_feed_items_read(feed);
 
 	for (const auto& item : feed->items()) {
 		REQUIRE_FALSE(item->unread());
@@ -636,24 +675,6 @@ TEST_CASE(
 	}
 }
 
-TEST_CASE("clear_feeds_items() removes all items from all feeds",
-	"[FeedContainer]")
-{
-	FeedContainer feedcontainer;
-	ConfigContainer cfg;
-	Cache rsscache(":memory:", &cfg);
-	feedcontainer.set_feeds({});
-	const auto feed = std::make_shared<RssFeed>(&rsscache);
-	for (int j = 0; j < 5; ++j) {
-		feed->add_item(std::make_shared<RssItem>(&rsscache));
-	}
-	feedcontainer.add_feed(feed);
-
-	REQUIRE(feed->items().size() == 5);
-	feedcontainer.clear_feeds_items();
-	REQUIRE(feed->items().size() == 0);
-}
-
 TEST_CASE(
 	"unread_feed_count() returns number of feeds that have unread items in "
 	"them",
@@ -679,26 +700,113 @@ TEST_CASE(
 	REQUIRE(feedcontainer.unread_feed_count() == 2);
 }
 
-TEST_CASE("unread_item_count() returns number of unread items in all feeds",
+TEST_CASE("unread_item_count() returns number of distinct unread items "
+	"in non-hidden feeds",
 	"[FeedContainer]")
 {
 	FeedContainer feedcontainer;
 	ConfigContainer cfg;
 	Cache rsscache(":memory:", &cfg);
-	const auto feeds = get_five_empty_feeds(&rsscache);
-	for (int j = 0; j < 5; ++j) {
-		const auto item = std::make_shared<RssItem>(&rsscache);
-		const auto item2 = std::make_shared<RssItem>(&rsscache);
-		if ((j % 2) == 0) {
-			item->set_unread_nowrite(false);
-			item2->set_unread_nowrite(false);
-		}
-		feeds[j]->add_item(item);
-		feeds[j]->add_item(item2);
-	}
-	feedcontainer.set_feeds(feeds);
 
-	REQUIRE(feedcontainer.unread_item_count() == 4);
+	SECTION("No query feeds") {
+		const auto feeds = get_five_empty_feeds(&rsscache);
+		for (int j = 0; j < 5; ++j) {
+			const auto item = std::make_shared<RssItem>(&rsscache);
+			item->set_guid(std::to_string(j) + "item1");
+			const auto item2 = std::make_shared<RssItem>(&rsscache);
+			item2->set_guid(std::to_string(j) + "item2");
+			if ((j % 2) == 0) {
+				item->set_unread_nowrite(false);
+				item2->set_unread_nowrite(false);
+			}
+			feeds[j]->add_item(item);
+			feeds[j]->add_item(item2);
+		}
+		feedcontainer.set_feeds(feeds);
+
+		REQUIRE(feedcontainer.unread_item_count() == 4);
+	}
+
+	SECTION("Query feeds do not affect the total count") {
+		// This is a regression test for https://github.com/newsboat/newsboat/issues/1120
+
+		auto feeds = get_five_empty_feeds(&rsscache);
+
+		auto query1 = std::make_shared<RssFeed>(&rsscache);
+		query1->set_rssurl("query:Title contains word:title # \"word\"");
+		auto query2 = std::make_shared<RssFeed>(&rsscache);
+		query2->set_rssurl("query:Posts by John Doe:author = \"John Doe\"");
+
+		feeds.push_back(query1);
+		feeds.push_back(query2);
+
+		for (int j = 0; j < 5; ++j) {
+			const auto item = std::make_shared<RssItem>(&rsscache);
+			item->set_title("All titles contain word");
+			item->set_author("John Doe");
+			item->set_guid(std::to_string(j) + "item1");
+			const auto item2 = std::make_shared<RssItem>(&rsscache);
+			item2->set_title("All titles contain word");
+			item2->set_author("John Doe");
+			item2->set_guid(std::to_string(j) + "item2");
+			if ((j % 2) == 0) {
+				item->set_unread_nowrite(false);
+				item2->set_unread_nowrite(false);
+			}
+			feeds[j]->add_item(item);
+			feeds[j]->add_item(item2);
+		}
+
+		feedcontainer.set_feeds(feeds);
+		feedcontainer.populate_query_feeds();
+
+		REQUIRE(feedcontainer.unread_item_count() == 4);
+	}
+
+	SECTION("Items in hidden feeds are not counted") {
+		// This is a regression test for https://github.com/newsboat/newsboat/issues/444
+
+		auto feeds = get_five_empty_feeds(&rsscache);
+
+		// First feed is hidden and contains five unread items
+		feeds[0]->set_tags({"!hidden"});
+		for (int i = 0; i < 5; ++i) {
+			const auto item = std::make_shared<RssItem>(&rsscache);
+			item->set_guid(std::to_string(i) + "feed1");
+			item->set_unread(true);
+			feeds[0]->add_item(item);
+		}
+
+		// Second feed is **not** hidden and contains two unread items
+		for (int i = 0; i < 2; ++i) {
+			const auto item = std::make_shared<RssItem>(&rsscache);
+			item->set_guid(std::to_string(i) + "feed2");
+			item->set_unread(true);
+			feeds[1]->add_item(item);
+		}
+
+		// Third feed contains three read items -- they shouldn't affect the count
+		for (int i = 0; i < 3; ++i) {
+			const auto item = std::make_shared<RssItem>(&rsscache);
+			item->set_guid(std::to_string(i) + "feed3");
+			item->set_unread(false);
+			feeds[2]->add_item(item);
+		}
+
+		feedcontainer.set_feeds(feeds);
+
+		// Only the two items of the second feed are counted
+		REQUIRE(feedcontainer.unread_item_count() == 2);
+
+		SECTION("...unless they are also in some query feed(s)") {
+			feeds[3]->set_rssurl("query:Posts from the hidden feed:guid =~ \".*feed1\"");
+			feedcontainer.set_feeds(feeds);
+			feedcontainer.populate_query_feeds();
+
+			// Two items from the second feeds plus five items from the first (hidden) feed
+			REQUIRE(feedcontainer.unread_item_count() == 7);
+		}
+	}
 }
 
 TEST_CASE("get_unread_feed_count_per_tag returns 0 if there are no feeds "
@@ -994,3 +1102,29 @@ TEST_CASE("get_unread_item_count_per_tag returns the number of unread items "
 			== 24);
 	}
 }
+
+TEST_CASE("replace_feed() puts given feed into the specified position",
+	"[FeedContainer]")
+{
+	FeedContainer feedcontainer;
+
+	ConfigContainer cfg;
+	Cache rsscache(":memory:", &cfg);
+	const auto feeds = get_five_empty_feeds(&rsscache);
+
+	const auto first_feed = *feeds.begin();
+	const auto four_feeds = std::vector<std::shared_ptr<RssFeed>>(feeds.begin() + 1,
+			feeds.end());
+
+	feedcontainer.set_feeds(four_feeds);
+
+	const auto position = 2;
+	const auto feed_before_replacement = feedcontainer.get_feed(position);
+	REQUIRE(feed_before_replacement != first_feed);
+
+	feedcontainer.replace_feed(position, first_feed);
+	const auto feed_after_replacement = feedcontainer.get_feed(position);
+
+	REQUIRE(feed_before_replacement != feed_after_replacement);
+	REQUIRE(feed_after_replacement == first_feed);
+}
