@@ -1,10 +1,12 @@
 #include "fileurlreader.h"
 
-#include <unistd.h>
+#include <fstream>
 #include <map>
+#include <unistd.h>
 
 #include "3rd-party/catch.hpp"
-#include "test-helpers.h"
+#include "test-helpers/misc.h"
+#include "test-helpers/tempfile.h"
 
 using namespace newsboat;
 
@@ -13,16 +15,16 @@ TEST_CASE("URL reader remembers the file name from which it read the URLs",
 {
 	const std::string url("data/test-urls.txt");
 
-	FileUrlReader u;
-	REQUIRE(u.get_source() != url);
-	u.load_config(url);
+	FileUrlReader u(url);
+	REQUIRE(u.get_source() == url);
+	u.reload();
 	REQUIRE(u.get_source() == url);
 }
 
 TEST_CASE("URL reader extracts all URLs from the file", "[FileUrlReader]")
 {
-	FileUrlReader u;
-	u.load_config("data/test-urls.txt");
+	FileUrlReader u("data/test-urls.txt");
+	u.reload();
 
 	REQUIRE(u.get_urls().size() == 3);
 	REQUIRE(u.get_urls()[0] == "http://test1.url.cc/feed.xml");
@@ -32,8 +34,8 @@ TEST_CASE("URL reader extracts all URLs from the file", "[FileUrlReader]")
 
 TEST_CASE("URL reader extracts feeds' tags", "[FileUrlReader]")
 {
-	FileUrlReader u;
-	u.load_config("data/test-urls.txt");
+	FileUrlReader u("data/test-urls.txt");
+	u.reload();
 
 	REQUIRE(u.get_tags("http://test1.url.cc/feed.xml").size() == 2);
 	REQUIRE(u.get_tags("http://test1.url.cc/feed.xml")[0] == "tag1");
@@ -45,8 +47,8 @@ TEST_CASE("URL reader extracts feeds' tags", "[FileUrlReader]")
 
 TEST_CASE("URL reader keeps track of unique tags", "[FileUrlReader]")
 {
-	FileUrlReader u;
-	u.load_config("data/test-urls.txt");
+	FileUrlReader u("data/test-urls.txt");
+	u.reload();
 
 	REQUIRE(u.get_alltags().size() == 3);
 }
@@ -55,30 +57,16 @@ TEST_CASE("URL reader writes files that it can understand later",
 	"[FileUrlReader]")
 {
 	const std::string testDataPath("data/test-urls.txt");
-
 	TestHelpers::TempFile urlsFile;
 
-	std::ofstream urlsFileStream;
-	urlsFileStream.open(urlsFile.get_path());
-	REQUIRE(urlsFileStream.is_open());
-
-	std::ifstream testData;
-	testData.open(testDataPath);
-	REQUIRE(testData.is_open());
-
-	for (std::string line; std::getline(testData, line); ) {
-		urlsFileStream << line << '\n';
-	}
-
-	urlsFileStream.close();
-	testData.close();
+	TestHelpers::copy_file(testDataPath, urlsFile.get_path());
 
 	FileUrlReader u(urlsFile.get_path());
 	u.reload();
 	REQUIRE_FALSE(u.get_urls().empty());
 	REQUIRE_FALSE(u.get_alltags().empty());
 
-	urlsFileStream.open(urlsFile.get_path());
+	std::ofstream urlsFileStream(urlsFile.get_path());
 	REQUIRE(urlsFileStream.is_open());
 	urlsFileStream << std::string();
 	urlsFileStream.close();
@@ -95,3 +83,15 @@ TEST_CASE("URL reader writes files that it can understand later",
 		REQUIRE(u.get_tags(url) == u2.get_tags(url));
 	}
 }
+
+TEST_CASE("Preserves URLs as-is", "[FileUrlReader][issue926]")
+{
+	const std::string testDataPath("data/926-urls");
+
+	FileUrlReader u(testDataPath);
+	u.reload();
+
+	REQUIRE(u.get_urls().size() == 1);
+	REQUIRE(u.get_urls()[0] ==
+		R"_(exec:curl --silent https://feeds.metaebene.me/raumzeit/m4a  | sed 's#\(</guid>\|</id>\)#-M4A&#')_");
+}
