@@ -6,7 +6,8 @@
 #include "cache.h"
 #include "fileurlreader.h"
 #include "rssfeed.h"
-#include "test-helpers.h"
+#include "test-helpers/misc.h"
+#include "test-helpers/tempfile.h"
 
 using namespace newsboat;
 
@@ -91,20 +92,7 @@ TEST_CASE("import() populates UrlReader with URLs from the OPML file", "[Opml]")
 {
 	TestHelpers::TempFile urlsFile;
 
-	std::ifstream urlsExampleFile;
-	urlsExampleFile.open("data/test-urls.txt");
-	REQUIRE(urlsExampleFile.is_open());
-
-	std::ofstream urlsFileStream;
-	urlsFileStream.open(urlsFile.get_path());
-	REQUIRE(urlsFileStream.is_open());
-
-	for (std::string line; std::getline(urlsExampleFile, line); ) {
-		urlsFileStream << line << '\n';
-	}
-
-	urlsExampleFile.close();
-	urlsFileStream.close();
+	TestHelpers::copy_file("data/test-urls.txt", urlsFile.get_path());
 
 	using URL = std::string;
 	using Tag = std::string;
@@ -133,7 +121,7 @@ TEST_CASE("import() populates UrlReader with URLs from the OPML file", "[Opml]")
 	REQUIRE_NOTHROW(
 		opml::import(
 			"file://" + utils::getcwd() + "/data/example.opml",
-			&urlcfg));
+			urlcfg));
 
 	const std::map<URL, Tags> opmlUrls {
 		{"https://example.com/feed.xml", {}},
@@ -173,7 +161,7 @@ TEST_CASE("import() turns URLs that start with a pipe symbol (\"|\") "
 	REQUIRE_NOTHROW(
 		opml::import(
 			"file://" + utils::getcwd() + "/data/piped.opml",
-			&urlcfg));
+			urlcfg));
 
 	using URL = std::string;
 	using Tag = std::string;
@@ -208,7 +196,7 @@ TEST_CASE("import() turns \"filtercmd\" attribute into a `filter:` URL "
 	REQUIRE_NOTHROW(
 		opml::import(
 			"file://" + utils::getcwd() + "/data/filtered.opml",
-			&urlcfg));
+			urlcfg));
 
 	using URL = std::string;
 	using Tag = std::string;
@@ -236,20 +224,7 @@ TEST_CASE("import() skips URLs that are already present in UrlReader",
 {
 	TestHelpers::TempFile urlsFile;
 
-	std::ifstream urlsExampleFile;
-	urlsExampleFile.open("data/test-urls.txt");
-	REQUIRE(urlsExampleFile.is_open());
-
-	std::ofstream urlsFileStream;
-	urlsFileStream.open(urlsFile.get_path());
-	REQUIRE(urlsFileStream.is_open());
-
-	for (std::string line; std::getline(urlsExampleFile, line); ) {
-		urlsFileStream << line << '\n';
-	}
-
-	urlsExampleFile.close();
-	urlsFileStream.close();
+	TestHelpers::copy_file("data/test-urls.txt", urlsFile.get_path());
 
 	using URL = std::string;
 	using Tag = std::string;
@@ -278,7 +253,7 @@ TEST_CASE("import() skips URLs that are already present in UrlReader",
 	REQUIRE_NOTHROW(
 		opml::import(
 			"file://" + utils::getcwd() + "/data/test-urls+.opml",
-			&urlcfg));
+			urlcfg));
 
 	const std::map<URL, Tags> opmlUrls {
 		{"https://example.com/another_feed.atom", {}},
