@@ -1,10 +1,12 @@
 #include "opmlurlreader.h"
 
-#include <unistd.h>
+#include <fstream>
 #include <map>
+#include <unistd.h>
 
 #include "3rd-party/catch.hpp"
-#include "test-helpers.h"
+#include "test-helpers/misc.h"
+#include "test-helpers/tempfile.h"
 #include "utils.h"
 
 using namespace newsboat;
@@ -196,47 +198,3 @@ TEST_CASE("OpmlUrlReader::reload() skips things that can't be parsed",
 	tags.insert(alltags.cbegin(), alltags.cend());
 	REQUIRE(tags == expected_tags);
 }
-
-TEST_CASE("OpmlUrlReader::write_config() doesn't change the input file",
-	"[OpmlUrlReader]")
-{
-	const std::string testDataPath("data/example.opml");
-
-	TestHelpers::TempFile urlsFile;
-
-	std::ofstream urlsFileStream;
-	urlsFileStream.open(urlsFile.get_path());
-	REQUIRE(urlsFileStream.is_open());
-
-	std::ifstream testData;
-	testData.open(testDataPath);
-	REQUIRE(testData.is_open());
-
-	for (std::string line; std::getline(testData, line); ) {
-		urlsFileStream << line << '\n';
-	}
-
-	urlsFileStream.close();
-	testData.close();
-
-	ConfigContainer cfg;
-	cfg.set_configvalue("opml-url", "file://" + urlsFile.get_path());
-
-	OpmlUrlReader u(&cfg);
-	REQUIRE_NOTHROW(u.reload());
-
-	const std::string sentry("wasn't touched by OpmlUrlReader at all");
-	urlsFileStream.open(urlsFile.get_path());
-	REQUIRE(urlsFileStream.is_open());
-	urlsFileStream << sentry;
-	urlsFileStream.close();
-
-	REQUIRE_NOTHROW(u.write_config());
-
-	std::ifstream urlsFileReadStream;
-	urlsFileReadStream.open(urlsFile.get_path());
-	REQUIRE(urlsFileReadStream.is_open());
-	std::string line;
-	std::getline(urlsFileReadStream, line);
-	REQUIRE(line == sentry);
-}
