@@ -113,13 +113,13 @@ TEST_CASE("strprintf::fmt() formats int32_t", "[strprintf]")
 
 TEST_CASE("strprintf::fmt() formats uint32_t", "[strprintf]")
 {
-	const uint32_t input = 42;
+	const std::uint32_t input = 42;
 	REQUIRE(strprintf::fmt("%" PRIu32, input) == "42");
 
-	const uint32_t zero = 0;
+	const std::uint32_t zero = 0;
 	REQUIRE(strprintf::fmt("%" PRIu32, zero) == "0");
 
-	const uint32_t u32_max = std::numeric_limits<uint32_t>::max();
+	const std::uint32_t u32_max = std::numeric_limits<std::uint32_t>::max();
 	REQUIRE(strprintf::fmt("%" PRIu32, u32_max) == "4294967295");
 }
 
@@ -160,7 +160,7 @@ TEST_CASE("strprintf::fmt() formats pointers", "[strprintf]")
 	const auto x_ptr_void = reinterpret_cast<const void*>(x_ptr);
 	const auto x_ptr_void_formatted = strprintf::fmt("%p", x_ptr_void);
 
-	REQUIRE_FALSE(x_ptr_formatted.empty());
+	REQUIRE_FALSE(x_ptr_formatted == "");
 	REQUIRE(x_ptr_formatted == x_ptr_void_formatted);
 }
 
@@ -178,7 +178,7 @@ TEST_CASE("strprintf::fmt() formats null pointers the same", "[strprintf]")
 		strprintf::fmt("%p", static_cast<const long long*>(nullptr));
 	const auto ullong_ptr_fmt =
 		strprintf::fmt("%p", static_cast<const unsigned long long*>(nullptr));
-	REQUIRE_FALSE(int_ptr_fmt.empty());
+	REQUIRE_FALSE(int_ptr_fmt == "");
 	REQUIRE(int_ptr_fmt == uint_ptr_fmt);
 	REQUIRE(uint_ptr_fmt == long_ptr_fmt);
 	REQUIRE(long_ptr_fmt == ulong_ptr_fmt);
