@@ -3,6 +3,7 @@
 #include <chrono>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <tuple>
 #include <unistd.h>
 
 #include "3rd-party/catch.hpp"
@@ -249,6 +250,99 @@ TEST_CASE("tokenize_quoted does not consider escaped pound sign (\\#) "
 	REQUIRE(tokens[3] == "three");
 }
 
+TEST_CASE("extract_token_quoted() returns no result if it finds a comment (signaled by '#')",
+	"[utils]")
+{
+	SECTION("actual comment") {
+		std::string str = "\t\t  # commented out";
+		auto token = utils::extract_token_quoted(str);
+		REQUIRE_FALSE(token.has_value());
+		REQUIRE(str == "");
+	}
+
+	SECTION("ignores '#' if it is inside quotes") {
+		std::string str = R"("# in quoted token" other tokens)";
+		auto token = utils::extract_token_quoted(str);
+		REQUIRE(token.has_value());
+		REQUIRE(token.value() == "# in quoted token");
+		REQUIRE(str == " other tokens");
+	}
+
+	SECTION("token before start of comment") {
+		std::string str = "some-token # some comment";
+		auto token = utils::extract_token_quoted(str);
+		REQUIRE(token.has_value());
+		REQUIRE(token.value() == "some-token");
+		REQUIRE(str == " # some comment");
+	}
+}
+
+TEST_CASE("extract_token_quoted() ignores configured `delimiters` in front of tokens",
+	"[utils]")
+{
+	SECTION("default delimiters") {
+		std::string str = "\n\r\t \n\t\r token-name";
+		auto token = utils::extract_token_quoted(str);
+		REQUIRE(token.has_value());
+		REQUIRE(token.value() == "token-name");
+		REQUIRE(str == "");
+	}
+
+	SECTION("empty delimiters") {
+		std::string str = "\n\r\t \n\t\r token-name";
+		auto token = utils::extract_token_quoted(str, "");
+		REQUIRE(token.has_value());
+		REQUIRE(token.value() == "\n\r\t \n\t\r token-name");
+		REQUIRE(str == "");
+	}
+
+	SECTION("single delimiter") {
+		std::string str = "--token name--";
+		auto token = utils::extract_token_quoted(str, "-");
+		REQUIRE(token.has_value());
+		REQUIRE(token.value() == "token name");
+		REQUIRE(str == "--");
+	}
+
+	SECTION("two delimiters") {
+		std::string str = "--token name--";
+		auto token = utils::extract_token_quoted(str, " -");
+		REQUIRE(token.has_value());
+		REQUIRE(token.value() == "token");
+		REQUIRE(str == " name--");
+	}
+}
+
+TEST_CASE("extract_token_quoted() ignores delimiter characters within quoted strings",
+	"[utils]")
+{
+	SECTION("default delimiters") {
+		std::string str = R"(  "token name"  )";
+		auto token = utils::extract_token_quoted(str);
+		REQUIRE(token.has_value());
+		REQUIRE(token.value() == "token name");
+		REQUIRE(str == "  ");
+	}
+
+	SECTION("two delimiters") {
+		std::string str = R"(--"token name"--)";
+		auto token = utils::extract_token_quoted(str, " -");
+		REQUIRE(token.has_value());
+		REQUIRE(token.value() == "token name");
+		REQUIRE(str == "--");
+	}
+}
+
+TEST_CASE("extract_token_quoted() processes escape sequences within quoted strings",
+	"[utils]")
+{
+	std::string str = R"(  "\n \r \t \" \` \\ " remainder)";
+	auto token = utils::extract_token_quoted(str);
+	REQUIRE(token.has_value());
+	REQUIRE(token.value() == "\n \r \t \" \\` \\ ");
+	REQUIRE(str == " remainder");
+}
+
 TEST_CASE("tokenize_nl() split a string into delimiters and fields", "[utils]")
 {
 	std::vector<std::string> tokens;
@@ -527,17 +621,17 @@ TEST_CASE("run_command() doesn't wait for the command to finish",
 {
 	using namespace std::chrono;
 
-	const auto start = high_resolution_clock::now();
+	const auto start = steady_clock::now();
 
-	const std::string argument("5");
-	utils::run_command("sleep", argument);
+	// Using a big timeout value of 60 seconds to overcome any slowdowns that
+	// Cirrus CI sometimes exhibits, e.g. here waiting for `sleep 5` took 19
+	// seconds: https://cirrus-ci.com/task/6641382309756928?command=test#L64
+	utils::run_command("sleep", "60");
 
-	const auto finish = high_resolution_clock::now();
+	const auto finish = steady_clock::now();
 	const auto runtime = duration_cast<milliseconds>(finish - start);
 
-	// run_command finished under a second, meaning it didn't wait for
-	// a five-second sleep to finish
-	REQUIRE(runtime.count() < 1000);
+	REQUIRE(runtime.count() < 60000);
 }
 
 TEST_CASE("resolve_tilde() replaces ~ with the path to the $HOME directory",
@@ -899,16 +993,19 @@ TEST_CASE("utils::make_title extracts possible title from URL", "[utils]")
 	}
 }
 
-TEST_CASE("run_interactively", "[utils]")
+TEST_CASE("run_interactively runs a command with inherited I/O", "[utils]")
 {
 	SECTION("echo hello should return 0") {
-		int32_t result = utils::run_interactively("echo hello", "test");
+		const auto result = utils::run_interactively("echo hello", "test");
 		REQUIRE(result == 0);
 	}
 	SECTION("exit 1 should return 1") {
-		int32_t result = utils::run_interactively("exit 1", "test");
+		const auto result = utils::run_interactively("exit 1", "test");
 		REQUIRE(result == 1);
 	}
+
+	// Unfortunately, there is no easy way to provoke this function to return
+	// `nonstd::nullopt`, nor to test that it returns just the lower 8 bits.
 }
 
 TEST_CASE("remove_soft_hyphens remove all U+00AD characters from a string",
